@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified November 7, 2019
+Last modified January 26, 2021
 
 Description:  Compares reads to the kmers in a reference dataset, optionally 
 allowing an edit distance. Splits the reads into two outputs - those that 
@@ -81,6 +81,7 @@ bqhist=<file>       Quality histogram designed for box plots.
 lhist=<file>        Read length histogram.
 phist=<file>        Polymer length histogram.
 gchist=<file>       Read GC content histogram.
+enthist=<file>      Read entropy histogram.
 ihist=<file>        Insert size histogram, for paired reads in mapped sam.
 gcbins=100          Number gchist bins.  Set to 'auto' to use read length.
 maxhistlen=6000     Set an upper bound for histogram lengths; higher uses 
@@ -297,7 +298,10 @@ Cardinality estimation:
 cardinality=f       (loglog) Count unique kmers using the LogLog algorithm.
 cardinalityout=f    (loglogout) Count unique kmers in output reads.
 loglogk=31          Use this kmer length for counting.
-loglogbuckets=1999  Use this many buckets for counting.
+loglogbuckets=2048  Use this many buckets for counting.
+khist=<file>        Kmer frequency histogram; plots number of kmers versus
+                    kmer depth.  This is approximate.
+khistout=<file>     Kmer frequency histogram for output reads.
 
 Java Parameters:
 
