@@ -4,7 +4,7 @@ usage(){
 echo "
 BBMap
 Written by Brian Bushnell, from Dec. 2010 - present
-Last modified February 11, 2019
+Last modified February 13, 2020
 
 Description:  Fast and accurate splice-aware read aligner.
 Please read bbmap/docs/guides/BBMapGuide.txt for more information.
@@ -226,6 +226,8 @@ intronlen=999999999     Set to a lower number like 10 to change 'D' to 'N' in
                         cigar strings for deletions of at least that length.
 rgid=                   Set readgroup ID.  All other readgroup fields 
                         can be set similarly, with the flag rgXX=
+                        If you set a readgroup flag to the word 'filename',
+                        e.g. rgid=filename, the input file name will be used.
 mdtag=f                 Write MD tags.
 nhtag=f                 Write NH tags.
 xmtag=f                 Write XM tags (may only work correctly with ambig=all).
