@@ -5,6 +5,7 @@ import java.util.Arrays;
 
 import dna.AminoAcid;
 import dna.Data;
+import shared.KillSwitch;
 import shared.Shared;
 import shared.Tools;
 import stream.Read;
@@ -515,7 +516,7 @@ public final class BBIndex5 extends AbstractIndex {
 		assert(offsetsM.length==offsetsP.length);
 		assert(maxQuickScore==maxQuickScore(offsetsM, keyScoresM));
 		
-		final int[] bestScores=new int[6];
+		final int[] bestScores=KillSwitch.allocInt1D(6);
 		
 		//This prevents filtering by qscore when a low-quality read only uses a few keys.
 		//In that case, extending is more important.
@@ -2440,7 +2441,7 @@ public final class BBIndex5 extends AbstractIndex {
 	private final int[] startArray=new int[128];
 	private final int[] stopArray=new int[128];
 	private final Quad64[] tripleStorage=makeQuad64Storage(128);
-	private final int[] greedyReturn=new int[2];
+	private final int[] greedyReturn=KillSwitch.allocInt1D(2);
 	private final int[][] shrinkReturn2=new int[3][];
 	private final int[][] shrinkReturn3=new int[5][];
 	private final int[][] prescanReturn=new int[2][];
