@@ -16,6 +16,7 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
 import fileIO.TextStreamWriter;
+import shared.Parse;
 import shared.PreParser;
 import shared.ReadStats;
 import shared.Shared;
@@ -151,18 +152,18 @@ public class BBSplitter {
 					assert(b==null || (b.indexOf('%')>=0 && (b.indexOf('%')<b.lastIndexOf('.')))) :
 						"basename must contain a '%' symbol prior to file extension.";
 				}else if(a.equals("append") || a.equals("app")){
-					append=ReadStats.append=Tools.parseBoolean(b);
+					append=ReadStats.append=Parse.parseBoolean(b);
 //					sysout.println("Set append to "+append);
 					unparsed.add(args[i]);
 				}else if(a.equals("overwrite") || a.equals("ow")){
-					overwrite=Tools.parseBoolean(b);
+					overwrite=Parse.parseBoolean(b);
 //					Data.sysout.println("Set overwrite to "+overwrite);
 					unparsed.add(args[i]);
 				}else if(a.equals("verbose")){
-					verbose=Tools.parseBoolean(b);
+					verbose=Parse.parseBoolean(b);
 					unparsed.add(args[i]);
 				}else if(a.equals("rebuild")){
-					forceRebuild=Tools.parseBoolean(b);
+					forceRebuild=Parse.parseBoolean(b);
 					unparsed.add(args[i]);
 				}else if(a.equals("fastawrap") || a.equals("wrap")){
 					Shared.FASTA_WRAP=Integer.parseInt(b);
