@@ -103,7 +103,7 @@ public final class MultiStateAligner11tsJNI extends MSA{
 		minScore-=120; //Increases quality trivially
 
 		//Create arrays for passing values to and from native library
-		int[] result = new int[5];
+		int[] result = KillSwitch.allocInt1D(5);
 		long[] iterationsLimitedArray = new long[1];
 
 		//Put values into array for passing to native library
@@ -137,7 +137,7 @@ public final class MultiStateAligner11tsJNI extends MSA{
 	private final int[] fillUnlimited(byte[] read, byte[] ref, int refStartLoc, int refEndLoc){
 
 		//Create arrays for passing values to and from native library
-		int[] result = new int[4];
+		int[] result = KillSwitch.allocInt1D(4);
 		long[] iterationsUnlimitedArray = new long[1];
 		iterationsUnlimitedArray[0] = iterationsUnlimited;
 
