@@ -14,6 +14,7 @@ import dna.FastaToChromArrays2;
 import fileIO.ReadWrite;
 import fileIO.SummaryFile;
 import fileIO.TextStreamWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -116,7 +117,7 @@ public final class RandomReads3 {
 			
 //			int x=-1;
 //			try {
-//				x=Tools.parseIntKMG(b);
+//				x=Parse.parseIntKMG(b);
 //			} catch (NumberFormatException e) {}
 			
 			if(Parser.parseZip(arg, a, b)){
@@ -126,23 +127,23 @@ public final class RandomReads3 {
 			}else if(a.equals("coverage")){
 				targetCov=Float.parseFloat(b);
 			}else if(a.equals("simplenames") || a.equals("simple") || a.equals("tagsimple")){
-				FASTQ.TAG_CUSTOM_SIMPLE=Tools.parseBoolean(b);
+				FASTQ.TAG_CUSTOM_SIMPLE=Parse.parseBoolean(b);
 			}else if(a.equals("reads")){
-				maxReads=Tools.parseIntKMG(b);
+				maxReads=Parse.parseIntKMG(b);
 			}else if(a.equals("len") || a.equals("length") || a.equals("readlen") || a.equals("readlength")){
-				minlen=maxlen=Tools.parseIntKMG(b);
+				minlen=maxlen=Parse.parseIntKMG(b);
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("minlen") || a.equals("minlength")){
-				minlen=Tools.parseIntKMG(b);
+				minlen=Parse.parseIntKMG(b);
 				maxlen=Tools.max(minlen, maxlen);
 			}else if(a.equals("maxlen") || a.equals("maxlength")){
-				maxlen=Tools.parseIntKMG(b);
+				maxlen=Parse.parseIntKMG(b);
 				minlen=Tools.min(minlen, maxlen);
 			}else if(a.equals("midlen") || a.equals("midlength")){
-				midlen=Tools.parseIntKMG(b);
+				midlen=Parse.parseIntKMG(b);
 			}else if(a.equals("pbadapter") || a.equals("pacbioadapter")){
 				pbadapter=b;
 			}else if(a.equals("fragadapter") || a.equals("fragadapter1")){
@@ -150,7 +151,7 @@ public final class RandomReads3 {
 			}else if(a.equals("fragadapter2")){
 				fragadapter2=b;
 			}else if(a.equals("amp")){
-				AMP=Tools.parseIntKMG(b);
+				AMP=Parse.parseIntKMG(b);
 			}else if(a.equals("snprate")){
 				snpRate=Float.parseFloat(b);
 			}else if(a.equals("subrate")){
@@ -162,35 +163,35 @@ public final class RandomReads3 {
 			}else if(a.equals("nrate")){
 				nRate=Float.parseFloat(b);
 			}else if(a.equals("maxsnps")){
-				maxSnps=Tools.parseIntKMG(b);
+				maxSnps=Parse.parseIntKMG(b);
 			}else if(a.equals("maxdels")){
-				maxDels=Tools.parseIntKMG(b);
+				maxDels=Parse.parseIntKMG(b);
 			}else if(a.equals("maxsubs")){
-				maxSubs=Tools.parseIntKMG(b);
+				maxSubs=Parse.parseIntKMG(b);
 			}else if(a.equals("maxinss") || a.equals("maxins")){
-				maxInss=Tools.parseIntKMG(b);
+				maxInss=Parse.parseIntKMG(b);
 			}else if(a.equals("banns")){
-				BAN_NS=Tools.parseBoolean(b);
+				BAN_NS=Parse.parseBoolean(b);
 			}else if(a.equals("maxns")){
-				maxNs=Tools.parseIntKMG(b);
+				maxNs=Parse.parseIntKMG(b);
 			}else if(a.startsWith("maxdellen")){
-				maxDelLen=Tools.parseIntKMG(b);
+				maxDelLen=Parse.parseIntKMG(b);
 			}else if(a.startsWith("maxsublen")){
-				maxSubLen=Tools.parseIntKMG(b);
+				maxSubLen=Parse.parseIntKMG(b);
 			}else if(a.startsWith("maxinslen")){
-				maxInsLen=Tools.parseIntKMG(b);
+				maxInsLen=Parse.parseIntKMG(b);
 			}else if(a.startsWith("maxnlen")){
-				maxNLen=Tools.parseIntKMG(b);
+				maxNLen=Parse.parseIntKMG(b);
 			}else if(a.startsWith("mindellen")){
-				minDelLen=Tools.parseIntKMG(b);
+				minDelLen=Parse.parseIntKMG(b);
 			}else if(a.startsWith("minsublen")){
-				minSubLen=Tools.parseIntKMG(b);
+				minSubLen=Parse.parseIntKMG(b);
 			}else if(a.startsWith("mininslen")){
-				minInsLen=Tools.parseIntKMG(b);
+				minInsLen=Parse.parseIntKMG(b);
 			}else if(a.startsWith("minnlen")){
-				minNLen=Tools.parseIntKMG(b);
+				minNLen=Parse.parseIntKMG(b);
 			}else if(a.equals("fastawrap") || a.equals("wrap")){
-				Shared.FASTA_WRAP=Tools.parseIntKMG(b);
+				Shared.FASTA_WRAP=Parse.parseIntKMG(b);
 			}else if(a.startsWith("seed")){
 				seed2=Long.parseLong(b);
 			}else if(a.equals("ref") || a.equals("reference")){
@@ -199,75 +200,75 @@ public final class RandomReads3 {
 				Data.setPath(b);
 			}else if(a.equals("nodisk")){
 				assert(false) : "'nodisk' has not been implemented; please remove that flag.";
-				RefToIndex.NODISK=NODISK=Tools.parseBoolean(b);
+				RefToIndex.NODISK=NODISK=Parse.parseBoolean(b);
 			}else if(a.equals("s") || a.startsWith("snp")){
-				maxSnps=Tools.parseIntKMG(b);
+				maxSnps=Parse.parseIntKMG(b);
 				snpRate=1;
 			}else if(a.equals("i") || a.startsWith("ins")){
-				int x=Tools.parseIntKMG(b);
+				int x=Parse.parseIntKMG(b);
 				maxInss=(x>0 ? 1 : 0);
-				maxInsLen=Tools.parseIntKMG(b);
+				maxInsLen=Parse.parseIntKMG(b);
 				insRate=1;
 			}else if(a.equals("d") || a.startsWith("del")){
-				int x=Tools.parseIntKMG(b);
+				int x=Parse.parseIntKMG(b);
 				maxDels=(x>0 ? 1 : 0);
-				maxDelLen=Tools.parseIntKMG(b);
+				maxDelLen=Parse.parseIntKMG(b);
 				delRate=1;
 			}else if(a.equals("u") || a.startsWith("sub")){
-				int x=Tools.parseIntKMG(b);
+				int x=Parse.parseIntKMG(b);
 				maxSubs=(x>0 ? 1 : 0);
-				maxSubLen=Tools.parseIntKMG(b);
+				maxSubLen=Parse.parseIntKMG(b);
 				subRate=1;
 			}else if(a.equals("n")){
-				maxNs=Tools.parseIntKMG(b);
+				maxNs=Parse.parseIntKMG(b);
 				nRate=1;
 				minNLen=maxNLen=1;
 			}else if(a.startsWith("minchrom")){
-				minChrom=Tools.parseIntKMG(b);
+				minChrom=Parse.parseIntKMG(b);
 			}else if(a.equals("int") || a.equals("interleaved") || a.equals("interleave")){
-				OUTPUT_INTERLEAVED=Tools.parseBoolean(b);
+				OUTPUT_INTERLEAVED=Parse.parseBoolean(b);
 				if(OUTPUT_INTERLEAVED){paired=true;}
 			}else if(a.equals("biasedsnps")){
-				BIASED_SNPS=Tools.parseBoolean(b);
+				BIASED_SNPS=Parse.parseBoolean(b);
 			}else if(a.startsWith("maxchrom")){
-				maxChrom=Tools.parseIntKMG(b);
+				maxChrom=Parse.parseIntKMG(b);
 			}else if(a.startsWith("build") || a.startsWith("genome")){
-				build=Tools.parseIntKMG(b);
+				build=Parse.parseIntKMG(b);
 //				assert(false) : "Set genome to "+x;
 			}else if(a.startsWith("minq")){
-				minQuality=Tools.parseIntKMG(b);
+				minQuality=Parse.parseIntKMG(b);
 				midQuality=Tools.max(midQuality,  minQuality);
 				maxQuality=Tools.max(maxQuality,  minQuality);
 			}else if(a.startsWith("midq")){
-				midQuality=Tools.parseIntKMG(b);
+				midQuality=Parse.parseIntKMG(b);
 			}else if(a.startsWith("maxq")){
-				maxQuality=Tools.parseIntKMG(b);
+				maxQuality=Parse.parseIntKMG(b);
 				midQuality=Tools.min(midQuality,  maxQuality);
 				minQuality=Tools.min(minQuality,  maxQuality);
 			}else if(a.equals("q")){
-				minQuality=midQuality=maxQuality=Tools.parseIntKMG(b);
+				minQuality=midQuality=maxQuality=Parse.parseIntKMG(b);
 			}else if(a.equals("qv") || a.equals("variance") || a.equals("qvariance")){
-				qVariance=Tools.parseIntKMG(b);
+				qVariance=Parse.parseIntKMG(b);
 			}else if(a.equals("mininsert")){
-				minInsert=Tools.parseIntKMG(b);
+				minInsert=Parse.parseIntKMG(b);
 			}else if(a.equals("maxinsert")){
-				maxInsert=Tools.parseIntKMG(b);
+				maxInsert=Parse.parseIntKMG(b);
 			}else if(a.equals("readlengthdev") || a.equals("readlengthsd")){
-				readLengthDev=Tools.parseIntKMG(b);
+				readLengthDev=Parse.parseIntKMG(b);
 			}else if(a.equals("linearlength")){
-				LINEAR_LENGTH=Tools.parseBoolean(b); 
+				LINEAR_LENGTH=Parse.parseBoolean(b); 
 				BELL_LENGTH=!LINEAR_LENGTH;
 			}else if(a.equals("belllength") || a.equals("gaussianlength")){
-				BELL_LENGTH=Tools.parseBoolean(b); 
+				BELL_LENGTH=Parse.parseBoolean(b); 
 				LINEAR_LENGTH=!BELL_LENGTH;
 			}else if(a.startsWith("minmid")){
-				mateMiddleMin=Tools.parseIntKMG(b);
+				mateMiddleMin=Parse.parseIntKMG(b);
 			}else if(a.startsWith("maxmid")){
-				mateMiddleMax=Tools.parseIntKMG(b);
+				mateMiddleMax=Parse.parseIntKMG(b);
 			}else if(a.startsWith("paired")){
-				paired=Tools.parseBoolean(b);
+				paired=Parse.parseBoolean(b);
 			}else if(a.startsWith("superflat")){
-				SUPERFLAT_DIST=Tools.parseBoolean(b);
+				SUPERFLAT_DIST=Parse.parseBoolean(b);
 			}else if(a.startsWith("exponential")){
 				if(b==null){EXP_DIST=true;}
 				else{
@@ -276,31 +277,31 @@ public final class RandomReads3 {
 						EXP_DIST=true;
 						EXP_LAMDA=Double.parseDouble(b);
 					}else{
-						EXP_DIST=Tools.parseBoolean(b);
+						EXP_DIST=Parse.parseBoolean(b);
 					}
 				}
 			}else if(a.startsWith("triang")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					SUPERFLAT_DIST=FLAT_DIST=BELL_DIST=false;
 				}
 			}else if(a.startsWith("flat")){
-				FLAT_DIST=Tools.parseBoolean(b);
+				FLAT_DIST=Parse.parseBoolean(b);
 			}else if(a.startsWith("bell") || a.startsWith("gauss") || a.startsWith("round")){
-				BELL_DIST=Tools.parseBoolean(b);
+				BELL_DIST=Parse.parseBoolean(b);
 			}else if(a.equals("illuminanames")){
-				ILLUMINA_NAMES=Tools.parseBoolean(b);
+				ILLUMINA_NAMES=Parse.parseBoolean(b);
 			}else if(a.equals("insertnames") || a.equals("renamebyinsert")){
-				INSERT_NAMES=Tools.parseBoolean(b);
+				INSERT_NAMES=Parse.parseBoolean(b);
 			}else if(a.startsWith("unique")){
-				USE_UNIQUE_SNPS=Tools.parseBoolean(b);
+				USE_UNIQUE_SNPS=Parse.parseBoolean(b);
 			}else if(a.startsWith("adderrors") || a.startsWith("usequality")){
-				ADD_ERRORS_FROM_QUALITY=Tools.parseBoolean(b);
+				ADD_ERRORS_FROM_QUALITY=Parse.parseBoolean(b);
 			}else if(a.equals("pacbio")){
 				if(b!=null && (b.charAt(0)=='.' || Tools.isDigit(b.charAt(0)))){
 					pbMinErrorRate=pbMaxErrorRate=Float.parseFloat(b);
 					ADD_PACBIO_ERRORS=pbMinErrorRate>0;
 				}else{
-					ADD_PACBIO_ERRORS=Tools.parseBoolean(b);
+					ADD_PACBIO_ERRORS=Parse.parseBoolean(b);
 				}
 				if(ADD_PACBIO_ERRORS){ADD_ERRORS_FROM_QUALITY=false;}
 			}else if(a.equals("pbmin") || a.equals("pbminrate")){
@@ -308,39 +309,39 @@ public final class RandomReads3 {
 			}else if(a.equals("pbmax") || a.equals("pbmaxrate")){
 				pbMaxErrorRate=Float.parseFloat(b);
 			}else if(a.startsWith("midpad")){
-				midPad=Tools.parseIntKMG(b);
+				midPad=Parse.parseIntKMG(b);
 			}else if(a.startsWith("randomscaffold")){
-				RANDOM_SCAFFOLD=Tools.parseBoolean(b);
+				RANDOM_SCAFFOLD=Parse.parseBoolean(b);
 			}else if(a.startsWith("metagenome")){
-				METAGENOME=Tools.parseBoolean(b);
+				METAGENOME=Parse.parseBoolean(b);
 			}else if(a.startsWith("replacenoref")){
-				REPLACE_NOREF=Tools.parseBoolean(b);
+				REPLACE_NOREF=Parse.parseBoolean(b);
 			}else if(a.equals("out") || a.equals("out1")){
 				out1=b;
 			}else if(a.equals("out2")){
 				out2=b;
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ext") || a.equals("extension")){
 				fileExt=b;
 				if(fileExt==null){fileExt=".fq.gz";}
 				if(!fileExt.startsWith(".")){fileExt="."+fileExt;}
 			}else if(a.equals("perfect")){
-				PERFECT_READ_RATIO=(Tools.parseBoolean(b) ? 1 : Float.parseFloat(b));
+				PERFECT_READ_RATIO=(Parse.parseBoolean(b) ? 1 : Float.parseFloat(b));
 			}else if(a.equals("singlescaffold")){
-				FORCE_SINGLE_SCAFFOLD=Tools.parseBoolean(b);
+				FORCE_SINGLE_SCAFFOLD=Parse.parseBoolean(b);
 			}else if(a.equals("samestrand")){
-				mateSameStrand=Tools.parseBoolean(b);
+				mateSameStrand=Parse.parseBoolean(b);
 			}else if(a.equals("minoverlap") || a.equals("overlap")){
-				MIN_SCAFFOLD_OVERLAP=Tools.parseIntKMG(b);
+				MIN_SCAFFOLD_OVERLAP=Parse.parseIntKMG(b);
 			}else if(a.equals("prefix")){
 				prefix_=b;
 			}else if(a.equals("slashes") || a.equals("addslashes") || a.equals("slash") || a.equals("addslash")){
-				addslash=FASTQ.ADD_SLASH_PAIRNUM_TO_CUSTOM_ID=Tools.parseBoolean(b);
+				addslash=FASTQ.ADD_SLASH_PAIRNUM_TO_CUSTOM_ID=Parse.parseBoolean(b);
 			}else if(a.equals("addpairnum") || a.equals("pairnum") || a.equals("addcolon")){
-				FASTQ.ADD_PAIRNUM_TO_CUSTOM_ID=Tools.parseBoolean(b);
+				FASTQ.ADD_PAIRNUM_TO_CUSTOM_ID=Parse.parseBoolean(b);
 			}else if(a.equals("slashspace") || a.equals("spaceslash")){
-				spaceslash=Tools.parseBoolean(b);
+				spaceslash=Parse.parseBoolean(b);
 				FASTQ.SPACE_SLASH=spaceslash;
 			}else if(a.equals("in")){
 				in1=(b==null || b.equalsIgnoreCase("null") ? null : b);
