@@ -18,6 +18,7 @@ import kmer.HashArray1D;
 import kmer.HashForest;
 import kmer.KmerNode;
 import kmer.KmerTableSet;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -147,23 +148,23 @@ public class KmerCompressor {
 			}else if(a.equals("out") || a.equals("contigs")){
 				outContigs=b;
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("fuse")){
 				if(b==null || Character.isLetter(b.charAt(0))){
-					fuse_=Tools.parseBoolean(b) ? 100000 : 0;
+					fuse_=Parse.parseBoolean(b) ? 100000 : 0;
 				}else{
 					fuse_=Integer.parseInt(b);
 				}
 			}else if(a.equals("showstats") || a.equals("stats")){
-				showStats=Tools.parseBoolean(b);
+				showStats=Parse.parseBoolean(b);
 			}else if(a.equals("mincount") || a.equals("mincov") || a.equals("mindepth") || a.equals("min")){
-				minCount=Tools.parseIntKMG(b);
+				minCount=Parse.parseIntKMG(b);
 			}else if(a.equals("maxcount") || a.equals("maxcov") || a.equals("maxdepth") || a.equals("max")){
-				maxCount=Tools.parseIntKMG(b);
+				maxCount=Parse.parseIntKMG(b);
 			}else if(a.equals("requiresamecount") || a.equals("rsc") || a.equals("rsd")){
-				REQUIRE_SAME_COUNT=Tools.parseBoolean(b);
+				REQUIRE_SAME_COUNT=Parse.parseBoolean(b);
 			}else if(a.equals("threads") || a.equals("t")){
 				Shared.setThreads(b);
 			}else if(a.equals("buildthreads") || a.equals("bthreads") || a.equals("bt")){
@@ -174,17 +175,17 @@ public class KmerCompressor {
 					BUILD_THREADS=Integer.parseInt(b);
 				}
 			}else if(a.equals("showspeed") || a.equals("ss")){
-				showSpeed=Tools.parseBoolean(b);
+				showSpeed=Parse.parseBoolean(b);
 			}else if(a.equals("verbose")){
 //				assert(false) : "Verbose flag is currently static final; must be recompiled to change.";
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("verbose2")){
 //				assert(false) : "Verbose flag is currently static final; must be recompiled to change.";
-				verbose2=Tools.parseBoolean(b);
+				verbose2=Parse.parseBoolean(b);
 			}else if(a.equals("ilb") || a.equals("ignoreleftbranches") || a.equals("ignoreleftjunctions") || a.equals("ibb") || a.equals("ignorebackbranches")){
-				extendThroughLeftJunctions=Tools.parseBoolean(b);
+				extendThroughLeftJunctions=Parse.parseBoolean(b);
 			}else if(a.equals("rcomp")){
-				doRcomp=Tools.parseBoolean(b);
+				doRcomp=Parse.parseBoolean(b);
 			}
 			
 			else if(KmerTableSetU.isValidArgument(a)){
