@@ -601,11 +601,13 @@ public class Tadpole1 extends Tadpole {
 			int cnum=0;
 			for(Contig c : contigs){
 				c.id=cnum;
-				if(c.leftBranch()){
+//				if(c.leftBranch()){
+				if(true){
 					long kmer=c.leftKmer(k);
 					tables.claim(kmer, rcomp(kmer), cnum);
 				}
-				if(c.rightBranch()){
+//				if(c.rightBranch()){
+				if(true){
 					long kmer=c.rightKmer(k);
 					tables.claim(kmer, rcomp(kmer), cnum);
 				}
@@ -630,7 +632,8 @@ public class Tadpole1 extends Tadpole {
 			
 			assert(tables.getCount(kmer0, rkmer0)>0);
 			assert(tables.findOwner(kmer0)==c.id) : tables.findOwner(kmer0)+", "+c.id;
-
+//			System.err.println(tables.findOwner(kmer0));
+			
 			int leftMaxPos=fillLeftCounts(kmer0, rkmer0, leftCounts);
 			int leftMax=leftCounts[leftMaxPos];
 			int leftSecondPos=Tools.secondHighestPosition(leftCounts);
