@@ -8,6 +8,7 @@ import java.util.Locale;
 
 import dna.AminoAcid;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -92,7 +93,7 @@ public class BloomFilter implements Serializable {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("k") || a.equals("ksmall")){
 				k_=Integer.parseInt(b);
 				assert(k_<=31 && k_>=1);
@@ -115,9 +116,9 @@ public class BloomFilter implements Serializable {
 					for(String s : b.split(",")){extra.add(s);}
 				}
 			}else if(a.equals("rcomp")){
-				rcomp_=Tools.parseBoolean(b);
+				rcomp_=Parse.parseBoolean(b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
