@@ -13,6 +13,7 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import jgi.BBMerge;
 import shared.MetadataWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -111,9 +112,9 @@ public class BloomFilterCorrectorWrapper {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equalsIgnoreCase("k") || a.equalsIgnoreCase("bloomK") || a.equalsIgnoreCase("bloomFilterK") || a.equalsIgnoreCase("kbig")){
@@ -124,7 +125,7 @@ public class BloomFilterCorrectorWrapper {
 			}else if(a.equalsIgnoreCase("hashes") || a.equalsIgnoreCase("bloomHashes") || a.equalsIgnoreCase("bloomFilterHashes")){
 				hashes_=Integer.parseInt(b);
 			}else if(a.equals("rcomp")){
-				rcomp_=Tools.parseBoolean(b);
+				rcomp_=Parse.parseBoolean(b);
 			}else if(a.equals("bits")){
 				setBits=true;
 				bits_=Integer.parseInt(b);
@@ -134,27 +135,27 @@ public class BloomFilterCorrectorWrapper {
 			}else if(a.equals("minprob")){
 				KmerCount7MTA.minProb=Float.parseFloat(b);
 			}else if(a.equals("requireboth")){
-				requireBothToPass_=Tools.parseBoolean(b);
+				requireBothToPass_=Parse.parseBoolean(b);
 			}else if(a.equals("ecc")){
-				ecc_=Tools.parseBoolean(b);
+				ecc_=Parse.parseBoolean(b);
 			}else if(a.equals("ecco")){
-				ecco_=Tools.parseBoolean(b);
+				ecco_=Parse.parseBoolean(b);
 			}else if(a.equals("merge")){
-				merge_=Tools.parseBoolean(b);
+				merge_=Parse.parseBoolean(b);
 			}else if(a.equals("testmerge")){
-				testMerge_=Tools.parseBoolean(b);
+				testMerge_=Parse.parseBoolean(b);
 			}else if(a.equals("testmergewidth")){
 				testMergeWidth=Integer.parseInt(b);
 			}else if(a.equals("testmergethresh")){
 				testMergeThresh=Integer.parseInt(b);
 			}else if(a.equals("testmergemult")){
-				testMergeMult=Tools.parseKMG(b);
+				testMergeMult=Parse.parseKMG(b);
 			}else if(a.equals("vstrict")){
-				vstrict_=Tools.parseBoolean(b);
+				vstrict_=Parse.parseBoolean(b);
 			}else if(a.equals("ustrict")){
-				ustrict_=Tools.parseBoolean(b);
+				ustrict_=Parse.parseBoolean(b);
 			}else if(a.equals("tossjunk")){
-				tossjunk_=Tools.parseBoolean(b);
+				tossjunk_=Parse.parseBoolean(b);
 			}else if(a.equals("memfraction") || a.equals("memmult") || a.equals("memratio")){
 				memFraction=Float.parseFloat(b);
 			}else if(a.equalsIgnoreCase("highCountFraction") || a.equalsIgnoreCase("mincountfraction") || a.equals("hcf")){
@@ -162,25 +163,25 @@ public class BloomFilterCorrectorWrapper {
 			}
 			
 			else if(a.equals("pincer")){
-				corrector.ECC_PINCER=Tools.parseBoolean(b);
+				corrector.ECC_PINCER=Parse.parseBoolean(b);
 			}else if(a.equals("tail")){
-				corrector.ECC_TAIL=Tools.parseBoolean(b);
+				corrector.ECC_TAIL=Parse.parseBoolean(b);
 			}else if(a.equals("reassemble")){
-				corrector.ECC_REASSEMBLE=Tools.parseBoolean(b);
+				corrector.ECC_REASSEMBLE=Parse.parseBoolean(b);
 			}else if(a.equals("smooth")){
 				if(b!=null && Character.isDigit(b.charAt(0))){
 					corrector.smoothWidth=Integer.parseInt(b);
 					corrector.smooth=corrector.smoothWidth>0;
 				}else{
-					corrector.smooth=Tools.parseBoolean(b);
+					corrector.smooth=Parse.parseBoolean(b);
 				}
 //				assert(false) : corrector.smooth+", "+corrector.smoothWidth;
 			}else if(a.equals("smoothwidth")){
 				corrector.smoothWidth=Integer.parseInt(b);
 			}else if(a.equals("cells")){
-				BloomFilter.OVERRIDE_CELLS=Tools.parseKMG(b);
+				BloomFilter.OVERRIDE_CELLS=Parse.parseKMG(b);
 			}else if(a.equals("seed")){
-				KCountArray7MTA.setSeed(Tools.parseKMG(b));
+				KCountArray7MTA.setSeed(Parse.parseKMG(b));
 			}
 			
 			else if(a.equals("ref")){
@@ -196,7 +197,7 @@ public class BloomFilterCorrectorWrapper {
 			}else if(a.equals("outb2") || a.equals("outbad2") || a.equals("outlow2")){
 				outbad2=b;
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
