@@ -9,6 +9,7 @@ import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import jgi.BBMerge;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -98,9 +99,9 @@ public class BloomFilterWrapper {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equalsIgnoreCase("k") || a.equalsIgnoreCase("bloomK") || a.equalsIgnoreCase("bloomFilterK")){
@@ -110,7 +111,7 @@ public class BloomFilterWrapper {
 			}else if(a.equalsIgnoreCase("minhits") || a.equalsIgnoreCase("bloomMinHits") || a.equalsIgnoreCase("bloomFilterMinHits")){
 				minConsecutiveMatches_=Integer.parseInt(b);
 			}else if(a.equals("rcomp")){
-				rcomp_=Tools.parseBoolean(b);
+				rcomp_=Parse.parseBoolean(b);
 			}else if(a.equals("bits")){
 				setBits=true;
 				bits_=Integer.parseInt(b);
@@ -122,17 +123,17 @@ public class BloomFilterWrapper {
 			}else if(a.equals("minprob")){
 				KmerCount7MTA.minProb=Float.parseFloat(b);
 			}else if(a.equals("requireboth")){
-				requireBothToMatch_=Tools.parseBoolean(b);
+				requireBothToMatch_=Parse.parseBoolean(b);
 			}else if(a.equals("ecco")){
-				ecco_=Tools.parseBoolean(b);
+				ecco_=Parse.parseBoolean(b);
 			}else if(a.equals("merge")){
-				merge_=Tools.parseBoolean(b);
+				merge_=Parse.parseBoolean(b);
 			}else if(a.equals("memfraction") || a.equals("memmult") || a.equals("memratio")){
 				memFraction=Float.parseFloat(b);
 			}else if(a.equals("cells")){
-				BloomFilter.OVERRIDE_CELLS=Tools.parseKMG(b);
+				BloomFilter.OVERRIDE_CELLS=Parse.parseKMG(b);
 			}else if(a.equals("seed")){
-				KCountArray7MTA.setSeed(Tools.parseKMG(b));
+				KCountArray7MTA.setSeed(Parse.parseKMG(b));
 			}
 			
 			else if(a.equals("serialin")){
@@ -152,7 +153,7 @@ public class BloomFilterWrapper {
 			}else if(a.equals("outu2") || a.equals("out2")){
 				out2=b;
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
