@@ -8,6 +8,8 @@ import dna.AminoAcid;
 import dna.Data;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -85,25 +87,25 @@ public class ErrorCorrect extends Thread{
 			}else if(a.equals("threads") || a.equals("t")){
 				System.err.println("Can't change threadcount for this class."); //THREADS=Integer.parseInt(b);
 			}else if(a.startsWith("reads") || a.startsWith("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.startsWith("tablereads")){
-				tablereads=Tools.parseKMG(b);
+				tablereads=Parse.parseKMG(b);
 			}else if(a.startsWith("build") || a.startsWith("genome")){
 				Data.setGenome(Integer.parseInt(b));
 				Data.sysout.println("Set genome to "+Data.GENOME_BUILD);
 			}else if(a.equals("outputinfo") || a.startsWith("info")){
-				OUTPUT_INFO=Tools.parseBoolean(b);
+				OUTPUT_INFO=Parse.parseBoolean(b);
 			}else if(a.startsWith("out")){
 				output=b;
 			}else if(a.startsWith("verbose")){
-				KCountArray.verbose=Tools.parseBoolean(b);
-//				verbose=KCountArray.verbose=Tools.parseBoolean(b);
+				KCountArray.verbose=Parse.parseBoolean(b);
+//				verbose=KCountArray.verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered") || a.equals("ord")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else{
 				throw new RuntimeException("Unknown parameter "+args[i]);
 			}
@@ -609,8 +611,8 @@ public class ErrorCorrect extends Thread{
 		}
 		assert(len==setlen-1) : setlen+", "+len+", "+error+", "+startLoc;
 		
-		int[] counts=new int[4];
-		int[] dists=new int[4];
+		int[] counts=KillSwitch.allocInt1D(4);
+		int[] dists=KillSwitch.allocInt1D(4);
 		int maxLoc=Tools.min(bases.length-1, error+setlen-1);
 		if(!bs.get(error+1)){maxLoc=Tools.min(maxLoc, error+9);}
 		else{
@@ -718,8 +720,8 @@ public class ErrorCorrect extends Thread{
 		}
 		assert(len==setlen-1) : setlen+", "+len+", "+error+", "+stopLoc;
 		
-		int[] counts=new int[4];
-		int[] dists=new int[4];
+		int[] counts=KillSwitch.allocInt1D(4);
+		int[] dists=KillSwitch.allocInt1D(4);
 		int minLoc=Tools.max(0, error-setlen+1);
 		if(error==0 || !bs.get(error-1)){minLoc=Tools.max(minLoc, error-9);}
 		else{
