@@ -6,6 +6,7 @@ import java.util.Arrays;
 import java.util.Random;
 import java.util.concurrent.atomic.AtomicIntegerArray;
 
+import shared.KillSwitch;
 import shared.Primes;
 import shared.Shared;
 import shared.Timer;
@@ -189,7 +190,7 @@ public final class KCountArray7MTA extends KCountArray {
 	@Override
 	public final int[] readAllLeft(final long key, final int k, boolean makeCanonical, int[] rvec){
 		assert(k<=32);
-		if(rvec==null){rvec=new int[4];}
+		if(rvec==null){rvec=KillSwitch.allocInt1D(4);}
 		final long key2=key>>>2;
 		final int shift=2*(k-1);
 		final long akey=key2|(0L<<shift);
