@@ -7,6 +7,7 @@ import java.util.Locale;
 
 import dna.AminoAcid;
 import fileIO.FileFormat;
+import shared.Parse;
 import shared.Timer;
 import shared.Tools;
 import stream.ConcurrentReadInputStream;
@@ -46,7 +47,7 @@ public class KmerCount6MT extends KmerCountAbstract {
 			}else if(a.startsWith("gap")){
 				gap=Integer.parseInt(b);
 			}else if(a.startsWith("reads") || a.startsWith("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.startsWith("matrixbits")){
 				matrixbits=Integer.parseInt(b);
 			}else if(a.startsWith("hashes")){
