@@ -4,6 +4,7 @@ import java.util.ArrayList;
 
 import dna.AminoAcid;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Tools;
 import stream.Read;
 import structures.ByteBuilder;
@@ -620,7 +621,7 @@ public class Clump extends ArrayList<Read> implements Comparable<Clump> {
 //		assert(Splitter.findBestPivot(this)<0); //TODO: Slow
 		Read consen=makeSimpleConsensus();
 		long sum=0;
-		final int[] rvector=new int[2];
+		final int[] rvector=KillSwitch.allocInt1D(2);
 		for(Read r : this){
 			sum+=errorCorrect(r, consen, rvector);
 		}
@@ -987,37 +988,37 @@ public class Clump extends ArrayList<Read> implements Comparable<Clump> {
 		}else if(a.equals("border")){
 			KmerComparator.defaultBorder=Integer.parseInt(b);
 		}else if(a.equals("conservative")){
-			conservativeFlag=Tools.parseBoolean(b);
+			conservativeFlag=Parse.parseBoolean(b);
 		}else if(a.equals("aggressive")){
-			aggressiveFlag=Tools.parseBoolean(b);
+			aggressiveFlag=Parse.parseBoolean(b);
 		}else if(a.equals("forceprocess")){
-			forceProcess=Tools.parseBoolean(b);
+			forceProcess=Parse.parseBoolean(b);
 		}else if(a.equals("mergefirst")){
-			KmerComparator.mergeFirst=Tools.parseBoolean(b);
+			KmerComparator.mergeFirst=Parse.parseBoolean(b);
 		}else if(a.equals("findcorrelations")){
-			Splitter.FIND_CORRELATIONS=Tools.parseBoolean(b);
+			Splitter.FIND_CORRELATIONS=Parse.parseBoolean(b);
 		}else if(a.equals("maxcorrelations")){
 			Splitter.MAX_CORRELATIONS=Integer.parseInt(b);
 		}
 		
 		else if(a.equals("sortx")){
-			sortX=Tools.parseBoolean(b);
+			sortX=Parse.parseBoolean(b);
 		}else if(a.equals("sorty")){
-			sortY=Tools.parseBoolean(b);
+			sortY=Parse.parseBoolean(b);
 		}else if(a.equals("sortxy")){
-			sortX=sortY=Tools.parseBoolean(b);
+			sortX=sortY=Parse.parseBoolean(b);
 		}else if(a.equals("forcesortxy") || a.equals("forcexy")){
-			forceSortXY=Tools.parseBoolean(b);
+			forceSortXY=Parse.parseBoolean(b);
 		}else if(a.equals("sortxysize") || a.equals("xysize")){
 			sortXYSize=Integer.parseInt(b);
 		}
 		
 		else if(a.equals("removeallduplicates") || a.equals("allduplicates")){
-			markAll=Tools.parseBoolean(b);
+			markAll=Parse.parseBoolean(b);
 		}else if(a.equals("addcount") || a.equals("renamebycount")){
-			renameByCount=Tools.parseBoolean(b);
+			renameByCount=Parse.parseBoolean(b);
 		}else if(a.equals("optical") || a.equals("opticalonly")){
-			opticalOnly=Tools.parseBoolean(b);
+			opticalOnly=Parse.parseBoolean(b);
 		}else if(a.equals("dupesubs") || a.equals("duplicatesubs") || a.equals("dsubs") || a.equals("subs") || a.equals("s")){
 			maxSubstitutions=Integer.parseInt(b);
 		}else if(a.equals("dupedist") || a.equals("duplicatedistance") || a.equals("ddist") || a.equals("dist") || a.equals("opticaldist") || a.equals("distance")){
@@ -1026,13 +1027,13 @@ public class Clump extends ArrayList<Read> implements Comparable<Clump> {
 		}else if(a.equals("scanlimit") || a.equals("scan")){
 			scanLimit=Integer.parseInt(b);
 		}else if(a.equals("allowns")){
-			allowNs=Tools.parseBoolean(b);
+			allowNs=Parse.parseBoolean(b);
 		}else if(a.equals("containment") || a.equals("absorbcontainment") || a.equals("ac") || a.equals("contains")){
-			containment=Tools.parseBoolean(b);
+			containment=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("prefixOrSuffix") || a.equalsIgnoreCase("suffixOrPrefix") || a.equals("affix") || a.equals("pos")){
-			affix=Tools.parseBoolean(b);
+			affix=Parse.parseBoolean(b);
 		}else if(a.equals("printduplicates")){
-			printDuplicates=Tools.parseBoolean(b);
+			printDuplicates=Parse.parseBoolean(b);
 		}else if(a.equals("dupeidentity")){
 			float dupeIdentity=Float.parseFloat(b);
 			if(dupeIdentity>1){dupeIdentity=dupeIdentity/100;}
