@@ -3,6 +3,7 @@ import java.util.Arrays;
 import java.util.HashMap;
 
 import align2.QualityTools;
+import shared.KillSwitch;
 import shared.Tools;
 import structures.ByteBuilder;
 
@@ -192,7 +193,7 @@ public final class AminoAcid {
 	/** Element i is: 5-bit alphabetical code for a symbol, 0 otherwise */
 	public static final byte[] acidToNumber0=new byte[128];//Rename acidToNumber0
 	
-	/** Element i is: 5-bit alphabetical code for a symbol (plus X and . and -), -1 otherwise */
+	/** Element i is: 5-bit alphabetical code for a symbol (plus X, B, J, Z, . and -), -1 otherwise */
 	public static final byte[] acidToNumberExtended=new byte[128];
 	
 	/** Element i is: 5-bit alphabetical code for a symbol, -1 otherwise */
@@ -433,7 +434,7 @@ public final class AminoAcid {
 	
 	public static final byte[] numberToBases(int code, int n){
 		
-		byte[] bytes=new byte[n];
+		byte[] bytes=KillSwitch.allocByte1D(n);
 		
 		for(int i=n-1; i>=0; i--){
 			int temp=code&3;
@@ -642,7 +643,7 @@ public final class AminoAcid {
 		final int stop=frame+blen;
 		final int alen=blen/3;
 		
-		byte[] out=new byte[alen];
+		byte[] out=KillSwitch.allocByte1D(alen);
 		for(int i=2+frame, j=0; i<stop; i+=3, j++){
 			byte a=toByte(bases[i-2], bases[i-1], bases[i]);
 			out[j]=a;
@@ -656,7 +657,7 @@ public final class AminoAcid {
 		final int blen=stop-start;
 		final int alen=blen/3;
 		
-		byte[] out=new byte[alen];
+		byte[] out=KillSwitch.allocByte1D(alen);
 		for(int i=2+start, j=0; i<stop; i+=3, j++){
 			byte a=toByte(bases[i-2], bases[i-1], bases[i]);
 			out[j]=a;
@@ -672,7 +673,7 @@ public final class AminoAcid {
 		final int stop=frame+blen;
 		final int alen=blen/3;
 		
-		byte[] out=new byte[alen];
+		byte[] out=KillSwitch.allocByte1D(alen);
 		for(int i=2+frame, j=0; i<stop; i+=3, j++){
 			byte qa=quals[i-2], qb=quals[i-1], qc=quals[i];
 			float pa=QualityTools.PROB_CORRECT[qa], pb=QualityTools.PROB_CORRECT[qb], pc=QualityTools.PROB_CORRECT[qc];
@@ -694,7 +695,7 @@ public final class AminoAcid {
 		final int alen=aminos.length;
 		final int blen=alen*3;
 		
-		final byte[] out=new byte[blen];
+		final byte[] out=KillSwitch.allocByte1D(blen);
 		for(int i=0, j=0; i<alen; i++, j+=3){
 			int code=aminoToCode[aminos[i]];
 			out[j+2]=numberToBase[(code&3)];
@@ -891,8 +892,16 @@ public final class AminoAcid {
 		for(int i=0; i<acidToNumber.length; i++){
 			acidToNumberExtended[i]=acidToNumber[i];
 		}
-		acidToNumberExtended['x']=acidToNumberExtended['X']=acidToNumberExtended['.']=(byte)(Tools.max(acidToNumberExtended)+1);
-		acidToNumberExtended['-']=(byte)(Tools.max(acidToNumberExtended)+1);
+		
+		{
+			byte anySym=(byte)(Tools.max(acidToNumberExtended)+1);
+			byte dash=(byte)(anySym+1);
+			acidToNumberExtended['x']=acidToNumberExtended['X']=acidToNumberExtended['.']=anySym;
+			acidToNumberExtended['b']=acidToNumberExtended['B']=anySym;
+			acidToNumberExtended['z']=acidToNumberExtended['Z']=anySym;
+			acidToNumberExtended['j']=acidToNumberExtended['J']=anySym;
+			acidToNumberExtended['-']=dash;
+		}
 		
 		acidToNumber8['H']=acidToNumber8['K']=acidToNumber8['R']=0;
 		acidToNumber8['D']=acidToNumber8['E']=1;
@@ -902,8 +911,9 @@ public final class AminoAcid {
 		acidToNumber8['P']=acidToNumber8['G']=5;
 		acidToNumber8['C']=acidToNumber8['*']=6;
 		acidToNumber8['B']=acidToNumber8['Z']=7;
-		
-		aminoToCode['X']=aminoToCode['x']=aminoToCode['B']=aminoToCode['b']=aminoToCode['Z']=aminoToCode['z']=65;
+
+		aminoToCode['X']=aminoToCode['x']=aminoToCode['B']=aminoToCode['b']=
+				aminoToCode['Z']=aminoToCode['z']=aminoToCode['J']=aminoToCode['j']=65;
 		codeToAA[65]=ANY;
 		codeToChar[65]='X';
 		codeToByte[65]='X';
