@@ -21,6 +21,7 @@ import fileIO.ChainLine;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
 import server.PercentEncoding;
+import shared.Parse;
 import shared.Primes;
 import shared.Shared;
 import shared.Tools;
@@ -812,7 +813,7 @@ public class Data {
 					else if(a.equalsIgnoreCase("source")){genomeSource=b;}
 					else if(a.equalsIgnoreCase("bytes")){fastabytes=Long.parseLong(b);}
 					else if(a.equalsIgnoreCase("last modified")){fastatime=Long.parseLong(b);}
-					else if(a.equalsIgnoreCase("scafprefixes")){scaffoldPrefixes=Tools.parseBoolean(b);}
+					else if(a.equalsIgnoreCase("scafprefixes")){scaffoldPrefixes=Parse.parseBoolean(b);}
 					else{assert(version<currentVersion) : "In array: Unknown term "+s;}
 				}
 			}
@@ -841,7 +842,7 @@ public class Data {
 					else if(a.equalsIgnoreCase("source")){genomeSource=b;}
 					else if(a.equalsIgnoreCase("bytes")){fastabytes=Long.parseLong(b);}
 					else if(a.equalsIgnoreCase("last modified")){fastatime=Long.parseLong(b);}
-					else if(a.equalsIgnoreCase("scafprefixes")){scaffoldPrefixes=Tools.parseBoolean(b);}
+					else if(a.equalsIgnoreCase("scafprefixes")){scaffoldPrefixes=Parse.parseBoolean(b);}
 					else{assert(version<currentVersion) : "In file "+tf.name+": Unknown term "+s;}
 				}
 			}
