@@ -509,6 +509,14 @@ public class ByteStreamWriter extends Thread {
 		return this;
 	}
 	
+	public ByteStreamWriter println(byte[] x){
+		if(verbose){System.err.println("Added line '"+new String(x)+"'");}
+		assert(open) : new String(x);
+		buffer.append(x).nl();
+		flushBuffer(false);
+		return this;
+	}
+	
 	public ByteStreamWriter print(byte[] x, int len){
 		if(verbose){System.err.println("Added line '"+new String(x)+"'");}
 		assert(open) : new String(x);
@@ -600,7 +608,7 @@ public class ByteStreamWriter extends Thread {
 	public ByteStreamWriter println(double x, int d){print(x, d); return print('\n');}
 	public ByteStreamWriter println(byte x){print(x); return print('\n');}
 	public ByteStreamWriter println(char x){print(x); return print('\n');}
-	public ByteStreamWriter println(byte[] x){print(x); return print('\n');}
+//	public ByteStreamWriter println(byte[] x){print(x); return print('\n');}
 	public ByteStreamWriter println(char[] x){print(x); return print('\n');}
 	public ByteStreamWriter println(ByteBuilder x){print(x); return print('\n');}
 	public ByteStreamWriter println(ByteBuilder x, boolean destroy){
@@ -620,6 +628,15 @@ public class ByteStreamWriter extends Thread {
 		return this;
 	}
 	
+	/*--------------------------------------------------------------*/
+	/*----------------           Inherited          ----------------*/
+	/*--------------------------------------------------------------*/
+	
+	@Override
+	public String toString(){
+		return "BSW for "+fname;
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
