@@ -10,6 +10,7 @@ import java.util.Arrays;
 import java.util.List;
 
 import jgi.TestFormat;
+import shared.Parse;
 import shared.PreParser;
 import shared.Tools;
 
@@ -41,9 +42,9 @@ public final class FileFormat {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("full")){
-				full=Tools.parseBoolean(b);
+				full=Parse.parseBoolean(b);
 			}else if(b!=null){
 //				assert(a.startsWith("in")) : "Unknown parameter "+arg;
 				if(a.startsWith("in")){files.add(b);}
