@@ -14,6 +14,7 @@ import jgi.Dedupe;
 import kmer.AbstractKmerTable;
 import kmer.HashArray1D;
 import kmer.ScheduleMaker;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -137,7 +138,7 @@ public class AnalyzeFlowCell {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("seed")){
 				seed=Long.parseLong(b);
 			}else if(a.equals("divisor") || a.equals("size")){
@@ -153,11 +154,11 @@ public class AnalyzeFlowCell {
 			}else if(a.equals("indump") || a.equals("ind") || a.equals("dumpin")){
 				dumpIn=b;
 			}else if(a.equals("pound")){
-				pound=Tools.parseBoolean(b);
+				pound=Parse.parseBoolean(b);
 			}else if(a.equals("loadkmers") || a.equals("usekmers")){
-				loadKmers=Tools.parseBoolean(b);
+				loadKmers=Parse.parseBoolean(b);
 			}else if(a.equals("lqo") || a.equals("lowqualityonly")){
-				discardOnlyLowQuality=Tools.parseBoolean(b);
+				discardOnlyLowQuality=Parse.parseBoolean(b);
 			}else if(a.equals("dl") || a.equals("discardlevel")){
 				discardLevel=Integer.parseInt(b);
 			}else if(a.equals("outbad") || a.equals("outb") || a.equals("outtoss") || a.equals("outt") || a.equals("outunwanted") || a.equals("outu")){
@@ -197,15 +198,15 @@ public class AnalyzeFlowCell {
 			}
 			
 			else if(a.equals("gton")){
-				gToN=Tools.parseBoolean(b);
+				gToN=Parse.parseBoolean(b);
 			}else if(a.equals("discardg")){
-				discardG=Tools.parseBoolean(b);
+				discardG=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("minpolyg")){
 				MicroTile.MIN_POLY_G=Integer.parseInt(b);
 			}else if(a.equals("trackcycles")){
-				MicroTile.TRACK_CYCLES=Tools.parseBoolean(b);
+				MicroTile.TRACK_CYCLES=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("parse_flag_goes_here")){
