@@ -3,7 +3,6 @@ package icecream;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.concurrent.ArrayBlockingQueue;
 
 import aligner.AlignmentResult;
 import aligner.FlatAligner;
@@ -16,6 +15,7 @@ import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import json.JsonObject;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -23,17 +23,13 @@ import shared.Shared;
 import shared.Timer;
 import shared.Tools;
 import shared.TrimRead;
-import stream.ConcurrentReadInputStream;
 import stream.ConcurrentReadOutputStream;
 import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import stream.SamLine;
-import stream.SamReadStreamer;
 import structures.ByteBuilder;
 import structures.EntropyTracker;
-import structures.IntList;
-import structures.ListNum;
 
 /**
  * Detects inverted repeats in PacBio reads.
@@ -131,8 +127,6 @@ public final class IceCreamFinder {
 		
 		//Create input FileFormat objects
 		ffin1=FileFormat.testInput(in1, FileFormat.FASTQ, extin, true, true);
-
-		queue=new ArrayBlockingQueue<ArrayList<Read>>(queuelen);
 		
 		final int alen=(adapter==null ? 20 : adapter.length);
 		stride=(int)(alen*1.9f);
@@ -172,7 +166,7 @@ public final class IceCreamFinder {
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("format")){
 				if(b==null){
 					assert(false) : arg;
@@ -187,44 +181,45 @@ public final class IceCreamFinder {
 				}
 				assert(format>=1 && format<=2) : arg;
 			}else if(a.equals("json")){
-				boolean x=Tools.parseBoolean(b);
+				boolean x=Parse.parseBoolean(b);
 				format=(x ? FORMAT_JSON : FORMAT_TEXT);
 			}else if(a.equals("ss") || a.equals("samstreamer") || a.equals("streamer")){
 				if(b!=null && Tools.isDigit(b.charAt(0))){
-					useStreamer=true;
-					streamerThreads=Tools.max(1, Integer.parseInt(b));
+					ZMWStreamer.useStreamer=true;
+					assert(Integer.parseInt(b)==1) : "ZMWStreamer threads currently capped at 1.";
+//					ZMWStreamer.streamerThreads=Tools.max(1, Integer.parseInt(b));
 				}else{
-					useStreamer=Tools.parseBoolean(b);
+					ZMWStreamer.useStreamer=Parse.parseBoolean(b);
 				}
 			}else if(a.equals("icecreamonly") || a.equals("ico")){
-				filterIceCreamOnly=Tools.parseBoolean(b);
+				filterIceCreamOnly=Parse.parseBoolean(b);
 			}else if(a.equals("keepshortreads") || a.equals("ksr")){
-				keepShortReads=Tools.parseBoolean(b);
+				keepShortReads=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("keepzmwstogether") || a.equals("kzt") || a.equals("keepreadstogether") || a.equals("krt")){
-				keepZMWsTogether=Tools.parseBoolean(b);
+				keepZMWsTogether=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("samplerate")){
 				float f=Float.parseFloat(b);
 				assert(false) : "TODO"; //TODO
 			}else if(a.equals("modifyheader") || a.equals("modifyheaders") || a.equals("changeheader") || a.equals("changeheaders")){
-				modifyHeader=Tools.parseBoolean(b);
-			}else if(a.equals("ccs")){
-				CCS=Tools.parseBoolean(b);
+				modifyHeader=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("ccs")){
+				CCS=Parse.parseBoolean(b);
 			}else if(a.equals("npad")){
 				npad=Integer.parseInt(b);
 			}else if(a.equals("minlength") || a.equals("minlen")){
 				minLengthAfterTrimming=Integer.parseInt(b);
 			}else if(a.equals("realign")){
-				realign=Tools.parseBoolean(b);
+				realign=Parse.parseBoolean(b);
 			}else if(a.equals("aligninverse") || a.equals("alignrc") || a.equals("findicecream")){
-				alignRC=Tools.parseBoolean(b);
+				alignRC=Parse.parseBoolean(b);
 			}else if(a.equals("alignadapter")){
-				alignAdapter=Tools.parseBoolean(b);
+				alignAdapter=Parse.parseBoolean(b);
 			}else if(a.equals("timeless")){
-				timeless=Tools.parseBoolean(b);
+				timeless=Parse.parseBoolean(b);
 			}else if(a.equals("flaglongreads")){
-				flagLongReads=Tools.parseBoolean(b);
+				flagLongReads=Parse.parseBoolean(b);
 			}else if(a.equals("trimreads") || a.equals("trim")){
-				trimReads=Tools.parseBoolean(b);
+				trimReads=Parse.parseBoolean(b);
 			}else if(a.equals("adapter")){
 				adapter=b==null ? null : b.getBytes();
 			}else if(a.equals("targetqlen") || a.equals("qlen")){
@@ -250,9 +245,9 @@ public final class IceCreamFinder {
 			}else if(a.equals("minscore")){
 				minScore=Integer.parseInt(b);
 			}else if(a.equals("parsecustom")){
-				parseCustom=Tools.parseBoolean(b);
+				parseCustom=Parse.parseBoolean(b);
 			}else if(a.equals("printtiming") || a.equals("extended")){
-				printTiming=Tools.parseBoolean(b);
+				printTiming=Parse.parseBoolean(b);
 			}else if(a.equals("queuelen") || a.equals("qlen")){
 				queuelen=Integer.parseInt(b);
 			}else if(a.equals("outg") || a.equals("outgood")){
@@ -282,12 +277,12 @@ public final class IceCreamFinder {
 				}
 				setAmbig=true;
 			}else if(a.equalsIgnoreCase("trimpolya")){//Parse standard flags in the parser
-				trimPolyA=Tools.parseBoolean(b);
+				trimPolyA=Parse.parseBoolean(b);
 			}else if(PolymerTrimmer.parse(arg, a, b)){
 				//do nothing
-			}else if(a.equals("minentropy") || a.equals("entropy") || a.equals("entropyfilter")){
+			}else if(a.equals("minentropy") || a.equals("entropy") || a.equals("entropyfilter") || a.equals("efilter")){
 				if(b==null || Character.isLetter(b.charAt(0))){
-					if(Tools.parseBoolean(b)){
+					if(Parse.parseBoolean(b)){
 						entropyCutoff=0.55f;
 					}else{
 						entropyCutoff=-1;
@@ -296,13 +291,13 @@ public final class IceCreamFinder {
 					entropyCutoff=Float.parseFloat(b);
 				}
 			}else if(a.equals("entropyblock") || a.equals("entropylength") || a.equals("entropylen") || a.equals("entlen")){
-				entropyLength=Tools.parseIntKMG(b);
+				entropyLength=Parse.parseIntKMG(b);
 			}else if(a.equals("entropyfraction") || a.equals("entfraction")){
 				entropyFraction=Float.parseFloat(b);
 			}else if(a.equals("monomerfraction") || a.equals("maxmonomerfraction") || a.equals("mmf")){
 				maxMonomerFraction=Float.parseFloat(b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
@@ -362,15 +357,7 @@ public final class IceCreamFinder {
 		Read.VALIDATE_IN_CONSTRUCTOR=Shared.threads()<4;
 		
 		//Create a read input stream
-		final ConcurrentReadInputStream cris;
-		final SamReadStreamer ss;
-		if(ffin1.samOrBam() && useStreamer){
-			cris=null;
-			ss=makeStreamer();
-		}else{
-			cris=makeCris();
-			ss=null;
-		}
+		ZMWStreamer zstream=new ZMWStreamer(ffin1, Shared.threads(), maxReads, -1);
 		
 		//Optionally create read output streams
 		final ConcurrentReadOutputStream rosg=makeCros(ffoutg);
@@ -384,14 +371,14 @@ public final class IceCreamFinder {
 		junctionsOut=0;
 		
 		//Process the reads in separate threads
-		spawnThreads(cris, ss, rosg, rosa, rosb, rosj);
+		spawnThreads(zstream, rosg, rosa, rosb, rosj);
 		
 		if(verbose){outstream.println("Finished; closing streams.");}
 		
 		//Write anything that was accumulated by ReadStats
 		errorState|=ReadStats.writeAll();
 		//Close the read streams
-		errorState|=ReadWrite.closeStreams(cris, rosg, rosa, rosb, rosj);
+		errorState|=ReadWrite.closeStreams(null, rosg, rosa, rosb, rosj);
 		
 		//Reset read validation
 		Read.VALIDATE_IN_CONSTRUCTOR=vic;
@@ -577,22 +564,6 @@ public final class IceCreamFinder {
 		bsw.poisonAndWait();
 	}
 	
-	private ConcurrentReadInputStream makeCris(){
-		ConcurrentReadInputStream cris=ConcurrentReadInputStream.getReadInputStream(maxReads, true, ffin1, null, null, null);
-		cris.start(); //Start the stream
-		if(verbose){outstream.println("Started cris");}
-		return cris;
-	}
-	
-	private SamReadStreamer makeStreamer(){
-		//Only 1 thread for now to force ordered input
-		streamerThreads=1; //Tools.max(1, Tools.min(streamerThreads, Shared.threads()/4));
-		SamReadStreamer ss=new SamReadStreamer(ffin1, streamerThreads, true, maxReads);
-		ss.start(); //Start the stream
-		if(verbose){outstream.println("Started sam streamer");}
-		return ss;
-	}
-	
 	private ConcurrentReadOutputStream makeCros(FileFormat ff){
 		if(ff==null){return null;}
 
@@ -605,7 +576,7 @@ public final class IceCreamFinder {
 	}
 	
 	/** Spawn process threads */
-	private void spawnThreads(final ConcurrentReadInputStream cris, SamReadStreamer ss,
+	private void spawnThreads(final ZMWStreamer zstream,
 			final ConcurrentReadOutputStream rosg, final ConcurrentReadOutputStream rosa,
 			final ConcurrentReadOutputStream rosb, final ConcurrentReadOutputStream rosj){
 		
@@ -614,7 +585,7 @@ public final class IceCreamFinder {
 		//Fill a list with ProcessThreads
 		ArrayList<ProcessThread> alpt=new ArrayList<ProcessThread>(threads);
 		for(int i=0; i<threads; i++){
-			alpt.add(new ProcessThread(rosg, rosa, rosb, rosj, i));
+			alpt.add(new ProcessThread(zstream, rosg, rosa, rosb, rosj, i));
 		}
 		
 		//Start the threads
@@ -622,128 +593,13 @@ public final class IceCreamFinder {
 			pt.start();
 		}
 		
-		if(cris!=null){
-			handleCris(cris);
-		}else{
-			handleStreamer(ss);
-		}
+		zstream.runStreamer(false);
 		
 		//Wait for threads to finish
 		waitForThreads(alpt);
 		
 		//Do anything necessary after processing
-		
-	}
-	
-	/** 
-	 * Pull reads from the cris;
-	 * organize them into lists of subreads from the same ZMW;
-	 * put those lists into the shared queue.
-	 */
-	private void handleCris(final ConcurrentReadInputStream cris){
-		//Grab the first ListNum of reads
-		ListNum<Read> ln=cris.nextList();
-
-		ArrayList<Read> buffer=new ArrayList<Read>();
-		long prevZmw=-1;
-		
-		long added=0;
-		
-		//As long as there is a nonempty read list...
-		while(ln!=null && ln.size()>0){
-
-			for(Read r : ln) {
-				long zmw;
-				try {
-					zmw=Tools.parseZmw(r.id);
-				} catch (Exception e) {
-					zmw=r.numericID;//For testing only; disable for production
-				}
-				if(zmw<0){zmw=r.numericID;}//For testing only; disable for production
-				if(verbose){System.err.println("Fetched read "+r.id+"; "+(zmw!=prevZmw)+", "+buffer.isEmpty()+", "+zmw+", "+prevZmw);}
-				if(zmw!=prevZmw && !buffer.isEmpty()){
-					ZMWs++;
-					addToQueue(buffer);
-					added+=buffer.size();
-					buffer=new ArrayList<Read>();
-				}
-				buffer.add(r);
-				prevZmw=zmw;
-			}
-			
-			cris.returnList(ln);
-			
-			//Fetch a new list
-			ln=cris.nextList();
-		}
-
-		if(!buffer.isEmpty()){
-			ZMWs++;
-			added+=buffer.size();
-			addToQueue(buffer);
-		}
-		
-		//Notify the input stream that the final list was used
-		if(ln!=null){
-			cris.returnList(ln.id, ln.list==null || ln.list.isEmpty());
-		}
-		
-		//Notify worker threads that there is no more data
-		for(int i=0; i<threads; i++){
-			addToQueue(poison);
-		}
-	}
-	
-	/** 
-	 * Pull reads from the streamer;
-	 * organize them into lists of subreads from the same ZMW;
-	 * put those lists into the shared queue.
-	 */
-	private void handleStreamer(final SamReadStreamer ss){
-		//Grab the first ListNum of reads
-		ListNum<Read> ln=ss.nextList();
-
-		ArrayList<Read> buffer=new ArrayList<Read>();
-		long prevZmw=-1;
-		
-		long added=0;
-		
-		//As long as there is a nonempty read list...
-		while(ln!=null && ln.size()>0){
-
-			for(Read r : ln) {
-				long zmw;
-				try {
-					zmw=Tools.parseZmw(r.id);
-				} catch (Exception e) {
-					zmw=r.numericID;//For testing only; disable for production
-				}
-				if(zmw<0){zmw=r.numericID;}//For testing only; disable for production
-				if(verbose){System.err.println("Fetched read "+r.id+"; "+(zmw!=prevZmw)+", "+buffer.isEmpty()+", "+zmw+", "+prevZmw);}
-				if(zmw!=prevZmw && !buffer.isEmpty()){
-					ZMWs++;
-					addToQueue(buffer);
-					added+=buffer.size();
-					buffer=new ArrayList<Read>();
-				}
-				buffer.add(r);
-				prevZmw=zmw;
-			}
-			
-			//Fetch a new list
-			ln=ss.nextList();
-		}
-
-		if(!buffer.isEmpty()){
-			ZMWs++;
-			added+=buffer.size();
-			addToQueue(buffer);
-		}
-		
-		//Notify worker threads that there is no more data
-		for(int i=0; i<threads; i++){
-			addToQueue(poison);
-		}
+		ZMWs=zstream.ZMWs;
 	}
 	
 	private void waitForThreads(ArrayList<ProcessThread> alpt){
@@ -817,43 +673,18 @@ public final class IceCreamFinder {
 	/*----------------         Inner Methods        ----------------*/
 	/*--------------------------------------------------------------*/
 	
-	private void addToQueue(ArrayList<Read> buffer){
-		if(verbose) {System.err.println("Adding to queue "+(buffer==poison ? "poison" : buffer.get(0).id));}
-		while(buffer!=null) {
-			try {
-				queue.put(buffer);
-				buffer=null;
-			} catch (InterruptedException e) {
-				// TODO Auto-generated catch block
-				e.printStackTrace();
-			}
-		}
-	}
-	
-	private ArrayList<Read> pullFromQueue(){
-		ArrayList<Read> buffer=null;
-		while(buffer==null) {
-			try {
-				buffer=queue.take();
-			} catch (InterruptedException e) {
-				// TODO Auto-generated catch block
-				e.printStackTrace();
-			}
-		}
-		if(verbose){System.err.println("Pulled from queue "+(buffer==poison ? "poison" : buffer.get(0).id));}
-		return buffer==poison ? null : buffer;
-	}
-	
 	/*--------------------------------------------------------------*/
 	/*----------------         Inner Classes        ----------------*/
 	/*--------------------------------------------------------------*/
 	
-	/** Proecesses reads. */
+	/** Processes reads. */
 	private class ProcessThread extends Thread {
 		
 		//Constructor
-		ProcessThread(final ConcurrentReadOutputStream ros_, final ConcurrentReadOutputStream rosa_, 
+		ProcessThread(final ZMWStreamer zstream_, 
+				final ConcurrentReadOutputStream ros_, final ConcurrentReadOutputStream rosa_, 
 				final ConcurrentReadOutputStream rosb_, final ConcurrentReadOutputStream rosj_, final int tid_){
+			zstream=zstream_;
 			rosg=ros_;
 			rosa=rosa_;
 			rosb=rosb_;
@@ -888,26 +719,14 @@ public final class IceCreamFinder {
 		void processInner(){
 
 			//As long as there is a nonempty read list...
-			for(ArrayList<Read> reads=pullFromQueue(); reads!=null; reads=pullFromQueue()){
+			for(ZMW reads=zstream.nextZMW(); reads!=null; reads=zstream.nextZMW()){
 //				if(verbose){outstream.println("Fetched "+reads.size()+" reads.");} //Disabled due to non-static access
 				
 				processList(reads);
 			}
 		}
 		
-		private int medianLength(ArrayList<Read> list){
-			if(list.size()<3){return -1;}
-			IntList lengths=new IntList(list.size()-2);
-			
-			for(int i=1; i<list.size()-1; i++){
-				lengths.add(list.get(i).length());
-			}
-			lengths.sort();
-			int median=lengths.get((lengths.size-1)/2);
-			return median;
-		}
-		
-		int flagLowEntropyReads(final ArrayList<Read> reads, final float minEnt, 
+		int flagLowEntropyReads(final ZMW reads, final float minEnt, 
 				final int minLen0, final float minFract){
 			int found=0;
 			for(Read r : reads){
@@ -925,7 +744,7 @@ public final class IceCreamFinder {
 			return found;
 		}
 		
-		int flagLongReads(final ArrayList<Read> reads, int median){
+		int flagLongReads(final ZMW reads, int median){
 			int found=0;
 			for(Read r : reads){
 				if(r.length()>longReadMult*median){
@@ -938,7 +757,7 @@ public final class IceCreamFinder {
 		}
 		
 		/** Each list is presumed to be all reads from a ZMW, in order */
-		void processList(final ArrayList<Read> reads){
+		void processList(final ZMW reads){
 			long numBases=0;
 			
 			//Loop through each read in the list for statistics
@@ -1014,7 +833,7 @@ public final class IceCreamFinder {
 
 			Read sample=null;//Read that will be searched for inverted repeat, typically median length
 			Read shortest=null;//shortest read in the middle, or overall if no middle reads
-			final int medianLength=medianLength(reads);
+			final int medianLength=reads.medianLength(true);
 			boolean foundInvertedRepeat=false;
 			int longReads=0;
 			int adapterReads=0;
@@ -1146,7 +965,7 @@ public final class IceCreamFinder {
 		
 		//TODO: Now that I think about it.  The order of the reads is important.
 		//Since they go forward-rev-forward-rev it's imprudent to discard inner reads.
-		private void removeShortTrash(ArrayList<Read> reads) {
+		private void removeShortTrash(ZMW reads) {
 			int removed=0;
 			for(int i=0; i<reads.size(); i++){
 				Read r=reads.get(i);
@@ -1158,53 +977,6 @@ public final class IceCreamFinder {
 			if(removed>0){Tools.condenseStrict(reads);}
 		}
 		
-		private void fixReadHeader(Read r, int leftTrim, int rightTrim){
-			leftTrim=Tools.max(0, leftTrim);
-			rightTrim=Tools.max(0, rightTrim);
-			if(leftTrim<1 && rightTrim<1){return;}
-			final int idx=r.id.lastIndexOf('/');
-			if(idx>0 && idx<r.id.length()-3){
-				String prefix=r.id.substring(0, idx+1);
-				String suffix=r.id.substring(idx+1);
-				if(suffix.indexOf('_')>0){
-					String coords=suffix, comment="";
-					int tab=suffix.indexOf('\t');
-					if(tab<0){tab=suffix.indexOf(' ');}
-					if(tab>0){
-						coords=coords.substring(0, tab);
-						comment=coords.substring(tab);
-					}
-					String[] split=Tools.underscorePattern.split(coords);
-					int left=Integer.parseInt(split[0]);
-					int right=Integer.parseInt(split[1]);
-					left+=leftTrim;
-					right-=rightTrim;
-					if(left>right){left=right;}
-					
-					if(right-left!=r.length()){right=left+r.length();}
-//					System.err.println(r.length()+", "+(right-left));
-					
-					r.id=prefix+left+"_"+right+comment;
-					final SamLine sl=r.samline;
-					if(sl!=null){
-						sl.qname=r.id;
-						if(sl.optional!=null){
-							for(int i=0; i<sl.optional.size(); i++){
-								String s=sl.optional.get(i);
-								if(s.startsWith("qe:i:")){
-									s="qe:i:"+right;
-									sl.optional.set(i, s);
-								}else if(s.startsWith("qs:i:")){
-									s="qs:i:"+left;
-									sl.optional.set(i, s);
-								}
-							}
-						}
-					}
-				}
-			}
-		}
-		
 		int trimRead(Read r, int lookahead){
 			final byte[] bases=r.bases;
 			
@@ -1216,7 +988,7 @@ public final class IceCreamFinder {
 //				System.err.println(r.length()+", "+left+", "+right+", "+r.id);
 				trimmed=TrimRead.trimByAmount(r, left, right, 1, false);
 //				System.err.println(r.length()+", "+left+", "+right+", "+r.id);
-				fixReadHeader(r, left, right);
+				ZMW.fixReadHeader(r, left, right);
 //				System.err.println(r.length()+", "+left+", "+right+", "+r.id);
 			}
 			
@@ -1238,7 +1010,7 @@ public final class IceCreamFinder {
 //				System.err.println(r.length()+", "+left+", "+right+", "+r.id);
 				trimmed=TrimRead.trimByAmount(r, left, right, 1, false);
 //				System.err.println(r.length()+", "+left+", "+right+", "+r.id);
-				fixReadHeader(r, left, right);
+				ZMW.fixReadHeader(r, left, right);
 //				System.err.println(r.length()+", "+left+", "+right+", "+r.id);
 			}
 			
@@ -1317,7 +1089,7 @@ public final class IceCreamFinder {
 			return aa!=null;
 		}
 		
-		private void outputReads(ArrayList<Read> reads, ArrayList<Read> junctions){
+		private void outputReads(ZMW reads, ArrayList<Read> junctions){
 			final int size=reads.size();
 			final ArrayList<Read> good=(rosg==null ? null : new ArrayList<Read>(size));
 			final ArrayList<Read> ambig=(rosa==null ? null : new ArrayList<Read>(size));
@@ -1820,6 +1592,7 @@ public final class IceCreamFinder {
 		/** Alternate scoring for slow adapter alignment */
 		final MultiStateAligner9PacBioAdapter2 msa2=(alignAdapter || trimReads) ? new MultiStateAligner9PacBioAdapter2() : null;
 
+		final ZMWStreamer zstream;
 		final EntropyTracker eTracker;
 		
 		final long[] adapterScoresT=new long[201];
@@ -1951,11 +1724,6 @@ public final class IceCreamFinder {
 	
 	/** Quit after processing this many input reads; -1 means no limit */
 	private long maxReads=-1;
-	
-	//Streamer seems to give more highly variable timings... sometimes.  And it's not really needed.
-	private boolean useStreamer=false;//Shared.threads()>64;
-
-	private int streamerThreads=1;
 
 	//Unused
 	protected long iceCreamReads=0;
@@ -2072,8 +1840,6 @@ public final class IceCreamFinder {
 	private final FileFormat ffirsrhist;
 	
 	private final int threads;
-	private final ArrayBlockingQueue<ArrayList<Read>> queue;
-	private final ArrayList<Read> poison=new ArrayList<Read>(0);
 	
 	/*--------------------------------------------------------------*/
 	/*----------------        Common Fields         ----------------*/
