@@ -4,6 +4,7 @@ import java.io.File;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Locale;
+
 import align2.QualityTools;
 import dna.AminoAcid;
 import fileIO.ByteFile;
@@ -11,6 +12,7 @@ import fileIO.ByteFile1;
 import fileIO.ByteFile2;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -59,6 +61,7 @@ public class AddAdapters {
 		Shared.capBuffers(4);
 		ReadWrite.USE_PIGZ=ReadWrite.USE_UNPIGZ=true;
 		ReadWrite.MAX_ZIP_THREADS=Shared.threads();
+		FASTQ.PARSE_CUSTOM=true;
 		
 		
 		for(int i=0; i<args.length; i++){
@@ -78,7 +81,7 @@ public class AddAdapters {
 			}else if(parser.parseInterleaved(arg, a, b)){
 				//do nothing
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -86,7 +89,7 @@ public class AddAdapters {
 				stream.FastqReadInputStream.verbose=verbose;
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("reads") || a.equals("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.equals("t") || a.equals("threads")){
 				Shared.setThreads(b);
 			}else if(a.equals("in") || a.equals("input") || a.equals("in1") || a.equals("input1")){
@@ -110,9 +113,9 @@ public class AddAdapters {
 			}else if(a.equals("minlength") || a.equals("minlen") || a.equals("ml")){
 				minlen=Integer.parseInt(b);
 			}else if(a.equals("3'") || a.equalsIgnoreCase("3prime") || a.equalsIgnoreCase("3-prime") || a.equalsIgnoreCase("right") || a.equalsIgnoreCase("r")){
-				right=Tools.parseBoolean(b);
+				right=Parse.parseBoolean(b);
 			}else if(a.equals("5'") || a.equalsIgnoreCase("5prime") || a.equalsIgnoreCase("5-prime") || a.equalsIgnoreCase("left") || a.equalsIgnoreCase("l")){
-				right=!Tools.parseBoolean(b);
+				right=!Parse.parseBoolean(b);
 			}else if(a.equals("end")){
 				assert(b!=null) : "Bad parameter: "+arg;
 				if(b.equals("3'") || b.equalsIgnoreCase("3prime") || b.equalsIgnoreCase("3-prime") || b.equalsIgnoreCase("right") || a.equalsIgnoreCase("r")){
@@ -121,21 +124,21 @@ public class AddAdapters {
 					right=true;
 				}
 			}else if(a.equals("addslash")){
-				addslash=Tools.parseBoolean(b);
+				addslash=Parse.parseBoolean(b);
 			}else if(a.equals("adderrors")){
-				adderrors=Tools.parseBoolean(b);
+				adderrors=Parse.parseBoolean(b);
 			}else if(a.equals("addreversecomplement") || a.equals("arc")){
-				addRC=Tools.parseBoolean(b);
+				addRC=Parse.parseBoolean(b);
 			}else if(a.equals("addpaired")){
-				addPaired=Tools.parseBoolean(b);
+				addPaired=Parse.parseBoolean(b);
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("write")){
-				writeMode=Tools.parseBoolean(b);
+				writeMode=Parse.parseBoolean(b);
 			}else if(a.equals("grade")){
-				writeMode=!Tools.parseBoolean(b);
+				writeMode=!Parse.parseBoolean(b);
 			}else if(a.equals("mode")){
 				if("grade".equalsIgnoreCase(b) || "read".equalsIgnoreCase(b)){
 					writeMode=false;
@@ -538,41 +541,52 @@ public class AddAdapters {
 		}
 	}
 	
+//	private void grade_old(Read r1, Read r2){
+//		
+//		final String a=r1.id.split(" ")[0];
+//		final String b=(r2==null ? a : r2.id.split(" ")[0]);
+//		final int len=a.split("_").length;
+//		
+//		if(r2!=null){
+//			if(r1.id.endsWith(" /2") || r2.id.endsWith(" /1") || !a.equals(b)){
+//				mispaired+=2;
+//			}
+//			if(len==3){
+//				r2.setPairnum(0);
+//			}else if(len==5){
+//				if(r1.id.endsWith(" /2")){r1.setPairnum(1);}
+//				if(r2.id.endsWith(" /1")){r2.setPairnum(0);}
+//			}else{
+//				throw new RuntimeException("Headers are corrupt. They must be generated by AddAdapters or RenameReads.");
+//			}
+//		}else{
+//			if(len!=3){
+//				throw new RuntimeException("Headers are corrupt, or paired reads are being processed as unpaired.  Try running with 'int=t' or with 'in1=' and 'in2='");
+//			}
+//		}
+//		grade(r1);
+//		grade(r2);
+//	}
+	
 	private void grade(Read r1, Read r2){
-		final String a=r1.id.split(" ")[0];
-		final String b=(r2==null ? a : r2.id.split(" ")[0]);
-		final int len=a.split("_").length;
-		
-		if(r2!=null){
-			if(r1.id.endsWith(" /2") || r2.id.endsWith(" /1") || !a.equals(b)){
-				mispaired+=2;
-			}
-			if(len==3){
-				r2.setPairnum(0);
-			}else if(len==5){
-				if(r1.id.endsWith(" /2")){r1.setPairnum(1);}
-				if(r2.id.endsWith(" /1")){r2.setPairnum(0);}
-			}else{
-				throw new RuntimeException("Headers are corrupt. They must be generated by AddAdapters or RenameReads.");
-			}
-		}else{
-			if(len!=3){
-				throw new RuntimeException("Headers are corrupt, or paired reads are being processed as unpaired.  Try running with 'int=t' or with 'in1=' and 'in2='");
-			}
-		}
 		grade(r1);
 		grade(r2);
 	}
 	
 	private void grade(Read r){
 		if(r==null){return;}
+		
+		int insert=r.insert();
+		int originalLength=r.stop-r.start+1;
+		int length=r.length();
+		
 		final int offset=(2*r.pairnum());
 		
-		String[] sa=r.id.split(" ")[0].split("_");
-		final long id=Long.parseLong(sa[0]);
-		final int initial=Integer.parseInt(sa[1+offset]);
-		final int remaining=Integer.parseInt(sa[2+offset]);
-		final int actual=r.length();
+//		String[] sa=r.id.split(" ")[0].split("_");
+//		final long id=Long.parseLong(sa[0]);
+		final int initial=originalLength;
+		final int remaining=Tools.min(initial, insert);
+		final int actual=length;
 		
 		readsProcessed++;
 		basesProcessed+=actual;
@@ -583,6 +597,9 @@ public class AddAdapters {
 		
 		validBasesExpected+=remaining;
 		
+
+//		System.err.println("initial="+initial+", remaining="+remaining+", actual="+actual);
+		
 		if(initial==remaining){//Should not have trimmed
 			if(actual==remaining || (actual<2 && (remaining<1 || remaining<minlen))){
 				correct++;
