@@ -14,7 +14,9 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextStreamWriter;
 import json.JsonObject;
+import shared.KillSwitch;
 import shared.MetadataWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -102,7 +104,7 @@ public final class AssemblyStats2 {
 						gc=null;
 					}
 				}else if(a.equals("benchmark")){
-					benchmark=Tools.parseBoolean(b);
+					benchmark=Parse.parseBoolean(b);
 					if(benchmark){
 						out=null;
 						gc=null;
@@ -114,7 +116,7 @@ public final class AssemblyStats2 {
 						throw new RuntimeException("\nUnknown format: "+FORMAT+"; valid values are 1 through 8.\n");
 					}
 				}else if(a.equals("json")){
-					if(Tools.parseBoolean(b)){FORMAT=8;}
+					if(Parse.parseBoolean(b)){FORMAT=8;}
 					else{FORMAT=1;}
 				}else if(a.equals("gcformat")){
 					GCFORMAT=Integer.parseInt(b);
@@ -122,33 +124,33 @@ public final class AssemblyStats2 {
 						throw new RuntimeException("\nUnknown gcformat: "+GCFORMAT+"; valid values are 0 through 5.\n");
 					}
 				}else if(a.equals("cutoff")){
-					cutoff=Tools.parseKMG(b);
+					cutoff=Parse.parseKMG(b);
 				}else if(a.equals("k") || a.equals("bbmapkmer")){
 					bbmapkmer=Integer.parseInt(b);
 				}else if(a.equals("printl90") || a.equals("l90") || a.equals("printn90") || a.equals("n90")){
-					printL90=Tools.parseBoolean(b);
+					printL90=Parse.parseBoolean(b);
 				}else if(a.equals("printextended") || a.equals("extended")){
-					printExtended=Tools.parseBoolean(b);
+					printExtended=Parse.parseBoolean(b);
 				}else if(a.equals("overwrite") || a.equals("ow")){
-					overwrite=Tools.parseBoolean(b);
+					overwrite=Parse.parseBoolean(b);
 				}else if(a.equals("n_")){
-					N_UNDERSCORE=Tools.parseBoolean(b);
+					N_UNDERSCORE=Parse.parseBoolean(b);
 				}else if(a.equals("header") || a.equals("useheader")){
-					useheader=Tools.parseBoolean(b);
+					useheader=Parse.parseBoolean(b);
 				}else if(a.equals("addfilename") || a.equals("addname")){
-					addfilename=Tools.parseBoolean(b);
+					addfilename=Parse.parseBoolean(b);
 				}else if(a.equals("minscaf") || a.equals("mincontig") || a.equals("minlen") || a.equals("min")){
-					MINSCAF_=Tools.parseIntKMG(b);
+					MINSCAF_=Parse.parseIntKMG(b);
 				}else if(a.equals("showspeed") || a.equals("ss")){
-					showspeed=Tools.parseBoolean(b);
+					showspeed=Parse.parseBoolean(b);
 				}else if(a.equals("printheadersize") || a.equals("phs")){
-					printheadersize=Tools.parseBoolean(b);
+					printheadersize=Parse.parseBoolean(b);
 				}else if(a.equals("skipduplicatelines") || a.equals("sdl")){
-					skipDuplicateLines=Tools.parseBoolean(b);
+					skipDuplicateLines=Parse.parseBoolean(b);
 				}else if(a.equals("printduplicatelines") || a.equals("pdl")){
-					skipDuplicateLines=!Tools.parseBoolean(b);
+					skipDuplicateLines=!Parse.parseBoolean(b);
 				}else if(a.equals("showbbmap")){
-					if(!Tools.parseBoolean(b)){bbmapkmer=0;}
+					if(!Parse.parseBoolean(b)){bbmapkmer=0;}
 				}else if(a.equals("contigbreak") || (arg.contains("=") && (a.equals("n")))){
 					maxNs=Integer.parseInt(b);
 				}
@@ -158,7 +160,7 @@ public final class AssemblyStats2 {
 				}else if(a.equals("logsumbase") || a.equals("logbase")){
 					logSumBase=Double.parseDouble(b);
 				}else if(a.equals("squarelog") || a.equals("logsquare") || a.equals("logsquared")){
-					squareLog=Tools.parseBoolean(b);
+					squareLog=Parse.parseBoolean(b);
 				}else if(a.equals("logpower")){
 					logPower=Double.parseDouble(b);
 				}else if(a.equals("powsum") || a.equals("powersum") || a.equals("powersumpower") || a.equals("powsumpower")){
@@ -166,14 +168,14 @@ public final class AssemblyStats2 {
 				}
 				
 				else if(a.equalsIgnoreCase("assemblyScoreMinLen")){
-					assemblyScoreMinLen=Tools.parseKMG(b);
+					assemblyScoreMinLen=Parse.parseKMG(b);
 				}else if(a.equalsIgnoreCase("assemblyScoreMaxLen")){
-					assemblyScoreMaxLen=Tools.parseKMG(b);
+					assemblyScoreMaxLen=Parse.parseKMG(b);
 				}else if(a.equalsIgnoreCase("alignedFraction") || a.equalsIgnoreCase("aligned") || a.equalsIgnoreCase("mapped")){
 					alignedFraction=Double.parseDouble(b);
 					if(alignedFraction>1){alignedFraction/=100;}
 				}else if(a.equals("score") || a.equals("assemblyscore")){
-					printAssemblyScore=Tools.parseBoolean(b);
+					printAssemblyScore=Parse.parseBoolean(b);
 				}
 				
 				else if(i>0 && (a.equals("n") || a.equals("-n")) && b!=null){
@@ -326,8 +328,8 @@ public final class AssemblyStats2 {
 			}
 		}
 //		assert(false) : GCFORMAT+", "+out+", "+tswgc;
-		final long[] counts=new long[8];
-		final long[] overall=new long[8];
+		final long[] counts=KillSwitch.allocLong1D(8);
+		final long[] overall=KillSwitch.allocLong1D(8);
 		final StringBuilder hdr=(gcout==null ? null : new StringBuilder());
 		boolean hdmode=false;
 		
@@ -618,8 +620,8 @@ public final class AssemblyStats2 {
 			}
 		}
 //		assert(false) : GCFORMAT+", "+out+", "+tswgc;
-		final long[] counts=new long[8];
-		final long[] overall=new long[8];
+		final long[] counts=KillSwitch.allocLong1D(8);
+		final long[] overall=KillSwitch.allocLong1D(8);
 		final StringBuilder hdr=(gcout==null ? null : new StringBuilder());
 		int line=0;
 		
