@@ -7,6 +7,7 @@ import assemble.Tadpole;
 import assemble.Tadpole1;
 import assemble.Tadpole2;
 import dna.AminoAcid;
+import shared.KillSwitch;
 import shared.Shared;
 import shared.Tools;
 import stream.Read;
@@ -39,7 +40,7 @@ public final class BBMergeOverlapper {
 	
 	protected static final int mateByOverlap(Read a, Read b, float[] aprob, float[] bprob, int[] rvector,
 			int minOverlap0, final int minOverlap, final int minInsert0, int margin, final int maxMismatches0, final int maxMismatches, final int minq) {
-		if(rvector==null){rvector=new int[5];}
+		if(rvector==null){rvector=KillSwitch.allocInt1D(5);}
 		final int x;
 		if(false && Shared.USE_JNI){//TODO: Disabled!
 			x=mateByOverlapJNI(a.bases, b.bases, a.quality, b.quality, aprob, bprob, rvector, minOverlap0, minOverlap, minInsert0, margin, maxMismatches0, maxMismatches, minq);
@@ -52,7 +53,7 @@ public final class BBMergeOverlapper {
 	protected static final int mateByOverlapRatio(Read a, Read b, float[] aprob, float[] bprob, int[] rvector,
 			int minOverlap0, int minOverlap, int minInsert0, int minInsert, final float maxRatio, final float minSecondRatio,
 			final float margin, final float offset, final float gIncr, final float bIncr, boolean useQuality) {
-		if(rvector==null){rvector=new int[5];}
+		if(rvector==null){rvector=KillSwitch.allocInt1D(5);}
 //		final boolean swapped;
 //		if(a.length()>b.length()){
 //			swapped=true;
@@ -93,7 +94,7 @@ public final class BBMergeOverlapper {
 		assert(margin>=1);
 		minOverlap=Tools.max(4, minOverlap0, minOverlap);
 		minOverlap0=Tools.mid(4, minOverlap0, minOverlap);
-		if(rvector==null){rvector=new int[5];}
+		if(rvector==null){rvector=KillSwitch.allocInt1D(5);}
 		
 		final byte[] abases=a.bases, bbases=b.bases, aqual=a.quality, bqual=b.quality;
 		final int alen=abases.length, blen=bbases.length;
@@ -258,7 +259,7 @@ public final class BBMergeOverlapper {
 		assert(margin>=1);
 		minOverlap=Tools.max(4, minOverlap0, minOverlap);
 		minOverlap0=Tools.mid(4, minOverlap0, minOverlap);
-		if(rvector==null){rvector=new int[5];}
+		if(rvector==null){rvector=KillSwitch.allocInt1D(5);}
 		
 		final byte[] abases=a.bases, bbases=b.bases;
 		final int alen=abases.length, blen=bbases.length;
