@@ -11,6 +11,7 @@ import dna.Data;
 import fileIO.ByteFile1;
 import fileIO.ReadWrite;
 import fileIO.TextStreamWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -81,7 +82,7 @@ public class BBQC {
 			}else if(Parser.parseCommonStatic(arg, a, b)){
 				//do nothing
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
 				primaryArgList.add(arg);
@@ -121,7 +122,7 @@ public class BBQC {
 			}else if(a.equals("phixref")){
 				phixRef=b;
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("ml") || a.equals("minlen") || a.equals("minlength")){
 				minLen=Integer.parseInt(b);
 			}else if(a.equals("mlf") || a.equals("minlenfrac") || a.equals("minlenfraction") || a.equals("minlengthfraction")){
@@ -141,15 +142,15 @@ public class BBQC {
 			}else if(a.equals("filelist")){
 				fileListName=b;
 			}else if(a.equals("compress")){
-				compress=Tools.parseBoolean(b);
+				compress=Parse.parseBoolean(b);
 			}else if(a.equals("rna")){
-				rnaFlag=Tools.parseBoolean(b);
+				rnaFlag=Parse.parseBoolean(b);
 			}else if(a.equals("phix")){
-				phixFlag=Tools.parseBoolean(b);
+				phixFlag=Parse.parseBoolean(b);
 			}else if(a.equals("lambda")){
-				lambdaFlag=Tools.parseBoolean(b);
+				lambdaFlag=Parse.parseBoolean(b);
 			}else if(a.equals("pjet")){
-				pjetFlag=Tools.parseBoolean(b);
+				pjetFlag=Parse.parseBoolean(b);
 			}else if(a.equals("ktrim")){
 				ktrim=b;
 			}else if(a.equals("mink")){
@@ -186,27 +187,27 @@ public class BBQC {
 			}else if(a.equals("trimq")){
 				trimq=Byte.parseByte(b);
 			}else if(a.equals("human") || a.equals("removehuman")){
-				removehuman=Tools.parseBoolean(b);
+				removehuman=Parse.parseBoolean(b);
 			}else if(a.equals("normalize") || a.equals("norm")){
-				normalize=Tools.parseBoolean(b);
+				normalize=Parse.parseBoolean(b);
 			}else if(a.equals("ecc")){
-				ecc=Tools.parseBoolean(b);
+				ecc=Parse.parseBoolean(b);
 			}else if(a.equals("aec") || a.equals("aecc")){
-				aecc=Tools.parseBoolean(b);
+				aecc=Parse.parseBoolean(b);
 				if(aecc){ecc=true;}
 			}else if(a.equals("cecc")){
-				cecc=Tools.parseBoolean(b);
+				cecc=Parse.parseBoolean(b);
 				if(cecc){ecc=true;}
 			}else if(a.equals("markerrorsonly") || a.equals("meo")){
-				meo=Tools.parseBoolean(b);
+				meo=Parse.parseBoolean(b);
 			}else if(a.equals("tam")){
-				tam=Tools.parseBoolean(b);
+				tam=Parse.parseBoolean(b);
 			}else if(a.equals("taf")){
-				trimAfterFiltering=Tools.parseBoolean(b);
+				trimAfterFiltering=Parse.parseBoolean(b);
 			}else if(a.equals("mue")){
-				mue=Tools.parseBoolean(b);
+				mue=Parse.parseBoolean(b);
 			}else if(a.equals("mw1")){
-				mw1=Tools.parseBoolean(b);
+				mw1=Parse.parseBoolean(b);
 			}else if(a.equals("max") || a.equals("maxdepth")){
 				maxdepth=Integer.parseInt(b);
 			}else if(a.equals("min") || a.equals("mindepth")){
@@ -230,15 +231,15 @@ public class BBQC {
 			}else if(a.equals("hits") || a.equals("minhits")){
 				minhits=Integer.parseInt(b);
 			}else if(a.equals("fast")){
-				fast=Tools.parseBoolean(b);
+				fast=Parse.parseBoolean(b);
 			}else if(a.equals("local")){
-				local=Tools.parseBoolean(b);
+				local=Parse.parseBoolean(b);
 			}else if(a.equals("mappath") || a.equals("indexpath")){
 				indexPath=b;
 			}else if(a.equals("mapref")){
 				mapRef=b;
 			}else if(a.equals("copyundefined") || a.equals("cu")){
-				copyUndefined=Tools.parseBoolean(b);
+				copyUndefined=Parse.parseBoolean(b);
 			}else if(a.equals("qtrim")){
 				if(b==null){qtrim="rl";}
 				else if(b.equalsIgnoreCase("left") || b.equalsIgnoreCase("l")){qtrim="l";}
@@ -247,14 +248,14 @@ public class BBQC {
 				else if(Tools.isDigit(b.charAt(0))){
 					trimq=Byte.parseByte(b);
 					qtrim=(trimq>=0 ? "lr" : "f");
-				}else{qtrim=""+Tools.parseBoolean(b);}
+				}else{qtrim=""+Parse.parseBoolean(b);}
 			}else if(a.equals("optitrim") || a.equals("otf") || a.equals("otm")){
 				if(b!=null && (b.charAt(0)=='.' || Tools.isDigit(b.charAt(0)))){
 					TrimRead.optimalMode=true;
 					TrimRead.optimalBias=Float.parseFloat(b);
 					assert(TrimRead.optimalBias>=0 && TrimRead.optimalBias<1);
 				}else{
-					TrimRead.optimalMode=Tools.parseBoolean(b);
+					TrimRead.optimalMode=Parse.parseBoolean(b);
 				}
 			}else if(a.equals("maxns")){
 				maxNs=Integer.parseInt(b);
