@@ -12,6 +12,7 @@ import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -58,11 +59,11 @@ public class CallPeaks {
 			if(Parser.parseZip(arg, a, b)){
 				//do nothing
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				ReadWrite.verbose=verbose;
@@ -79,13 +80,13 @@ public class CallPeaks {
 			}else if(a.equals("minpeak") || a.equals("minp")){
 				minPeak=Integer.parseInt(b);
 			}else if(a.equals("maxpeak") || a.equals("maxp")){
-				maxPeak=(int)Tools.min(Integer.MAX_VALUE, Tools.parseKMG(b));
+				maxPeak=(int)Tools.min(Integer.MAX_VALUE, Parse.parseKMG(b));
 			}else if(a.equals("maxpeakcount") || a.equals("maxpc") || a.equals("maxpeaks")){
 				maxPeakCount=Integer.parseInt(b);
 			}else if(a.equals("smoothradius")){
 				smoothRadius=Integer.parseInt(b);
 			}else if(a.equals("smoothprogressive")){
-				smoothProgressiveFlag=Tools.parseBoolean(b);
+				smoothProgressiveFlag=Parse.parseBoolean(b);
 			}else if(a.equals("maxradius")){
 				maxRadius=Integer.parseInt(b);
 			}else if(a.equals("progressivemult")){
@@ -97,7 +98,7 @@ public class CallPeaks {
 			}else if(a.equals("k")){
 				k=Integer.parseInt(b);
 			}else if(a.equals("logscale")){
-				logScale=Tools.parseBoolean(b);
+				logScale=Parse.parseBoolean(b);
 			}else if(a.equals("logwidth")){
 				logWidth=Double.parseDouble(b);
 			}else if(a.equals("logpasses")){
@@ -109,7 +110,7 @@ public class CallPeaks {
 			}else if(a.equals("byvolume")){
 				CALL_MODE=BY_VOLUME;
 			}else if(a.equalsIgnoreCase("weightByRelief")){
-				weightByRelief=Tools.parseBoolean(b);
+				weightByRelief=Parse.parseBoolean(b);
 			}
 			
 			else if(in==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
