@@ -19,6 +19,7 @@ import fileIO.ReadWrite;
 import fileIO.TextFile;
 import fileIO.TextStreamWriter;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -92,9 +93,9 @@ public class CoveragePileup {
 			if(a.equals("ref") || a.equals("reference") || a.equals("fasta")){
 				reference=b;
 			}else if(a.equals("addfromref")){
-				ADD_FROM_REF=Tools.parseBoolean(b);
+				ADD_FROM_REF=Parse.parseBoolean(b);
 			}else if(a.equals("addfromreads")){
-				ADD_FROM_READS=Tools.parseBoolean(b);
+				ADD_FROM_READS=Parse.parseBoolean(b);
 			}else if(a.equals("in") || a.equals("in1")){
 				in1=b;
 			}else if(a.equals("in2")){
@@ -116,7 +117,7 @@ public class CoveragePileup {
 				else if(Tools.isDigit(b.charAt(0))){
 					trimq=Float.parseFloat(b);
 					qtrimRight=trimq>0;
-				}else{qtrimRight=qtrimLeft=Tools.parseBoolean(b);}
+				}else{qtrimRight=qtrimLeft=Parse.parseBoolean(b);}
 			}else if(a.equals("trimq") || a.equals("trimquality")){
 				trimq=Float.parseFloat(b);
 			}else if(a.equals("ss") || a.equals("samstreamer")){
@@ -124,7 +125,7 @@ public class CoveragePileup {
 					useStreamer=true;
 					streamerThreads=Tools.max(1, Integer.parseInt(b));
 				}else{
-					useStreamer=Tools.parseBoolean(b);
+					useStreamer=Parse.parseBoolean(b);
 				}
 			}else if(a.equals("minq") || a.equals("minmapq")){
 				minMapq=Integer.parseInt(b);
@@ -145,89 +146,89 @@ public class CoveragePileup {
 			}else if(a.equals("normcovo") || a.equals("outnormalizedoverall")){
 				normcovOverall=b;
 			}else if(a.equals("delta")){
-				DELTA_ONLY=Tools.parseBoolean(b);
+				DELTA_ONLY=Parse.parseBoolean(b);
 			}else if(a.equals("physical") || a.equals("physicalcoverage") || a.equals("physcov")){
-				PHYSICAL_COVERAGE=Tools.parseBoolean(b);
+				PHYSICAL_COVERAGE=Parse.parseBoolean(b);
 			}else if(a.equals("tlen")){
-				USE_TLEN=Tools.parseBoolean(b);
+				USE_TLEN=Parse.parseBoolean(b);
 			}else if(a.equals("hist") || a.equals("histogram") || a.equals("covhist")){
 				histogram=b;
 			}else if(a.equals("reads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.equals("scafs") || a.equals("scaffolds")){
 				initialScaffolds=Tools.max(128, (int)(Tools.min(Long.parseLong(b),2000000000)));
 			}else if(a.equals("binsize")){
 				binsize=Integer.parseInt(b);
 			}else if(a.equals("32bit")){
-				bits32=Tools.parseBoolean(b);
+				bits32=Parse.parseBoolean(b);
 			}else if(a.equals("bitset") || a.equals("usebitset") || a.equals("bitsets") || a.equals("usebitsets")){
-//				if(Tools.parseBoolean(b)){arrayMode=BITSET_MODE;}
-				vectorMode=Tools.parseBoolean(b) ? BITSET_MODE : NOTHING_MODE;
+//				if(Parse.parseBoolean(b)){arrayMode=BITSET_MODE;}
+				vectorMode=Parse.parseBoolean(b) ? BITSET_MODE : NOTHING_MODE;
 			}else if(a.equals("array") || a.equals("arrays") || a.equals("usearrays")){
-				vectorMode=Tools.parseBoolean(b) ? ARRAY_MODE : NOTHING_MODE;
+				vectorMode=Parse.parseBoolean(b) ? ARRAY_MODE : NOTHING_MODE;
 			}else if(a.equals("median") || a.equals("calcmedian")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					vectorMode=ARRAY_MODE;
 				}
 			}else if(a.startsWith("nonzero") || a.equals("nzo")){
-				NONZERO_ONLY=Tools.parseBoolean(b);
+				NONZERO_ONLY=Parse.parseBoolean(b);
 				if(verbose){outstream.println("Set NONZERO_ONLY to "+NONZERO_ONLY);}
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 				if(verbose){outstream.println("Set overwrite to "+overwrite);}
 			}else if(a.equalsIgnoreCase("twocolumn")){
-				TWOCOLUMN=Tools.parseBoolean(b);
+				TWOCOLUMN=Parse.parseBoolean(b);
 				if(verbose){outstream.println("Set TWOCOLUMN to "+TWOCOLUMN);}
 			}else if(a.equalsIgnoreCase("keyvalue") || a.equalsIgnoreCase("machineout")){
-				KEY_VALUE=Tools.parseBoolean(b);
+				KEY_VALUE=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("countgc")){
-				COUNT_GC=Tools.parseBoolean(b);
+				COUNT_GC=Parse.parseBoolean(b);
 				if(verbose){outstream.println("Set COUNT_GC to "+COUNT_GC);}
 			}else if(a.equals("secondary") || a.equals("usesecondary")){
-				USE_SECONDARY=Tools.parseBoolean(b);
+				USE_SECONDARY=Parse.parseBoolean(b);
 				if(verbose){outstream.println("Set USE_SECONDARY_ALIGNMENTS to "+USE_SECONDARY);}
 			}else if(a.equals("softclip") || a.equals("includesoftclip")){
-				INCLUDE_SOFT_CLIP=Tools.parseBoolean(b);
+				INCLUDE_SOFT_CLIP=Parse.parseBoolean(b);
 				if(verbose){outstream.println("Set INCLUDE_SOFT_CLIP to "+INCLUDE_SOFT_CLIP);}
 			}else if(a.equals("keepshortbins") || a.equals("ksb")){
-				KEEP_SHORT_BINS=Tools.parseBoolean(b);
+				KEEP_SHORT_BINS=Parse.parseBoolean(b);
 				if(verbose){outstream.println("Set KEEP_SHORT_BINS to "+KEEP_SHORT_BINS);}
 			}else if(a.equals("strandedcoverage") || a.equals("strandedcov") || a.equals("covstranded") || a.equals("stranded")){
-				STRANDED=Tools.parseBoolean(b);
+				STRANDED=Parse.parseBoolean(b);
 			}else if(a.equals("startcov") || a.equals("covstart") || a.equals("startonly")){
-				START_ONLY=Tools.parseBoolean(b);
+				START_ONLY=Parse.parseBoolean(b);
 			}else if(a.equals("stopcov") || a.equals("covstop") || a.equals("stoponly")){
-				STOP_ONLY=Tools.parseBoolean(b);
+				STOP_ONLY=Parse.parseBoolean(b);
 			}else if(a.equals("concise")){
-				CONCISE=Tools.parseBoolean(b);
+				CONCISE=Parse.parseBoolean(b);
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("normc") || a.equals("normalizecoverage")){
-				NORMALIZE_COVERAGE=Tools.parseBoolean(b);
+				NORMALIZE_COVERAGE=Parse.parseBoolean(b);
 			}else if(a.equals("header") || a.equals("hdr")){
-				printHeader=Tools.parseBoolean(b);
+				printHeader=Parse.parseBoolean(b);
 			}else if(a.equals("headerpound") || a.equals("#")){
-				headerPound=Tools.parseBoolean(b);
+				headerPound=Parse.parseBoolean(b);
 			}else if(a.equals("stdev")){
-				calcCovStdev=Tools.parseBoolean(b);
+				calcCovStdev=Parse.parseBoolean(b);
 			}else if(a.equals("delcov") || a.equals("dels") || a.equals("includedels") || a.equals("includedeletions") || a.equals("delcoverage")){
-				INCLUDE_DELETIONS=Tools.parseBoolean(b);
+				INCLUDE_DELETIONS=Parse.parseBoolean(b);
 			}else if(a.equals("dupecoverage") || a.equals("dupecov") || a.equals("dupes") || a.equals("duplicates") || a.equals("includeduplicates")){
-				INCLUDE_DUPLICATES=Tools.parseBoolean(b);
+				INCLUDE_DUPLICATES=Parse.parseBoolean(b);
 			}else if(a.equals("ignoredupes") || a.equals("ignoreduplicates")){
-				INCLUDE_DUPLICATES=!Tools.parseBoolean(b);
+				INCLUDE_DUPLICATES=!Parse.parseBoolean(b);
 			}else if(a.equals("normb") || a.equals("normalizebins")){
 				try {
 					NORMALIZE_LENGTH_BINS=Integer.parseInt(b);
 				} catch (NumberFormatException e) {
-					boolean x=Tools.parseBoolean(b);
+					boolean x=Parse.parseBoolean(b);
 					NORMALIZE_LENGTH_BINS=x ? 100 : -1;
 				}
 			}else if(a.equals("covwindow")){
 				if(b==null || b.length()<1 || Character.isLetter(b.charAt(0))){
-					USE_WINDOW=Tools.parseBoolean(b);
+					USE_WINDOW=Parse.parseBoolean(b);
 				}else{
 					LOW_COV_WINDOW=Integer.parseInt(b);
 					USE_WINDOW=(LOW_COV_WINDOW>0);
@@ -508,7 +509,7 @@ public class CoveragePileup {
 
 				if(a=='S' && b=='Q'){
 					Scaffold scaf=new Scaffold(line);
-					if(COUNT_GC){scaf.basecount=new long[8];}
+					if(COUNT_GC){scaf.basecount=KillSwitch.allocLong1D(8);}
 					assert(!table.containsKey(scaf.name)) : "\nDuplicate scaffold name!\n"+scaf+"\n\n"+table.get(scaf.name);
 					table.put(scaf.name, scaf);
 					list.add(scaf);
@@ -561,7 +562,7 @@ public class CoveragePileup {
 					if(ca!=null){
 						scaf.gc=ca.calcGC(loc, length, counts);
 					}
-					if(COUNT_GC){scaf.basecount=new long[8];}
+					if(COUNT_GC){scaf.basecount=KillSwitch.allocLong1D(8);}
 					assert(!table.containsKey(scaf.name)) : "\nDuplicate scaffold name!\n"+scaf+"\n\n"+table.get(scaf.name);
 					table.put(scaf.name, scaf);
 					list.add(scaf);
@@ -578,7 +579,7 @@ public class CoveragePileup {
 		ByteFile bf=ByteFile.makeByteFile(reference, false);
 		Scaffold scaf=null;
 		int len=0;
-		final long[] acgtn=new long[8];
+		final long[] acgtn=KillSwitch.allocLong1D(8);
 		boolean addLen=false;
 		for(byte[] s=bf.nextLine(); s!=null; s=bf.nextLine()){
 			if(s.length>0 && s[0]=='>'){
@@ -609,7 +610,7 @@ public class CoveragePileup {
 						outstream.println("Warning - SAM header did not include "+name+"\nAbsent scaffolds will be added; further warnings will be suppressed.");
 						warned=true;
 					}
-					if(COUNT_GC){scaf.basecount=new long[8];}
+					if(COUNT_GC){scaf.basecount=KillSwitch.allocLong1D(8);}
 					table.put(name, scaf);
 					list.add(scaf);
 					addLen=true;
@@ -753,7 +754,7 @@ public class CoveragePileup {
 					warned=true;
 				}
 				scaf=new Scaffold(scafName, 0);
-				if(COUNT_GC){scaf.basecount=new long[8];}
+				if(COUNT_GC){scaf.basecount=KillSwitch.allocLong1D(8);}
 				table.put(scafName, scaf);
 				list.add(scaf);
 				return addCoverage(scaf, seq, match, start0, stop0, readlen, nonClippedBases, strand, incrementFrags, properPair, sl);
@@ -930,7 +931,7 @@ public class CoveragePileup {
 			if(line[1]=='S' && line[2]=='Q'){
 				Scaffold scaf=new Scaffold(line);
 				if(!table.containsKey(scaf.name)){
-					if(COUNT_GC){scaf.basecount=new long[8];}
+					if(COUNT_GC){scaf.basecount=KillSwitch.allocLong1D(8);}
 					table.put(scaf.name, scaf);
 					list.add(scaf);
 					refBases+=scaf.length;
