@@ -5,6 +5,7 @@ import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.PriorityQueue;
 
+import shared.Parse;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -54,21 +55,24 @@ public class DedupeByMapping extends BBTool_ST{
 	@Override
 	public boolean parseArgument(String arg, String a, String b) {
 		if(a.equals("keepunmapped") | a.equals("ku")){
-			keepUnmapped=Tools.parseBoolean(b);
+			keepUnmapped=Parse.parseBoolean(b);
 			return true;
 		}else if(a.equals("keepsingletons") | a.equals("ks")){
-			keepSingletons=Tools.parseBoolean(b);
+			keepSingletons=Parse.parseBoolean(b);
 			return true;
 		}else if(a.equals("ignorepairorder") | a.equals("ipo")){
-			usePairOrder=!Tools.parseBoolean(b);
+			usePairOrder=!Parse.parseBoolean(b);
 			return true;
 		}else if(a.equals("sorted")){
-			sorted=Tools.parseBoolean(b);
+			sorted=Parse.parseBoolean(b);
 			return true;
 		}
 		return false;
 	}
 	
+	@Override
+	protected final boolean useSharedHeader(){return true;}
+	
 	@Override
 	protected boolean processReadPair(Read r1, Read r2) {
 		assert(r2==null);
@@ -98,7 +102,7 @@ public class DedupeByMapping extends BBTool_ST{
 		if(old==null){
 			nameToRead.put(r1.id, r1);
 		}else{
-			assert(old.mate==null);
+			//assert(old.mate==null);//This triggers...  maybe, after filtering and leaving some unpaired reads
 			old.mate=r1;
 			r1.mate=old;
 			SamLine sl2=old.samline;
@@ -216,7 +220,7 @@ public class DedupeByMapping extends BBTool_ST{
 					}
 				}else if(keepSingletons && r2!=null && (r1.mapped()!=r1.mateMapped())){
 					retainedReads+=r1.pairCount();
-				retainedBases+=r1.pairLength();
+					retainedBases+=r1.pairLength();
 					unmapped.add(r1);
 				}else{
 //					System.err.println(r1.strandChar()+", "+r1.start+", "+r1.stop+", "+r2.strandChar()+", "+r2.start+", "+r2.stop);
@@ -420,7 +424,7 @@ public class DedupeByMapping extends BBTool_ST{
 //		if()
 
 		final int s1=r1.strand(), a1=r1.start, b1=r1.stop, c1=r1.chrom;
-		final int s2=r2.strand(), a2=r2.start, b2=r2.stop, c2=r2.chrom;
+		final int s2=(r2==null ? 0 : r2.strand()), a2=(r2==null ? 0 : r2.start), b2=(r2==null ? 0 : r2.stop), c2=(r2==null ? 0 : r2.chrom);
 		final Quad q;
 		if(usePairOrder){
 			q=new Quad(s1==0 ? a1 : b1, c1, s2==0 ? a2 : b2, c2);
