@@ -15,6 +15,7 @@ import fileIO.ByteFile2;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -84,7 +85,7 @@ public class DemuxByName {
 			if(parser.parse(arg, a, b)){
 				//do nothing
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -101,21 +102,21 @@ public class DemuxByName {
 			}else if(a.equalsIgnoreCase("length") || a.equalsIgnoreCase("len") || a.equalsIgnoreCase("affixlength") || a.equalsIgnoreCase("affixlen")){
 				fixedAffixLength=Integer.parseInt(b);
 			}else if(a.equals("prefixmode") || a.equals("prefix") || a.equals("pm")){
-				prefixMode=Tools.parseBoolean(b);
+				prefixMode=Parse.parseBoolean(b);
 			}else if(a.equals("suffixmode") || a.equals("suffix") || a.equals("sm")){
-				prefixMode=!Tools.parseBoolean(b);
+				prefixMode=!Parse.parseBoolean(b);
 			}else if(a.equals("column")){
 				column=Integer.parseInt(b);
 				assert(column>0 || column==-1) : "Column is 1-based; must be 1+ or else -1 to disable.";
 				column--;
 			}else if(a.equals("substringmode") || a.equals("substring")){
-				substringMode=Tools.parseBoolean(b);
+				substringMode=Parse.parseBoolean(b);
 			}else if(a.equals("outu") || a.equals("outu1")){
 				outu1=b;
 			}else if(a.equals("outu2")){
 				outu2=b;
 			}else if(a.equals("perheader") || a.equals("persequence") || a.equals("pername")){
-				perheader=Tools.parseBoolean(b);
+				perheader=Parse.parseBoolean(b);
 			}else if(a.equals("delimiter")){
 				if(b==null){delimiter=null;}
 				
