@@ -17,6 +17,7 @@ import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -178,7 +179,7 @@ public class DemuxByName2 {
 			String b=split.length>1 ? split[1] : null;
 
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				BufferedMultiCros.verbose=verbose;
 			}else if(a.equals("names") || a.equals("name") || a.equals("affixes")){
 				if(b!=null){
@@ -188,24 +189,24 @@ public class DemuxByName2 {
 					}
 				}
 			}else if(a.equals("threaded")){
-				threaded=Tools.parseBoolean(b);
+				threaded=Parse.parseBoolean(b);
 			}else if(a.equals("chrom") || a.equals("chrommode") || a.equals("scaffold")){
-				if(Tools.parseBoolean(b)){mode=CHROM_MODE;}
+				if(Parse.parseBoolean(b)){mode=CHROM_MODE;}
 			}else if(a.equals("substringmode") || a.equals("substring")){
-				if(Tools.parseBoolean(b)){mode=SUBSTRING_MODE;}
+				if(Parse.parseBoolean(b)){mode=SUBSTRING_MODE;}
 			}else if(a.equals("barcode") || a.equals("barcodemode") || a.equals("index")){
-				if(Tools.parseBoolean(b)){mode=BARCODE_MODE;}
+				if(Parse.parseBoolean(b)){mode=BARCODE_MODE;}
 			}else if(a.equals("perheader") || a.equals("persequence") || a.equals("header") || a.equals("headermode")){
-				if(Tools.parseBoolean(b)){mode=HEADER_MODE;}
+				if(Parse.parseBoolean(b)){mode=HEADER_MODE;}
 			}else if(a.equals("affix") || a.equals("affixmode")){
-				if(Tools.parseBoolean(b)){mode=AFFIX_MODE;}
+				if(Parse.parseBoolean(b)){mode=AFFIX_MODE;}
 			}else if(a.equals("delimiter")){
-				delimiter=Tools.parseSymbol(b);
+				delimiter=Parse.parseSymbol(b);
 				if(delimiter!=null){mode=DELIMITER_MODE;}
 			}else if(a.equals("prefixmode") || a.equals("prefix") || a.equals("pm")){
-				prefixMode=Tools.parseBoolean(b);
+				prefixMode=Parse.parseBoolean(b);
 			}else if(a.equals("suffixmode") || a.equals("suffix") || a.equals("sm")){
-				prefixMode=!Tools.parseBoolean(b);
+				prefixMode=!Parse.parseBoolean(b);
 			}else if(a.equals("column")){
 				column=Integer.parseInt(b);
 				assert(column>0 || column==-1) : "Column is 1-based; must be 1+ or else -1 to disable.";
@@ -215,15 +216,15 @@ public class DemuxByName2 {
 			}else if(a.equalsIgnoreCase("stats") || a.equalsIgnoreCase("report") || a.equalsIgnoreCase("results")){
 				stats=b;
 			}else if(a.equalsIgnoreCase("minreadstodump") || a.equalsIgnoreCase("minreads")){
-				minReadsToDump=Tools.parseKMG(b);
+				minReadsToDump=Parse.parseKMG(b);
 			}else if(a.equalsIgnoreCase("mcrostype")){
 				mcrosType=Integer.parseInt(b);
 			}else if(a.equalsIgnoreCase("streams") || a.equalsIgnoreCase("maxstreams")){
 				maxStreams=Integer.parseInt(b);
 			}else if(a.equalsIgnoreCase("readsperbuffer") || a.equalsIgnoreCase("rpb")){
-				readsPerBuffer=Tools.parseIntKMG(b);
+				readsPerBuffer=Parse.parseIntKMG(b);
 			}else if(a.equalsIgnoreCase("bytesPerBuffer") || a.equalsIgnoreCase("bpb")){
-				bytesPerBuffer=Tools.parseIntKMG(b);
+				bytesPerBuffer=Parse.parseIntKMG(b);
 			}else if(a.equals("hdist") || a.equals("hamming") || a.equals("hammingdistance")){
 				hdist=Integer.parseInt(b);
 			}else if(a.equals("outu") || a.equals("outu1")){
@@ -233,7 +234,7 @@ public class DemuxByName2 {
 			}else if(a.equals("pattern")){
 				parser.out1=b;
 			}else if(a.equals("remap") || a.equals("replace")){
-				remap=Tools.parseRemap(b);
+				remap=Parse.parseRemap(b);
 			}
 			//Old version, allowed more complicated replacements
 //			else if(a.equals("replace")){
@@ -245,8 +246,8 @@ public class DemuxByName2 {
 //						replaceB=b.substring(1);
 //					}else{
 //						String[] pair=b.split(",");
-//						replaceA=Tools.parseSymbol(pair[0]);
-//						replaceB=Tools.parseSymbol(pair[1]);
+//						replaceA=Parse.parseSymbol(pair[0]);
+//						replaceB=Parse.parseSymbol(pair[1]);
 //					}
 //				}
 //			}
