@@ -10,6 +10,7 @@ import dna.AminoAcid;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -88,21 +89,21 @@ public class FilterBySequence {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("storebases") || a.equals("keepbases") || a.equals("sb")){
-				storeBases=Tools.parseBoolean(b);
+				storeBases=Parse.parseBoolean(b);
 			}else if(a.equals("include")){
-				include=Tools.parseBoolean(b);
+				include=Parse.parseBoolean(b);
 			}else if(a.equals("exclude")){
-				include=!Tools.parseBoolean(b);
+				include=!Parse.parseBoolean(b);
 			}else if(a.equals("rcomp")){
-				rcomp=Tools.parseBoolean(b);
+				rcomp=Parse.parseBoolean(b);
 			}else if(a.equals("casesensitive") || a.equals("case")){
-				toUpperCase=!Tools.parseBoolean(b);
+				toUpperCase=!Parse.parseBoolean(b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(a.equals("ref")){
 				if(b==null){ref=null;}
