@@ -10,6 +10,7 @@ import fileIO.ByteFile;
 import fileIO.ReadWrite;
 import kmer.AbstractKmerTableSet;
 import kmer.KmerTableSet;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -124,14 +125,14 @@ public class KmerFilterSetMaker {
 //			}
 			
 			else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("threads") || a.equals("t")){
 				THREADS=(b==null || b.equalsIgnoreCase("auto") ? Shared.threads() : Integer.parseInt(b));
 			}else if(a.equals("verbose")){
 				assert(false) : "Verbose flag is currently static final; must be recompiled to change.";
-//				verbose=Tools.parseBoolean(b);
+//				verbose=Parse.parseBoolean(b);
 			}
 			
 			else if(KmerTableSet.isValidArgument(a)){
