@@ -19,6 +19,7 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import shared.KillSwitch;
 import shared.MetadataWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -90,7 +91,7 @@ public class ReformatReads {
 			}else if(a.equals("ref")){
 				ref=b;
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -98,21 +99,21 @@ public class ReformatReads {
 				stream.FastqReadInputStream.verbose=verbose;
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("sample") || a.equals("samplereads") || a.equals("samplereadstarget") || a.equals("srt")){
-				sampleReadsTarget=Tools.parseKMG(b);
+				sampleReadsTarget=Parse.parseKMG(b);
 				sampleReadsExact=(sampleReadsTarget>0);
 			}else if(a.equals("samplebases") || a.equals("samplebasestarget") || a.equals("sbt")){
-				sampleBasesTarget=Tools.parseKMG(b);
+				sampleBasesTarget=Parse.parseKMG(b);
 				sampleBasesExact=(sampleBasesTarget>0);
 			}else if(a.equals("prioritizelength")){
-				prioritizeLength=Tools.parseBoolean(b);
+				prioritizeLength=Parse.parseBoolean(b);
 			}else if(a.equals("upsample")){
-				allowUpsumaple=Tools.parseBoolean(b);
+				allowUpsample=Parse.parseBoolean(b);
 			}else if(a.equals("addslash")){
-				addslash=Tools.parseBoolean(b);
+				addslash=Parse.parseBoolean(b);
 			}else if(a.equals("addcolon")){
-				addcolon=Tools.parseBoolean(b);
+				addcolon=Parse.parseBoolean(b);
 			}else if(a.equals("slashspace") || a.equals("spaceslash")){
-				boolean x=Tools.parseBoolean(b);
+				boolean x=Parse.parseBoolean(b);
 				if(x){
 					slash1=" /1";
 					slash2=" /2";
@@ -121,23 +122,23 @@ public class ReformatReads {
 					slash2="/2";
 				}
 			}else if(a.equals("addunderscore") || a.equals("underscore")){
-				addunderscore=Tools.parseBoolean(b);
+				addunderscore=Parse.parseBoolean(b);
 			}else if(a.equals("uniquenames")){
-				uniqueNames=Tools.parseBoolean(b);
+				uniqueNames=Parse.parseBoolean(b);
 			}else if(a.equals("verifyinterleaved") || a.equals("verifyinterleaving") || a.equals("vint")){
-				verifyinterleaving=Tools.parseBoolean(b);
+				verifyinterleaving=Parse.parseBoolean(b);
 			}else if(a.equals("verifypaired") || a.equals("verifypairing") || a.equals("vpair")){
-				verifypairing=Tools.parseBoolean(b);
+				verifypairing=Parse.parseBoolean(b);
 			}else if(a.equals("allowidenticalnames") || a.equals("ain")){
-				allowIdenticalPairNames=Tools.parseBoolean(b);
+				allowIdenticalPairNames=Parse.parseBoolean(b);
 			}else if(a.equals("rcompmate") || a.equals("rcm")){
-				reverseComplementMate=Tools.parseBoolean(b);
+				reverseComplementMate=Parse.parseBoolean(b);
 				outstream.println("Set RCOMPMATE to "+reverseComplementMate);
 			}else if(a.equals("rcomp") || a.equals("rc") || a.equals("reversecomplement")){
-				reverseComplement=Tools.parseBoolean(b);
+				reverseComplement=Parse.parseBoolean(b);
 				outstream.println("Set RCOMP to "+reverseComplement);
 			}else if(a.equals("comp") || a.equals("complement")){
-				complement=Tools.parseBoolean(b);
+				complement=Parse.parseBoolean(b);
 				outstream.println("Warning: Setting non-standard parameter 'complement'.");
 			}
 			
@@ -150,54 +151,54 @@ public class ReformatReads {
 //			}
 			
 			else if(a.equals("deleteempty") || a.equals("deletempty") || a.equals("delempty") || a.equals("def")){
-				deleteEmptyFiles=Tools.parseBoolean(b);
+				deleteEmptyFiles=Parse.parseBoolean(b);
 			}else if(a.equals("mappedonly")){
-				mappedOnly=Tools.parseBoolean(b);
+				mappedOnly=Parse.parseBoolean(b);
 			}else if(a.equals("pairedonly")){
-				pairedOnly=Tools.parseBoolean(b);
+				pairedOnly=Parse.parseBoolean(b);
 			}else if(a.equals("unpairedonly")){
-				unpairedOnly=Tools.parseBoolean(b);
+				unpairedOnly=Parse.parseBoolean(b);
 			}else if(a.equals("unmappedonly")){
-				unmappedOnly=Tools.parseBoolean(b);
+				unmappedOnly=Parse.parseBoolean(b);
 			}else if(a.equals("requiredbits") || a.equals("rbits")){
-				requiredBits=Tools.parseIntHexDecOctBin(b);
+				requiredBits=Parse.parseIntHexDecOctBin(b);
 			}else if(a.equals("filterbits") || a.equals("fbits")){
-				filterBits=Tools.parseIntHexDecOctBin(b);
+				filterBits=Parse.parseIntHexDecOctBin(b);
 			}else if(a.equals("primaryonly")){
-				primaryOnly=Tools.parseBoolean(b);
+				primaryOnly=Parse.parseBoolean(b);
 			}else if(a.equals("remap1")){
-				remap1=Tools.parseRemap(b);
+				remap1=Parse.parseRemap(b);
 			}else if(a.equals("remap2")){
-				remap2=Tools.parseRemap(b);
+				remap2=Parse.parseRemap(b);
 			}else if(a.equals("remap")){
-				remap1=remap2=Tools.parseRemap(b);
+				remap1=remap2=Parse.parseRemap(b);
 			}else if(a.equals("minmapq")){
 				minMapq=Integer.parseInt(b);
 			}else if(a.equals("maxmapq")){
 				maxMapq=Integer.parseInt(b);
 			}else if(a.equals("skipreads")){
-				skipreads=Tools.parseKMG(b);
+				skipreads=Parse.parseKMG(b);
 			}else if(a.equals("undefinedton") || a.equals("iupacton") || a.equals("itn")){
-				iupacToN=Tools.parseBoolean(b);
+				iupacToN=Parse.parseBoolean(b);
 			}else if(a.equals("quantize") || a.equals("quantizesticky")){
 				quantizeQuality=Quantizer.parse(arg, a, b);
 			}else if(a.equals("samversion") || a.equals("samv") || a.equals("sam")){
 				parser.parse(arg, a, b);
 				fixCigar=true;
 			}else if(a.equals("deleteinput")){
-				deleteInput=Tools.parseBoolean(b);
+				deleteInput=Parse.parseBoolean(b);
 			}else if(a.equals("invert") || a.equals("invertfilters")){
-				invertFilters=Tools.parseBoolean(b);
+				invertFilters=Parse.parseBoolean(b);
 			}else if(a.equals("k")){
 				k=Integer.parseInt(b);
 			}
 			
 			else if(a.equalsIgnoreCase("lastUnderscoreToSpace") || a.equalsIgnoreCase("underscoreToSpace")){
-				lastUnderscoreToSpace=Tools.parseBoolean(b);
+				lastUnderscoreToSpace=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("fixheader") || a.equals("fixheaders") || a.equals("fixnames")){
-				fixHeaders=Tools.parseBoolean(b);
+				fixHeaders=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("padleft")){
@@ -1100,7 +1101,7 @@ public class ReformatReads {
 								assert(readsRemaining>0) : readsRemaining;
 								double prob=sampleReadsTarget/(double)(readsRemaining);
 //								outstream.println("sampleReadsTarget="+sampleReadsTarget+", readsRemaining="+readsRemaining+", prob="+prob);
-								while(allowUpsumaple && prob>1){
+								while(allowUpsample && prob>1){
 									listOut.add(r);
 									sampleReadsTarget--;
 									prob--;
@@ -1116,9 +1117,9 @@ public class ReformatReads {
 						for(Read r : reads){
 							if(r!=null){
 								assert(basesRemaining>0) : basesRemaining;
-								int bases=r.length()+(r.mate==null ? 0 : r.mateLength());
+								final int bases=r.pairLength();
 								double prob=sampleBasesTarget/(double)(basesRemaining);
-								while(allowUpsumaple && prob>1){
+								while(allowUpsample && prob>1){
 									listOut.add(r);
 									sampleBasesTarget-=bases;
 									prob--;
@@ -1623,7 +1624,7 @@ public class ReformatReads {
 	private long sampleseed=-1;
 	private boolean sampleReadsExact=false;
 	private boolean sampleBasesExact=false;
-	private boolean allowUpsumaple=false;
+	private boolean allowUpsample=false;
 	private boolean prioritizeLength=false;
 	private long sampleReadsTarget=0;
 	private long sampleBasesTarget=0;
