@@ -10,6 +10,7 @@ import fileIO.TextStreamWriter;
 import kmer.AbstractKmerTable;
 import kmer.TableLoaderLockFree;
 import kmer.TableReader;
+import shared.Parse;
 import shared.Timer;
 import shared.Tools;
 import stream.ConcurrentReadInputStream;
@@ -99,29 +100,29 @@ public class SplitNexteraLMP extends BBTool_ST {
 			minReadLength=Integer.parseInt(b);
 			return true;
 		}else if(a.equals("useinnerlmp") || a.equals("innerlmp")){
-			useInnerLMP=Tools.parseBoolean(b);
+			useInnerLMP=Parse.parseBoolean(b);
 			return true;
 		}else if(a.equals("rename")){
-			RENAME=Tools.parseBoolean(b);
+			RENAME=Parse.parseBoolean(b);
 			return true;
 		}else if(a.equals("literal")){
 			literals=(b==null ? null : b.split(","));
 			return true;
 		}else if(a.equals("mask")){
-			mask=Tools.parseBoolean(b);
+			mask=Parse.parseBoolean(b);
 			return true;
 		}else if(a.equals("merge")){
-			merge=Tools.parseBoolean(b);
+			merge=Parse.parseBoolean(b);
 			return true;
 		}else if(a.equals("testmerge")){
 			testmerge=Double.parseDouble(b);
 			if(testmerge>1){testmerge/=100;}
 			return true;
 		}else if(a.equals("rcomp")){
-			rcomp=Tools.parseBoolean(b);
+			rcomp=Parse.parseBoolean(b);
 			return true;
 		}else if(a.equals("maskmiddle") || a.equals("mm")){
-			maskMiddle=Tools.parseBoolean(b);
+			maskMiddle=Parse.parseBoolean(b);
 			return true;
 		}else if(a.equals("k")){
 			k=Integer.parseInt(b);
