@@ -9,6 +9,7 @@ import java.util.Locale;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -94,26 +95,26 @@ public final class SplitPairsAndSingles {
 				outsingle=b;
 				setOut=true;
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("showspeed") || a.equals("ss")){
-				showSpeed=Tools.parseBoolean(b);
+				showSpeed=Parse.parseBoolean(b);
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("addslash")){
-				addslash=Tools.parseBoolean(b);
+				addslash=Parse.parseBoolean(b);
 			}else if(a.equals("addcolon")){
-				addcolon=Tools.parseBoolean(b);
+				addcolon=Parse.parseBoolean(b);
 			}else if(a.equals("reads") || a.startsWith("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.equals("fixinterleaving") || a.equals("fi") || a.equals("fint") || a.equals("fixint")){
-				fixInterleaving_=Tools.parseBoolean(b);
+				fixInterleaving_=Parse.parseBoolean(b);
 				if(fixInterleaving_){repair_=false;}
 			}else if(a.equals("allowidenticalnames") || a.equals("ain")){
-				allowIdenticalPairNames_=Tools.parseBoolean(b);
+				allowIdenticalPairNames_=Parse.parseBoolean(b);
 			}else if(a.equals("repair") || a.equals("rp")){
-				repair_=Tools.parseBoolean(b);
+				repair_=Parse.parseBoolean(b);
 				if(repair_){fixInterleaving_=false;}
 			}else if(i==0 && in1==null && arg.indexOf('=')<0 && arg.lastIndexOf('.')>0){
 				in1=args[i];
