@@ -13,6 +13,7 @@ import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import jgi.BBMerge;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Primes;
@@ -134,54 +135,54 @@ public class KmerTableSet extends AbstractKmerTableSet {
 					}
 				}
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("initialsize")){
-				initialSize=Tools.parseIntKMG(b);
+				initialSize=Parse.parseIntKMG(b);
 			}else if(a.equals("showstats") || a.equals("stats")){
-				showStats=Tools.parseBoolean(b);
+				showStats=Parse.parseBoolean(b);
 			}else if(a.equals("ways")){
-				ways_=Tools.parseIntKMG(b);
+				ways_=Parse.parseIntKMG(b);
 			}else if(a.equals("buflen") || a.equals("bufflen") || a.equals("bufferlength")){
-				buflen=Tools.parseIntKMG(b);
+				buflen=Parse.parseIntKMG(b);
 			}else if(a.equals("k")){
 				assert(b!=null) : "\nk needs an integer value from 1 to 31, such as k=27.  Default is 31.\n";
-				k_=Tools.parseIntKMG(b);
+				k_=Parse.parseIntKMG(b);
 			}else if(a.equals("threads") || a.equals("t")){
 				THREADS=(b==null || b.equalsIgnoreCase("auto") ? Shared.threads() : Integer.parseInt(b));
 			}else if(a.equals("showspeed") || a.equals("ss")){
-				showSpeed=Tools.parseBoolean(b);
+				showSpeed=Parse.parseBoolean(b);
 			}else if(a.equals("ecco")){
-				ecco_=Tools.parseBoolean(b);
+				ecco_=Parse.parseBoolean(b);
 			}else if(a.equals("merge")){
-				merge_=Tools.parseBoolean(b);
+				merge_=Parse.parseBoolean(b);
 			}else if(a.equals("verbose")){
 //				assert(false) : "Verbose flag is currently static final; must be recompiled to change.";
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("verbose2")){
 //				assert(false) : "Verbose flag is currently static final; must be recompiled to change.";
-				verbose2=Tools.parseBoolean(b);
+				verbose2=Parse.parseBoolean(b);
 			}else if(a.equals("minprob")){
 				minProb_=Double.parseDouble(b);
 			}else if(a.equals("minprobprefilter") || a.equals("mpp")){
-				minProbPrefilter=Tools.parseBoolean(b);
+				minProbPrefilter=Parse.parseBoolean(b);
 			}else if(a.equals("minprobmain") || a.equals("mpm")){
-				minProbMain=Tools.parseBoolean(b);
+				minProbMain=Parse.parseBoolean(b);
 			}else if(a.equals("reads") || a.startsWith("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.equals("prealloc") || a.equals("preallocate")){
 				if(b==null || b.length()<1 || Character.isLetter(b.charAt(0))){
-					prealloc_=Tools.parseBoolean(b);
+					prealloc_=Parse.parseBoolean(b);
 				}else{
 					preallocFraction=Tools.max(0, Double.parseDouble(b));
 					prealloc_=(preallocFraction>0);
 				}
 			}else if(a.equals("prefilter")){
 				if(b==null || b.length()<1 || !Tools.isDigit(b.charAt(0))){
-					prefilter=Tools.parseBoolean(b);
+					prefilter=Parse.parseBoolean(b);
 				}else{
-					filterMax_=Tools.parseIntKMG(b);
+					filterMax_=Parse.parseIntKMG(b);
 					prefilter=filterMax_>0;
 				}
 			}else if(a.equals("prefiltersize") || a.equals("prefilterfraction") || a.equals("pff")){
@@ -189,28 +190,28 @@ public class KmerTableSet extends AbstractKmerTableSet {
 				assert(prefilterFraction<=1) : "prefiltersize must be 0-1, a fraction of total memory.";
 				prefilter=prefilterFraction>0;
 			}else if(a.equals("prehashes") || a.equals("hashes")){
-				prehashes=Tools.parseIntKMG(b);
+				prehashes=Parse.parseIntKMG(b);
 			}else if(a.equals("prefilterpasses") || a.equals("prepasses")){
 				assert(b!=null) : "Bad parameter: "+arg;
 				if(b.equalsIgnoreCase("auto")){
 					prepasses=-1;
 				}else{
-					prepasses=Tools.parseIntKMG(b);
+					prepasses=Parse.parseIntKMG(b);
 				}
 			}else if(a.equals("onepass")){
-				onePass=Tools.parseBoolean(b);
+				onePass=Parse.parseBoolean(b);
 			}else if(a.equals("passes")){
-				int passes=Tools.parseIntKMG(b);
+				int passes=Parse.parseIntKMG(b);
 				onePass=(passes<2);
 			}else if(a.equals("rcomp")){
-				rcomp_=Tools.parseBoolean(b);
+				rcomp_=Parse.parseBoolean(b);
 			}else if(a.equals("tabletype")){
 				tableType_=Integer.parseInt(b);
 			}
 			
 			else if(a.equalsIgnoreCase("filterMemoryOverride") || a.equalsIgnoreCase("filterMemory") || 
 					a.equalsIgnoreCase("prefilterMemory") || a.equalsIgnoreCase("filtermem")){
-				filterMemoryOverride=Tools.parseKMG(b);
+				filterMemoryOverride=Parse.parseKMG(b);
 			}
 			
 			else if(IGNORE_UNKNOWN_ARGS){
@@ -1714,4 +1715,39 @@ public class KmerTableSet extends AbstractKmerTableSet {
 	/** Attempt to merge via overlap prior to counting kmers */
 	private final boolean merge;
 	
+	/*--------------------------------------------------------------*/
+	/*----------------            Walker            ----------------*/
+	/*--------------------------------------------------------------*/
+	
+	public Walker walk(){
+		return new WalkerKST();
+	}
+	
+	public class WalkerKST extends Walker {
+		
+		WalkerKST(){
+			w=tables[0].walk();
+		}
+		
+		/** 
+		 * Fills this object with the next key and value.
+		 * @return True if successful.
+		 */
+		public boolean next(){
+			if(w==null){return false;}
+			if(w.next()){return true;}
+			if(tnum<tables.length){tnum++;}
+			w=(tnum<tables.length ? tables[tnum].walk() : null);
+			return w==null ? false : w.next();
+		}
+		
+		public long kmer(){return w.kmer();}
+		public int value(){return w.value();}
+		
+		private Walker w=null;
+
+		/** current table number */
+		private int tnum=0;
+	}
+	
 }
