@@ -10,6 +10,7 @@ import dna.Data;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.ReadStats;
 import shared.Shared;
@@ -73,18 +74,18 @@ public class RemoveAdapters3 {
 			}else if(a.equals("query") || a.equals("adapter")){
 				query=b;
 			}else if(a.equals("split")){
-				splitReads=Tools.parseBoolean(b);
+				splitReads=Parse.parseBoolean(b);
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 				System.out.println("Set overwrite to "+overwrite);
 			}else if(a.equals("threads") || a.equals("t")){
 				if(b.equalsIgnoreCase("auto")){THREADS=Shared.LOGICAL_PROCESSORS;}
 				else{THREADS=Integer.parseInt(b);}
 				System.out.println("Set threads to "+THREADS);
 			}else if(a.equals("reads") || a.equals("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.startsWith("outname") || a.startsWith("outfile") || a.equals("out")){
 				if(b==null || b.equalsIgnoreCase("null") || b.equalsIgnoreCase("none") || split.length==1){
 					System.out.println("No output file.");
@@ -100,13 +101,13 @@ public class RemoveAdapters3 {
 					}
 				}
 			}else if(a.equals("perfectmode")){
-				PERFECTMODE=Tools.parseBoolean(b);
+				PERFECTMODE=Parse.parseBoolean(b);
 				if(ziplevel==-1){ziplevel=2;}
 			}else if(a.equals("minratio")){
 				MINIMUM_ALIGNMENT_SCORE_RATIO=Float.parseFloat(b);
 				System.out.println("Set MINIMUM_ALIGNMENT_SCORE_RATIO to "+MINIMUM_ALIGNMENT_SCORE_RATIO);
 			}else if(a.startsWith("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else{
 				throw new RuntimeException("Unknown parameter: "+args[i]);
 			}
