@@ -10,6 +10,7 @@ import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -115,12 +116,12 @@ public class AnalyzeGenes {
 				assert(b!=null);
 				Tools.addFiles(b, gffList);
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("alignribo") || a.equals("align")){
-				alignRibo=Tools.parseBoolean(b);
+				alignRibo=Parse.parseBoolean(b);
 			}else if(a.equals("adjustendpoints")){
-				adjustEndpoints=Tools.parseBoolean(b);
+				adjustEndpoints=Parse.parseBoolean(b);
 			}
 			
 			else if(ProkObject.parse(arg, a, b)){}
