@@ -14,6 +14,7 @@ import fileIO.ReadWrite;
 import gff.CompareGff;
 import jgi.BBMerge;
 import json.JsonObject;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -151,13 +152,13 @@ public class CallGenes extends ProkObject {
 			}else if(a.equalsIgnoreCase("out18s") || a.equalsIgnoreCase("18sout")){
 				out18S=b;
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				//ReadWrite.verbose=verbose;
 				GeneCaller.verbose=verbose;
 			}
 			
 			else if(a.equals("json_out") || a.equalsIgnoreCase("json")){
-				json_out=Tools.parseBoolean(b);
+				json_out=Parse.parseBoolean(b);
 			}else if(a.equals("stats") || a.equalsIgnoreCase("outstats")){
 				outStats=b;
 			}else if(a.equals("hist") || a.equalsIgnoreCase("outhist") || a.equalsIgnoreCase("lengthhist") || a.equalsIgnoreCase("lhist") || a.equalsIgnoreCase("genehist")){
@@ -167,13 +168,13 @@ public class CallGenes extends ProkObject {
 			}else if(a.equals("binlen") || a.equals("binlength") || a.equals("histdiv")){
 				geneHistBins=Integer.parseInt(b);
 			}else if(a.equals("printzero") || a.equals("pz")){
-				printZeroCountHist=Tools.parseBoolean(b);
+				printZeroCountHist=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("merge")){
-				merge=Tools.parseBoolean(b);
+				merge=Parse.parseBoolean(b);
 			}else if(a.equals("ecco")){
-				ecco=Tools.parseBoolean(b);
+				ecco=Parse.parseBoolean(b);
 			}
 
 			else if(a.equalsIgnoreCase("setbias16s")) {
@@ -191,7 +192,7 @@ public class CallGenes extends ProkObject {
 			}
 			
 			else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("translate")){
