@@ -3,6 +3,8 @@ package prok;
 import java.util.Arrays;
 
 import dna.AminoAcid;
+import shared.KillSwitch;
+import shared.Parse;
 import shared.Tools;
 import structures.ByteBuilder;
 
@@ -205,13 +207,13 @@ public class FrameStats {
 		
 		while(b<line.length && line[b]!='\t'){b++;}
 		assert(b>a) : "Missing field 0: "+new String(line);
-		valid=Tools.parseInt(line, a, b);
+		valid=Parse.parseInt(line, a, b);
 		b++;
 		a=b;
 		
 		while(b<line.length && line[b]!='\t'){b++;}
 		assert(b>a) : "Missing field 1: "+new String(line);
-		frame=Tools.parseInt(line, a, b);
+		frame=Parse.parseInt(line, a, b);
 		b++;
 		a=b;
 		
@@ -223,7 +225,7 @@ public class FrameStats {
 			for(int kmer=0; kmer<row.length; kmer++){
 				while(b<line.length && line[b]!='\t'){b++;}
 				assert(b>a) : "Missing field 1: "+new String(line);
-				long count=Tools.parseLong(line, a, b);
+				long count=Parse.parseLong(line, a, b);
 				b++;
 				a=b;
 				row[kmer]=count;
@@ -301,7 +303,7 @@ public class FrameStats {
 	public final long[][] countsFalse;
 	public final long[][][] counts;
 
-	public final long[] validSums=new long[2];
+	public final long[] validSums=KillSwitch.allocLong1D(2);
 	private float average=-1;
 	private float invAvg=-1;
 	
