@@ -9,6 +9,7 @@ import aligner.SingleStateAlignerFlat2;
 import dna.AminoAcid;
 import fileIO.FileFormat;
 import gff.GffLine;
+import shared.KillSwitch;
 import shared.Shared;
 import shared.Tools;
 import stream.Read;
@@ -347,7 +348,7 @@ public class GeneModel extends ProkObject {
 			byte[] universal=(consensusReads!=null && consensusReads.length>0 ? consensusReads[0].bases : null);
 			float minIdentity=ProkObject.minID(type);
 			if(universal!=null){
-				int[] coords=new int[2];
+				int[] coords=KillSwitch.allocInt1D(2);
 				final int a=Tools.max(0, start-(AnalyzeGenes.adjustEndpoints ? 200 : 50));
 				final int b=Tools.min(sd.bases.length-1, stop+(AnalyzeGenes.adjustEndpoints ? 200 : 50));
 				float id1=align(universal, sd.bases, a, b, minIdentity, coords);
