@@ -14,6 +14,7 @@ import consensus.BaseGraph;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -145,15 +146,15 @@ public class MergeRibo implements Accumulator<MergeRibo.ProcessThread> {
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("consensus")){
-				useConsensus=Tools.parseBoolean(b);
+				useConsensus=Parse.parseBoolean(b);
 			}else if(a.equals("best")){
-				useConsensus=!Tools.parseBoolean(b);
+				useConsensus=!Parse.parseBoolean(b);
 			}else if(a.equals("fast")){
-				fast=Tools.parseBoolean(b);
+				fast=Parse.parseBoolean(b);
 			}else if(a.equals("minid")){
 				minID=Float.parseFloat(b);
 			}else if(a.equals("maxns")){
@@ -167,13 +168,13 @@ public class MergeRibo implements Accumulator<MergeRibo.ProcessThread> {
 			}else if(a.equals("alt")){
 				alt=b;
 			}else if(a.equalsIgnoreCase("process16S") || a.equalsIgnoreCase("16S")){
-				process16S=Tools.parseBoolean(b);
+				process16S=Parse.parseBoolean(b);
 				process18S=!process16S;
 			}else if(a.equalsIgnoreCase("process18S") || a.equalsIgnoreCase("18S")){
-				process18S=Tools.parseBoolean(b);
+				process18S=Parse.parseBoolean(b);
 				process16S=!process18S;
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
