@@ -10,6 +10,7 @@ import dna.AminoAcid;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -22,8 +23,8 @@ import stream.FASTQ;
 import stream.FastaReadInputStream;
 import stream.Read;
 import stream.ReadInputStream;
-import structures.LongHashSet;
 import structures.ListNum;
+import structures.LongHashSet;
 import template.Accumulator;
 import template.ThreadWaiter;
 
@@ -145,15 +146,15 @@ public class RiboMaker implements Accumulator<RiboMaker.ProcessThread> {
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("filter")){
 				filterFile=b;
 			}else if(a.equals("ref")){
 				refFile=b;
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
