@@ -73,24 +73,24 @@ public class Parser {
 
 	public boolean parseCommon(String arg, String a, String b){
 		if(a.equals("reads") || a.equals("maxreads")){
-			maxReads=Tools.parseKMG(b);
+			maxReads=Parse.parseKMG(b);
 		}else if(a.equals("samplerate")){
 			samplerate=Float.parseFloat(b);
 			assert(samplerate<=1f && samplerate>=0f) : "samplerate="+samplerate+"; should be between 0 and 1";
 		}else if(a.equals("sampleseed")){
 			sampleseed=Long.parseLong(b);
 		}else if(a.equals("append") || a.equals("app")){
-			append=ReadStats.append=Tools.parseBoolean(b);
+			append=ReadStats.append=Parse.parseBoolean(b);
 		}else if(a.equals("overwrite") || a.equals("ow")){
-			overwrite=Tools.parseBoolean(b);
+			overwrite=Parse.parseBoolean(b);
 		}else if(a.equals("testsize")){
-			testsize=Tools.parseBoolean(b);
+			testsize=Parse.parseBoolean(b);
 		}else if(a.equals("breaklen") || a.equals("breaklength")){
 			breakLength=Integer.parseInt(b);
 		}else if(a.equals("recalibrate") || a.equals("recalibratequality") || a.equals("recal")){
-			recalibrateQuality=Tools.parseBoolean(b);
+			recalibrateQuality=Parse.parseBoolean(b);
 		}else if(a.equals("silent")){
-			silent=Tools.parseBoolean(b);
+			silent=Parse.parseBoolean(b);
 		}else{
 			return false;
 		}
@@ -104,10 +104,10 @@ public class Parser {
 					loglogk=Integer.parseInt(b);
 					loglog=loglogk>0;
 				} catch (NumberFormatException e) {
-					loglog=Tools.parseBoolean(b);
+					loglog=Parse.parseBoolean(b);
 				}
 			}else{
-				loglog=Tools.parseBoolean(b);
+				loglog=Parse.parseBoolean(b);
 			}
 		}else if(a.equals("cardinalityout") || a.equals("loglogout")){
 			if(b!=null && b.length()>0 && Tools.isDigit(b.charAt(0))){
@@ -115,13 +115,13 @@ public class Parser {
 					loglogk=Integer.parseInt(b);
 					loglogOut=loglogk>0;
 				} catch (NumberFormatException e) {
-					loglogOut=Tools.parseBoolean(b);
+					loglogOut=Parse.parseBoolean(b);
 				}
 			}else{
-				loglogOut=Tools.parseBoolean(b);
+				loglogOut=Parse.parseBoolean(b);
 			}
 		}else if(a.equals("buckets") || a.equals("loglogbuckets")){
-			loglogbuckets=Tools.parseIntKMG(b);
+			loglogbuckets=Parse.parseIntKMG(b);
 			assert(loglogbuckets>0);
 			loglogbuckets=CardinalityTracker.powerOf2AtLeast(loglogbuckets);
 		}else if(a.equals("loglogbits")){
@@ -159,7 +159,7 @@ public class Parser {
 			LogLog2.setMantissaBits(Integer.parseInt(b));
 			LogLog16.setMantissaBits(Integer.parseInt(b));
 		}else if(a.equals("loglogcounts") || a.equals("loglogcount")){
-			CardinalityTracker.trackCounts=Tools.parseBoolean(b);
+			CardinalityTracker.trackCounts=Parse.parseBoolean(b);
 		}else{
 			return false;
 		}
@@ -169,22 +169,22 @@ public class Parser {
 	
 	public boolean parseInterleaved(String arg, String a, String b){
 		if(a.equals("testinterleaved")){
-			FASTQ.TEST_INTERLEAVED=Tools.parseBoolean(b);
+			FASTQ.TEST_INTERLEAVED=Parse.parseBoolean(b);
 			System.err.println("Set TEST_INTERLEAVED to "+FASTQ.TEST_INTERLEAVED);
 			setInterleaved=true;
 		}else if(a.equals("forceinterleaved")){
-			FASTQ.FORCE_INTERLEAVED=Tools.parseBoolean(b);
+			FASTQ.FORCE_INTERLEAVED=Parse.parseBoolean(b);
 			System.err.println("Set FORCE_INTERLEAVED to "+FASTQ.FORCE_INTERLEAVED);
 			setInterleaved=true;
 		}else if(a.equals("interleaved") || a.equals("int")){
 			if("auto".equalsIgnoreCase(b)){FASTQ.FORCE_INTERLEAVED=!(FASTQ.TEST_INTERLEAVED=true);}
 			else{
-				FASTQ.FORCE_INTERLEAVED=FASTQ.TEST_INTERLEAVED=Tools.parseBoolean(b);
+				FASTQ.FORCE_INTERLEAVED=FASTQ.TEST_INTERLEAVED=Parse.parseBoolean(b);
 				System.err.println("Set INTERLEAVED to "+FASTQ.FORCE_INTERLEAVED);
 				setInterleaved=true;
 			}
 		}else if(a.equals("overrideinterleaved")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			ReadStreamByteWriter.ignorePairAssertions=x;
 			if(x){setInterleaved=true;}
 		}else{
@@ -234,25 +234,25 @@ public class Parser {
 			}else if(Tools.isDigit(b.charAt(0))){
 				parseTrimq(a, b);
 				qtrimRight=true;
-			}else{qtrimRight=qtrimLeft=Tools.parseBoolean(b);}
+			}else{qtrimRight=qtrimLeft=Parse.parseBoolean(b);}
 		}else if(a.equals("optitrim") || a.equals("otf") || a.equals("otm")){
 			if(b!=null && (b.charAt(0)=='.' || Tools.isDigit(b.charAt(0)))){
 				TrimRead.optimalMode=true;
 				TrimRead.optimalBias=Float.parseFloat(b);
 				assert(TrimRead.optimalBias>=0 && TrimRead.optimalBias<1);
 			}else{
-				TrimRead.optimalMode=Tools.parseBoolean(b);
+				TrimRead.optimalMode=Parse.parseBoolean(b);
 			}
 		}else if(a.equals("trimgoodinterval")){
 			TrimRead.minGoodInterval=Integer.parseInt(b);
 		}else if(a.equals("trimright") || a.equals("qtrimright")){
-			qtrimRight=Tools.parseBoolean(b);
+			qtrimRight=Parse.parseBoolean(b);
 		}else if(a.equals("trimleft") || a.equals("qtrimleft")){
-			qtrimLeft=Tools.parseBoolean(b);
+			qtrimLeft=Parse.parseBoolean(b);
 		}else if(a.equals("trimq") || a.equals("trimquality") || a.equals("trimq2")){
 			parseTrimq(a, b);
 		}else if(a.equals("trimclip")){
-			trimClip=Tools.parseBoolean(b);
+			trimClip=Parse.parseBoolean(b);
 		}else if(a.equals("trimpolya")){
 			trimPolyA=parsePoly(b);
 		}
@@ -289,7 +289,7 @@ public class Parser {
 			if(Tools.isDigit(b.charAt(0))){
 				r=Integer.parseInt(b);
 			}else{
-				boolean x=Tools.parseBoolean(b);
+				boolean x=Parse.parseBoolean(b);
 				r=x ? 2 : 0;
 			}
 		}
@@ -309,17 +309,17 @@ public class Parser {
 		}else if(a.equals("ftr2") || a.equals("forcetrimright2")){
 			forceTrimRight2=Integer.parseInt(b);
 		}else if(a.equals("trimbadsequence")){
-			trimBadSequence=Tools.parseBoolean(b);
+			trimBadSequence=Parse.parseBoolean(b);
 		}else if(a.equals("chastityfilter") || a.equals("cf")){
-			chastityFilter=Tools.parseBoolean(b);
+			chastityFilter=Parse.parseBoolean(b);
 		}else if(a.equals("failnobarcode")){
-			failIfNoBarcode=Tools.parseBoolean(b);
+			failIfNoBarcode=Parse.parseBoolean(b);
 		}else if(a.equals("badbarcodes") || a.equals("barcodefilter")){
 			if(b!=null && (b.equalsIgnoreCase("crash") || b.equalsIgnoreCase("fail"))){
 				failBadBarcodes=true;
 				removeBadBarcodes=true;
 			}else{
-				removeBadBarcodes=Tools.parseBoolean(b);
+				removeBadBarcodes=Parse.parseBoolean(b);
 				failBadBarcodes=false;
 			}
 		}else if(a.equals("barcodes") || a.equals("barcode")){
@@ -335,13 +335,13 @@ public class Parser {
 				removeBadBarcodes=true;
 			}
 		}else if(a.equals("requirebothbad") || a.equals("rbb")){
-			requireBothBad=Tools.parseBoolean(b);
+			requireBothBad=Parse.parseBoolean(b);
 		}else if(a.equals("removeifeitherbad") || a.equals("rieb")){
-			requireBothBad=!Tools.parseBoolean(b);
+			requireBothBad=!Parse.parseBoolean(b);
 		}else if(a.equals("ml") || a.equals("minlen") || a.equals("minlength")){
-			minReadLength=Tools.parseIntKMG(b);
+			minReadLength=Parse.parseIntKMG(b);
 		}else if(a.equals("maxlength") || a.equals("maxreadlength") || a.equals("maxreadlen") || a.equals("maxlen")){
-			maxReadLength=Tools.parseIntKMG(b);
+			maxReadLength=Parse.parseIntKMG(b);
 		}else if(a.equals("mingc")){
 			minGC=Float.parseFloat(b);
 //			if(minGC>0){filterGC=true;}
@@ -351,7 +351,7 @@ public class Parser {
 //			if(maxGC<1){filterGC=true;}
 			assert(minGC>=0 && minGC<=1) : "maxgc should be a decimal number between 0 and 1, inclusive.";
 		}else if(a.equals("usepairgc") || a.equals("pairgc")){
-			usePairGC=Tools.parseBoolean(b);
+			usePairGC=Parse.parseBoolean(b);
 			ReadStats.usePairGC=usePairGC;
 		}else if(a.equals("mlf") || a.equals("minlenfrac") || a.equals("minlenfraction") || a.equals("minlengthfraction")){
 			minLenFraction=Float.parseFloat(b);
@@ -373,13 +373,13 @@ public class Parser {
 		}else if(a.equals("minbasequality") || a.equals("mbq")){
 			minBaseQuality=Byte.parseByte(b);
 		}else if(a.equals("averagequalitybyprobability") || a.equals("aqbp")){
-			Read.AVERAGE_QUALITY_BY_PROBABILITY=Tools.parseBoolean(b);
+			Read.AVERAGE_QUALITY_BY_PROBABILITY=Parse.parseBoolean(b);
 		}else if(a.equals("mintl") || a.equals("mintrimlen") || a.equals("mintrimlength")){
 			minTrimLength=Integer.parseInt(b);
 		}else if(a.equals("untrim")){
-			untrim=Tools.parseBoolean(b);
+			untrim=Parse.parseBoolean(b);
 		}else if(a.equals("tossjunk")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			tossJunk=x;
 			if(x){Read.JUNK_MODE=Read.FLAG_JUNK;}
 		}else{
@@ -522,7 +522,7 @@ public class Parser {
 		if(a.equals("null")){
 			//Do nothing
 		}else if(a.equals("monitor") || a.equals("killswitch")){
-			if(Tools.isNumber(b)){
+			if(Parse.isNumber(b)){
 				String[] pair=b.split(",");
 				if(pair.length==1){
 					KillSwitch.launch(Double.parseDouble(pair[0]));
@@ -530,31 +530,31 @@ public class Parser {
 					assert(pair.length==2) : "monitor takes one or two arguments, like this: monitor=600,0.002";
 					KillSwitch.launch(Double.parseDouble(pair[0]), Double.parseDouble(pair[1]));
 				}
-			}else if(Tools.parseBoolean(b)){
+			}else if(Parse.parseBoolean(b)){
 				KillSwitch.launch();
 			}
 		}else if(a.equals("trd") || a.equals("trc") || a.equals("trimreaddescription") || a.equals("trimreaddescriptions")){
-			Shared.TRIM_READ_COMMENTS=Tools.parseBoolean(b);
+			Shared.TRIM_READ_COMMENTS=Parse.parseBoolean(b);
 			if(!setTrimRname){Shared.TRIM_RNAME=Shared.TRIM_READ_COMMENTS;}
 		}else if(a.equals("trimrefdescription") || a.equals("trimrefdescriptions") || a.equals("trimrname")){
-			Shared.TRIM_RNAME=Tools.parseBoolean(b);
+			Shared.TRIM_RNAME=Parse.parseBoolean(b);
 			setTrimRname=true;
 		}else if(a.equals("tuc") || a.equals("touppercase")){
-			Read.TO_UPPER_CASE=Tools.parseBoolean(b);
+			Read.TO_UPPER_CASE=Parse.parseBoolean(b);
 		}else if(a.equals("lctn") || a.equals("lowercaseton")){
-			Read.LOWER_CASE_TO_N=Tools.parseBoolean(b);
+			Read.LOWER_CASE_TO_N=Parse.parseBoolean(b);
 		}else if(a.equals("changequality") || a.equals("cq")){
-			Read.CHANGE_QUALITY=Tools.parseBoolean(b);
+			Read.CHANGE_QUALITY=Parse.parseBoolean(b);
 			BBMerge.changeQuality=Read.CHANGE_QUALITY;
 		}else if(a.equals("tossbrokenreads") || a.equals("tbr")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			Read.TOSS_BROKEN_QUALITY=x;
 			ConcurrentReadInputStream.REMOVE_DISCARDED_READS=x;
 		}else if(a.equals("nullifybrokenquality") || a.equals("nbq")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			Read.NULLIFY_BROKEN_QUALITY=x;
 		}else if(a.equals("dotdashxton")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			Read.DOT_DASH_X_TO_N=x;
 		}else if(a.equals("junk")){
 			if("ignore".equalsIgnoreCase(b)){Read.JUNK_MODE=Read.IGNORE_JUNK;}
@@ -564,86 +564,86 @@ public class Parser {
 			else if("iupacton".equalsIgnoreCase(b)){Read.JUNK_MODE=Read.FIX_JUNK_AND_IUPAC;}
 			else{assert(false) : "Bad junk mode: "+arg;}
 		}else if(a.equals("undefinedton") || a.equals("iupacton") || a.equals("itn")){
-			Read.IUPAC_TO_N=Tools.parseBoolean(b);
+			Read.IUPAC_TO_N=Parse.parseBoolean(b);
 		}else if(a.equals("ignorejunk")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			if(x){Read.JUNK_MODE=Read.IGNORE_JUNK;}
 			else if(Read.JUNK_MODE==Read.IGNORE_JUNK){Read.JUNK_MODE=Read.CRASH_JUNK;}
 		}else if(a.equals("flagjunk")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			if(x){Read.JUNK_MODE=Read.FLAG_JUNK;}
 			else if(Read.JUNK_MODE==Read.FLAG_JUNK){Read.JUNK_MODE=Read.CRASH_JUNK;}
 		}else if(a.equals("fixjunk")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			if(x){Read.JUNK_MODE=Read.FIX_JUNK;}
 			else if(Read.JUNK_MODE==Read.FIX_JUNK){Read.JUNK_MODE=Read.CRASH_JUNK;}
 		}else if(a.equals("crashjunk") || a.equals("failjunk")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			if(x){Read.JUNK_MODE=Read.CRASH_JUNK;}
 			else if(Read.JUNK_MODE==Read.CRASH_JUNK){Read.JUNK_MODE=Read.IGNORE_JUNK;}
 		}else if(a.equals("skipvalidation")){
-			Read.SKIP_SLOW_VALIDATION=Tools.parseBoolean(b);
+			Read.SKIP_SLOW_VALIDATION=Parse.parseBoolean(b);
 		}else if(a.equals("validate")){
-			Read.SKIP_SLOW_VALIDATION=!Tools.parseBoolean(b);
+			Read.SKIP_SLOW_VALIDATION=!Parse.parseBoolean(b);
 		}else if(a.equals("validatebranchless")){
-//			Read.VALIDATE_BRANCHLESS=Tools.parseBoolean(b);
+//			Read.VALIDATE_BRANCHLESS=Parse.parseBoolean(b);
 		}else if(a.equals("bf1")){
-			ByteFile.FORCE_MODE_BF1=Tools.parseBoolean(b);
+			ByteFile.FORCE_MODE_BF1=Parse.parseBoolean(b);
 			ByteFile.FORCE_MODE_BF2=!ByteFile.FORCE_MODE_BF1;
 		}else if(a.equals("bf1bufferlen")){
-			ByteFile1.bufferlen=(int)Tools.parseKMGBinary(b);
+			ByteFile1.bufferlen=(int)Parse.parseKMGBinary(b);
 		}else if(a.equals("utot")){
-			Read.U_TO_T=Tools.parseBoolean(b);
+			Read.U_TO_T=Parse.parseBoolean(b);
 		}else if(a.equals("bf2")){
-			ByteFile.FORCE_MODE_BF2=Tools.parseBoolean(b);
+			ByteFile.FORCE_MODE_BF2=Parse.parseBoolean(b);
 			ByteFile.FORCE_MODE_BF1=!ByteFile.FORCE_MODE_BF2;
 		}else if(a.equals("bf3")){
-			ByteFile.FORCE_MODE_BF3=Tools.parseBoolean(b);
+			ByteFile.FORCE_MODE_BF3=Parse.parseBoolean(b);
 			if(ByteFile.FORCE_MODE_BF3){
 				ByteFile.FORCE_MODE_BF1=true;
 				ByteFile.FORCE_MODE_BF2=false;
 			}
 		}else if(a.equals("usejni") || a.equals("jni")){
-			Shared.USE_JNI=Tools.parseBoolean(b);
+			Shared.USE_JNI=Parse.parseBoolean(b);
 		}else if(a.equals("usempi") || a.equals("mpi")){
 			if(b!=null && Tools.isDigit(b.charAt(0))){
 				Shared.MPI_NUM_RANKS=Integer.parseInt(b);
 				Shared.USE_MPI=Shared.MPI_NUM_RANKS>0;
 			}else{
-				Shared.USE_MPI=Tools.parseBoolean(b);
+				Shared.USE_MPI=Parse.parseBoolean(b);
 			}
 		}else if(a.equals("crismpi")){
-			Shared.USE_CRISMPI=Tools.parseBoolean(b);
+			Shared.USE_CRISMPI=Parse.parseBoolean(b);
 		}else if(a.equals("mpikeepall")){
-			Shared.MPI_KEEP_ALL=Tools.parseBoolean(b);
+			Shared.MPI_KEEP_ALL=Parse.parseBoolean(b);
 		}else if(a.equals("readbufferlength") || a.equals("readbufferlen")){
-			Shared.setBufferLen((int)Tools.parseKMG(b));
+			Shared.setBufferLen((int)Parse.parseKMG(b));
 		}else if(a.equals("readbufferdata")){
-			Shared.setBufferData(Tools.parseKMG(b));
+			Shared.setBufferData(Parse.parseKMG(b));
 		}else if(a.equals("readbuffers")){
 			Shared.setBuffers(Integer.parseInt(b));
 		}else if(a.equals("rbm") || a.equals("renamebymapping")){
-			FASTQ.TAG_CUSTOM=Tools.parseBoolean(b);
+			FASTQ.TAG_CUSTOM=Parse.parseBoolean(b);
 		}else if(a.equals("don") || a.equals("deleteoldname")){
-			FASTQ.DELETE_OLD_NAME=Tools.parseBoolean(b);
+			FASTQ.DELETE_OLD_NAME=Parse.parseBoolean(b);
 		}else if(a.equals("assertcigar")){
-			ReadStreamWriter.ASSERT_CIGAR=Tools.parseBoolean(b);
+			ReadStreamWriter.ASSERT_CIGAR=Parse.parseBoolean(b);
 		}else if(a.equals("verbosesamline")){
-			SamLine.verbose=Tools.parseBoolean(b);
+			SamLine.verbose=Parse.parseBoolean(b);
 		}else if(a.equals("parsecustom") || a.equals("fastqparsecustom")){
-			FASTQ.PARSE_CUSTOM=Tools.parseBoolean(b);
+			FASTQ.PARSE_CUSTOM=Parse.parseBoolean(b);
 			System.err.println("Set FASTQ.PARSE_CUSTOM to "+FASTQ.PARSE_CUSTOM);
 		}else if(a.equals("fairqueues")){
-			ConcurrentDepot.fair=Tools.parseBoolean(b);
+			ConcurrentDepot.fair=Parse.parseBoolean(b);
 		}else if(a.equals("fixheader") || a.equals("fixheaders")){
-			Read.FIX_HEADER=Tools.parseBoolean(b);
+			Read.FIX_HEADER=Parse.parseBoolean(b);
 		}else if(a.equals("allownullheader") || a.equals("allownullheaders")){
-			Read.ALLOW_NULL_HEADER=Tools.parseBoolean(b);
+			Read.ALLOW_NULL_HEADER=Parse.parseBoolean(b);
 		}else if(a.equals("aminoin") || a.equals("amino")){
 			//TODO: ensure changes to this do not conflict with TranslateSixFrames "aain" flag.
-			Shared.AMINO_IN=SketchObject.amino=Tools.parseBoolean(b);
+			Shared.AMINO_IN=SketchObject.amino=Parse.parseBoolean(b);
 		}else if(a.equals("amino8")){
-			SketchObject.amino8=Tools.parseBoolean(b);
+			SketchObject.amino8=Parse.parseBoolean(b);
 			if(SketchObject.amino8){
 				Shared.AMINO_IN=SketchObject.amino=true;
 				AminoAcid.AMINO_SHIFT=3;
@@ -658,7 +658,7 @@ public class Parser {
 			Shared.setThreads(b);
 			if(!silent){System.err.println("Set threads to "+Shared.threads());}
 		}else if(a.equals("recalpairnum") || a.equals("recalibratepairnum")){
-			CalcTrueQuality.USE_PAIRNUM=Tools.parseBoolean(b);
+			CalcTrueQuality.USE_PAIRNUM=Parse.parseBoolean(b);
 		}else if(a.equals("taxpath")){
 			if("auto".equalsIgnoreCase(b)){
 				TaxTree.TAX_PATH=TaxTree.defaultTaxPath();
@@ -666,38 +666,38 @@ public class Parser {
 				TaxTree.TAX_PATH=b.replaceAll("\\\\", "/");
 			}
 		}else if(a.equals("parallelsort")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			Shared.setParallelSort(x);
 		}else if(a.equals("gcbeforemem")){
-			Shared.GC_BEFORE_PRINT_MEMORY=Tools.parseBoolean(b);
+			Shared.GC_BEFORE_PRINT_MEMORY=Parse.parseBoolean(b);
 		}else if(a.equals("warnifnosequence")){
-			FastaReadInputStream.WARN_IF_NO_SEQUENCE=Tools.parseBoolean(b);
+			FastaReadInputStream.WARN_IF_NO_SEQUENCE=Parse.parseBoolean(b);
 		}else if(a.equals("warnfirsttimeonly")){
-			FastaReadInputStream.WARN_FIRST_TIME_ONLY=Tools.parseBoolean(b);
+			FastaReadInputStream.WARN_FIRST_TIME_ONLY=Parse.parseBoolean(b);
 		}else if(a.equals("silva")){
-			TaxTree.SILVA_MODE=Tools.parseBoolean(b);
+			TaxTree.SILVA_MODE=Parse.parseBoolean(b);
 		}else if(a.equals("unite")){
-			TaxTree.UNITE_MODE=Tools.parseBoolean(b);
+			TaxTree.UNITE_MODE=Parse.parseBoolean(b);
 		}else if(a.equals("parallelsort") || a.equals("paralellsort")){
-			Shared.parallelSort=Tools.parseBoolean(b);
+			Shared.parallelSort=Parse.parseBoolean(b);
 		}else if(a.equals("imghq")){
-			TaxTree.IMG_HQ=Tools.parseBoolean(b);
+			TaxTree.IMG_HQ=Parse.parseBoolean(b);
 		}
 		
 		else if(a.equals("callins") ||  a.equals("callinss")){
-			var2.Var.CALL_INS=Tools.parseBoolean(b);
+			var2.Var.CALL_INS=Parse.parseBoolean(b);
 		}else if(a.equals("calldel") || a.equals("calldels")){
-			var2.Var.CALL_DEL=Tools.parseBoolean(b);
+			var2.Var.CALL_DEL=Parse.parseBoolean(b);
 		}else if(a.equals("callsub") || a.equals("callsubs") || a.equals("callsnp") || a.equals("callsnps")){
-			var2.Var.CALL_SUB=Tools.parseBoolean(b);
+			var2.Var.CALL_SUB=Parse.parseBoolean(b);
 		}else if(a.equals("callindel") || a.equals("callindels")){
-			var2.Var.CALL_INS=var2.Var.CALL_DEL=Tools.parseBoolean(b);
+			var2.Var.CALL_INS=var2.Var.CALL_DEL=Parse.parseBoolean(b);
 		}else if(a.equals("calljunct") || a.equals("calljunction") || a.equals("calljunctions")){
-			var2.Var.CALL_JUNCTION=Tools.parseBoolean(b);
+			var2.Var.CALL_JUNCTION=Parse.parseBoolean(b);
 		}else if(a.equals("callnocall") || a.equals("callnocalls")){
-			var2.Var.CALL_NOCALL=Tools.parseBoolean(b);
+			var2.Var.CALL_NOCALL=Parse.parseBoolean(b);
 		}else if(a.equals("kmg") || a.equals("outputkmg")){
-			Shared.OUTPUT_KMG=Tools.parseBoolean(b);
+			Shared.OUTPUT_KMG=Parse.parseBoolean(b);
 		}
 		
 		else if(a.equals("tmpdir")){
@@ -709,21 +709,21 @@ public class Parser {
 		}
 		
 		else if(a.equals("fixextensions") || a.equals("fixextension") || a.equals("tryallextensions")){
-			Shared.FIX_EXTENSIONS=Tools.parseBoolean(b);
+			Shared.FIX_EXTENSIONS=Parse.parseBoolean(b);
 		}
 		
 		else if(a.equals("2passresize") || a.equals("twopassresize")){
-			AbstractKmerTable.TWO_PASS_RESIZE=Tools.parseBoolean(b);
+			AbstractKmerTable.TWO_PASS_RESIZE=Parse.parseBoolean(b);
 		}
 		
 		else if(a.equalsIgnoreCase("forceJavaParseDouble")){
-			Tools.FORCE_JAVA_PARSE_DOUBLE=Tools.parseBoolean(b);
+			Tools.FORCE_JAVA_PARSE_DOUBLE=Parse.parseBoolean(b);
 		}
 		
 		else if(a.equalsIgnoreCase("awsServers") || a.equalsIgnoreCase("aws")){
-			Shared.awsServers=Tools.parseBoolean(b);
+			Shared.awsServers=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("nerscServers") || a.equalsIgnoreCase("nersc")){
-			Shared.awsServers=!Tools.parseBoolean(b);
+			Shared.awsServers=!Parse.parseBoolean(b);
 		}
 		
 		else if(a.equals("entropyk") || a.equals("ek")){
@@ -743,7 +743,7 @@ public class Parser {
 	public static boolean parseQuality(String arg, String a, String b){
 		parsedQuality=true; //For internal verification that this function was indeed called.
 		if(a.equals("ignorebadquality") || a.equals("ibq")){
-			FASTQ.IGNORE_BAD_QUALITY=Tools.parseBoolean(b);
+			FASTQ.IGNORE_BAD_QUALITY=Parse.parseBoolean(b);
 			if(FASTQ.IGNORE_BAD_QUALITY){Read.CHANGE_QUALITY=false;}
 		}else if(a.equals("ascii") || a.equals("asciioffset") || a.equals("quality") || a.equals("qual")){
 			byte x;
@@ -773,7 +773,7 @@ public class Parser {
 		}else if(a.equals("fakefastaqual") || a.equals("fakefastaquality") || a.equals("ffq")){
 			if(b==null || b.length()<1){b="f";}
 			if(Character.isLetter(b.charAt(0))){
-				FastaReadInputStream.FAKE_QUALITY=Tools.parseBoolean(b);
+				FastaReadInputStream.FAKE_QUALITY=Parse.parseBoolean(b);
 			}else{
 				int x=Integer.parseInt(b);
 				if(x<1){
@@ -858,7 +858,7 @@ public class Parser {
 				ReadStats.GC_BINS_AUTO=false;
 			}
 		}else if(a.equals("gcchart") || a.equals("gcplot")){
-			ReadStats.GC_PLOT_X=Tools.parseBoolean(b);
+			ReadStats.GC_PLOT_X=Parse.parseBoolean(b);
 		}else if(a.equals("entropyhistogram") || a.equals("entropyhist") || a.equals("enhist") || a.equals("enthist")){
 			ReadStats.ENTROPY_HIST_FILE=(b==null || b.equalsIgnoreCase("null") || b.equalsIgnoreCase("none")) ? null : b;
 			ReadStats.COLLECT_ENTROPY_STATS=(ReadStats.ENTROPY_HIST_FILE!=null);
@@ -871,6 +871,8 @@ public class Parser {
 				ReadStats.ENTROPY_BINS=Integer.parseInt(b);
 //				ReadStats.ENTROPY_BINS_AUTO=false;
 			}
+		}else if(a.equals("entropyns") || a.equals("entropyhistns")){
+			ReadStats.allowEntropyNs=Parse.parseBoolean(b);
 		}else if(a.equals("timehistogram") || a.equals("thist")){
 			ReadStats.TIME_HIST_FILE=(b==null || b.equalsIgnoreCase("null") || b.equalsIgnoreCase("none")) ? null : b;
 			ReadStats.COLLECT_TIME_STATS=(ReadStats.TIME_HIST_FILE!=null);
@@ -890,11 +892,11 @@ public class Parser {
 		}
 		
 		else if(a.equals("maxhistlen")){
-			ReadStats.MAXLEN=ReadStats.MAXINSERTLEN=ReadStats.MAXLENGTHLEN=Tools.parseIntKMG(b);
+			ReadStats.MAXLEN=ReadStats.MAXINSERTLEN=ReadStats.MAXLENGTHLEN=Parse.parseIntKMG(b);
 		}
 		
 		else if(a.equals("fixindels") || a.equals("ignorevcfindels")){
-			CallVariants.fixIndels=Tools.parseBoolean(b);
+			CallVariants.fixIndels=Parse.parseBoolean(b);
 		}
 		
 		else{
@@ -915,9 +917,9 @@ public class Parser {
 				ReadWrite.BZIPLEVEL=Tools.min(x, 9);
 			}
 		}else if(a.equals("allowziplevelchange")){
-			ReadWrite.ALLOW_ZIPLEVEL_CHANGE=Tools.parseBoolean(b);
+			ReadWrite.ALLOW_ZIPLEVEL_CHANGE=Parse.parseBoolean(b);
 		}else if(a.equals("usegzip") || a.equals("gzip")){
-			ReadWrite.USE_GZIP=Tools.parseBoolean(b);
+			ReadWrite.USE_GZIP=Parse.parseBoolean(b);
 		}else if(a.equals("usebgzip") || a.equals("bgzip")){
 			
 			if(b!=null && Tools.isDigit(b.charAt(0))){
@@ -927,16 +929,16 @@ public class Parser {
 					ReadWrite.USE_BGZIP=true;
 					ReadWrite.MAX_ZIP_THREADS=zt;
 				}
-			}else{ReadWrite.USE_BGZIP=Tools.parseBoolean(b);}
+			}else{ReadWrite.USE_BGZIP=Parse.parseBoolean(b);}
 			if(ReadWrite.USE_BGZIP){ReadWrite.PREFER_BGZIP=true;}
 		}else if(a.equals("forcepigz")){
-			ReadWrite.FORCE_PIGZ=Tools.parseBoolean(b);
+			ReadWrite.FORCE_PIGZ=Parse.parseBoolean(b);
 			if(ReadWrite.FORCE_PIGZ){ReadWrite.USE_PIGZ=true;}
 		}else if(a.equals("forcebgzip")){
-			ReadWrite.FORCE_BGZIP=Tools.parseBoolean(b);
+			ReadWrite.FORCE_BGZIP=Parse.parseBoolean(b);
 			if(ReadWrite.FORCE_BGZIP){ReadWrite.USE_BGZIP=true;}
 		}else if(a.equals("preferbgzip")){
-			ReadWrite.PREFER_BGZIP=Tools.parseBoolean(b);
+			ReadWrite.PREFER_BGZIP=Parse.parseBoolean(b);
 		}else if(a.equals("zipthreads")){
 			ReadWrite.MAX_ZIP_THREADS=Integer.parseInt(b);
 		}else if(a.equals("usepigz") || a.equals("pigz")){
@@ -947,7 +949,7 @@ public class Parser {
 					ReadWrite.USE_PIGZ=true;
 					ReadWrite.MAX_ZIP_THREADS=zt;
 				}
-			}else{ReadWrite.USE_PIGZ=Tools.parseBoolean(b);}
+			}else{ReadWrite.USE_PIGZ=Parse.parseBoolean(b);}
 		}else if(a.equals("zipthreaddivisor") || a.equals("ztd")){
 			ReadWrite.setZipThreadMult(1/Float.parseFloat(b));
 		}else if(a.equals("blocksize")){
@@ -957,19 +959,19 @@ public class Parser {
 			int x=Integer.parseInt(b);
 			ReadWrite.PIGZ_ITERATIONS=Tools.mid(32, x, 1024);
 		}else if(a.equals("usegunzip") || a.equals("gunzip") || a.equals("ungzip")){
-			ReadWrite.USE_GUNZIP=Tools.parseBoolean(b);
+			ReadWrite.USE_GUNZIP=Parse.parseBoolean(b);
 		}else if(a.equals("useunpigz") || a.equals("unpigz")){
-			ReadWrite.USE_UNPIGZ=Tools.parseBoolean(b);
+			ReadWrite.USE_UNPIGZ=Parse.parseBoolean(b);
 		}else if(a.equals("useunbgzip") || a.equals("unbgzip")){
-			ReadWrite.USE_UNBGZIP=ReadWrite.PREFER_UNBGZIP=Tools.parseBoolean(b);
+			ReadWrite.USE_UNBGZIP=ReadWrite.PREFER_UNBGZIP=Parse.parseBoolean(b);
 		}else if(a.equals("preferunbgzip")){
-			ReadWrite.PREFER_UNBGZIP=Tools.parseBoolean(b);
+			ReadWrite.PREFER_UNBGZIP=Parse.parseBoolean(b);
 		}else if(a.equals("usebzip2") || a.equals("bzip2")){
-			ReadWrite.USE_BZIP2=Tools.parseBoolean(b);
+			ReadWrite.USE_BZIP2=Parse.parseBoolean(b);
 		}else if(a.equals("usepbzip2") || a.equals("pbzip2")){
-			ReadWrite.USE_PBZIP2=Tools.parseBoolean(b);
+			ReadWrite.USE_PBZIP2=Parse.parseBoolean(b);
 		}else if(a.equals("uselbzip2") || a.equals("lbzip2")){
-			ReadWrite.USE_LBZIP2=Tools.parseBoolean(b);
+			ReadWrite.USE_LBZIP2=Parse.parseBoolean(b);
 		}else{
 			return false;
 		}
@@ -981,58 +983,58 @@ public class Parser {
 			assert(b!=null) : "The sam flag requires a version number, e.g. 'sam=1.4'";
 			SamLine.VERSION=Float.parseFloat(b);
 		}else if(a.equals("sambamba")){
-			Data.USE_SAMBAMBA=Tools.parseBoolean(b);
+			Data.USE_SAMBAMBA=Parse.parseBoolean(b);
 		}else if(a.equals("samtools")){
-			Data.USE_SAMTOOLS=Tools.parseBoolean(b);
+			Data.USE_SAMTOOLS=Parse.parseBoolean(b);
 		}else if(a.equals("streamerthreads")){
 			SamStreamer.DEFAULT_THREADS=Integer.parseInt(b);
 		}else if(a.equals("prefermd") || a.equals("prefermdtag")){
-			SamLine.PREFER_MDTAG=Tools.parseBoolean(b);
+			SamLine.PREFER_MDTAG=Parse.parseBoolean(b);
 		}else if(a.equals("notags")){
-			SamLine.NO_TAGS=Tools.parseBoolean(b);
+			SamLine.NO_TAGS=Parse.parseBoolean(b);
 		}else if(a.equals("mdtag") || a.equals("md")){
-			SamLine.MAKE_MD_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_MD_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("idtag")){
-			SamLine.MAKE_IDENTITY_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_IDENTITY_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("xmtag") || a.equals("xm")){
-			SamLine.MAKE_XM_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_XM_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("smtag")){
-			SamLine.MAKE_SM_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_SM_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("amtag")){
-			SamLine.MAKE_AM_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_AM_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("nmtag")){
-			SamLine.MAKE_NM_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_NM_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("stoptag")){
-			SamLine.MAKE_STOP_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_STOP_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("lengthtag")){
-			SamLine.MAKE_LENGTH_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_LENGTH_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("boundstag")){
-			SamLine.MAKE_BOUNDS_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_BOUNDS_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("scoretag")){
-			SamLine.MAKE_SCORE_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_SCORE_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("sortscaffolds")){
-			SamLine.SORT_SCAFFOLDS=Tools.parseBoolean(b);
+			SamLine.SORT_SCAFFOLDS=Parse.parseBoolean(b);
 		}else if(a.equals("customtag")){
-			SamLine.MAKE_CUSTOM_TAGS=Tools.parseBoolean(b);
+			SamLine.MAKE_CUSTOM_TAGS=Parse.parseBoolean(b);
 		}else if(a.equals("nhtag")){
-			SamLine.MAKE_NH_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_NH_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("keepnames")){
-			SamLine.KEEP_NAMES=Tools.parseBoolean(b);
+			SamLine.KEEP_NAMES=Parse.parseBoolean(b);
 		}else if(a.equals("saa") || a.equals("secondaryalignmentasterisks")){
-			SamLine.SECONDARY_ALIGNMENT_ASTERISKS=Tools.parseBoolean(b);
+			SamLine.SECONDARY_ALIGNMENT_ASTERISKS=Parse.parseBoolean(b);
 		}else if(a.equals("inserttag")){
-			SamLine.MAKE_INSERT_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_INSERT_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("correctnesstag")){
-			SamLine.MAKE_CORRECTNESS_TAG=Tools.parseBoolean(b);
+			SamLine.MAKE_CORRECTNESS_TAG=Parse.parseBoolean(b);
 		}else if(a.equals("intronlen") || a.equals("intronlength")){
 			SamLine.INTRON_LIMIT=Integer.parseInt(b);
 			SamLine.setintron=true;
 		}else if(a.equals("suppressheader") || a.equals("noheader")){
-			ReadStreamWriter.NO_HEADER=Tools.parseBoolean(b);
+			ReadStreamWriter.NO_HEADER=Parse.parseBoolean(b);
 		}else if(a.equals("noheadersequences") || a.equals("nhs") || a.equals("suppressheadersequences")){
-			ReadStreamWriter.NO_HEADER_SEQUENCES=Tools.parseBoolean(b);
+			ReadStreamWriter.NO_HEADER_SEQUENCES=Parse.parseBoolean(b);
 		}else if(a.equals("tophat")){
-			if(Tools.parseBoolean(b)){
+			if(Parse.parseBoolean(b)){
 				SamLine.MAKE_TOPHAT_TAGS=true;
 				FastaReadInputStream.FAKE_QUALITY=true;
 				Shared.FAKE_QUAL=40;
@@ -1050,12 +1052,12 @@ public class Parser {
 				}else if(b.equals("us") || b.equals("unstranded")){
 					SamLine.XS_SECONDSTRAND=false;
 				}else{
-					SamLine.MAKE_XS_TAG=Tools.parseBoolean(b);
+					SamLine.MAKE_XS_TAG=Parse.parseBoolean(b);
 				}
 			}
 			SamLine.setxs=true;
 		}else if(a.equals("flipsam")){
-			SamLine.FLIP_ON_LOAD=Tools.parseBoolean(b);
+			SamLine.FLIP_ON_LOAD=Parse.parseBoolean(b);
 		}else if(parseReadgroup(arg, a, b)){
 			//do nothing
 		}else{
@@ -1071,11 +1073,11 @@ public class Parser {
 		}else if(a.equals("fastaminread") || a.equals("fastaminlen") || a.equals("fastaminlength")){
 			FastaReadInputStream.MIN_READ_LEN=Integer.parseInt(b);
 		}else if(a.equals("forcesectionname")){
-			FastaReadInputStream.FORCE_SECTION_NAME=Tools.parseBoolean(b);
+			FastaReadInputStream.FORCE_SECTION_NAME=Parse.parseBoolean(b);
 		}else if(a.equals("fastawrap") || a.equals("wrap")){
-			Shared.FASTA_WRAP=Tools.parseIntKMG(b);
+			Shared.FASTA_WRAP=Parse.parseIntKMG(b);
 		}else if(a.equals("fastadump")){
-			AbstractKmerTable.FASTA_DUMP=Tools.parseBoolean(b);
+			AbstractKmerTable.FASTA_DUMP=Parse.parseBoolean(b);
 		}else{
 			return false;
 		}
@@ -1090,9 +1092,9 @@ public class Parser {
 		}
 		
 		if(a.equals("trackall")){
-			CalcTrueQuality.TRACK_ALL=Tools.parseBoolean(b);
+			CalcTrueQuality.TRACK_ALL=Parse.parseBoolean(b);
 		}else if(a.equals("clearmatrices")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			if(x){
 				CalcTrueQuality.use_q102=new boolean[] {false, false};
 				CalcTrueQuality.use_qap=new boolean[] {false, false};
@@ -1108,31 +1110,31 @@ public class Parser {
 				CalcTrueQuality.use_q=new boolean[] {false, false};
 			}
 		}else if(a.equals("loadq102")){
-			CalcTrueQuality.use_q102[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_q102[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadqap")){
-			CalcTrueQuality.use_qap[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_qap[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadqbp")){
-			CalcTrueQuality.use_qbp[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_qbp[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadq10")){
-			CalcTrueQuality.use_q10[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_q10[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadq12")){
-			CalcTrueQuality.use_q12[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_q12[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadqb12")){
-			CalcTrueQuality.use_qb12[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_qb12[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadqb012")){
-			CalcTrueQuality.use_qb012[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_qb012[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadqb123")){
-			CalcTrueQuality.use_qb123[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_qb123[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadqb234")){
-			CalcTrueQuality.use_qb234[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_qb234[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadq12b12")){
-			CalcTrueQuality.use_q12b12[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_q12b12[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadqp")){
-			CalcTrueQuality.use_qp[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_qp[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("loadq")){
-			CalcTrueQuality.use_q[pass]=Tools.parseBoolean(b);
+			CalcTrueQuality.use_q[pass]=Parse.parseBoolean(b);
 		}else if(a.equals("observationcutoff")){
-			long x=Tools.parseIntKMG(b);
+			long x=Parse.parseIntKMG(b);
 			CalcTrueQuality.OBSERVATION_CUTOFF[pass]=x;
 		}else if(a.equals("recalpasses")){
 			CalcTrueQuality.passes=Integer.parseInt(b);
@@ -1144,7 +1146,7 @@ public class Parser {
 			int x=Tools.mid(0, Integer.parseInt(b), 93);
 			Read.setMinCalledQuality(Tools.min(x, Read.MIN_CALLED_QUALITY()));
 		}else if(a.equals("recalwithposition") || a.equals("recalwithpos") || a.equals("recalusepos")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			if(!x){
 				Arrays.fill(CalcTrueQuality.use_qp, false);
 				Arrays.fill(CalcTrueQuality.use_qbp, false);
