@@ -28,8 +28,8 @@ public class Shared {
 	//https://stackoverflow.com/questions/14288185/detecting-windows-or-linux
 	public static boolean LINUX=envContainsPair("OS", "nix", true) || envContainsPair("OS", "nux", true) || envContainsPair("OS", "aix", true);
 	public static boolean SOLARIS=envContainsPair("OS", "sunos", true);
-	public static boolean GENEPOOL=envContainsPair("NERSC_HOST", "genepool", false);
-	public static boolean DENOVO=envContainsPair("NERSC_HOST", "denovo", false);
+	public static boolean GENEPOOL=envContainsPair("NERSC_HOST", "genepool", false);//Probably deprecated
+	public static boolean DENOVO=envContainsPair("NERSC_HOST", "denovo", false);//Almost certainly deprecated
 	public static boolean CORI=envContainsPair("NERSC_HOST", "cori", false);
 	public static boolean NERSC=envContainsKey("NERSC_HOST");
 	public static boolean AWS=envContainsKey("EC2_HOME");
@@ -124,8 +124,8 @@ public class Shared {
 	public static final int GAPCOST=Tools.max(1, GAPLEN/64);
 	public static final byte GAPC='-';
 	
-	public static String BBMAP_VERSION_STRING="38.79";
-	public static String BBMAP_VERSION_NAME="Static Silence";
+	public static String BBMAP_VERSION_STRING="38.90";
+	public static String BBMAP_VERSION_NAME="Byte Safety";
 	
 	public static boolean TRIM_READ_COMMENTS=false;
 	public static boolean TRIM_RNAME=false; //For mapped sam reads
