@@ -10,6 +10,7 @@ import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -116,7 +117,7 @@ public class AnalyzeSketchResults {
 			}else if(a.equals("tree")){
 				treeFile=b;
 			}else if(a.equals("shrinkonly")){
-				shrinkOnly=Tools.parseBoolean(b);
+				shrinkOnly=Parse.parseBoolean(b);
 			}else if(a.equals("ssu") || a.equals("ssufile")){
 				assert(false) : "ssu and ssufile are deprecated; please specify 16S or 18S independently";
 			}else if(a.equalsIgnoreCase("16S") || a.equalsIgnoreCase("16Sfile")){
@@ -137,7 +138,7 @@ public class AnalyzeSketchResults {
 			}else if(a.equals("minsamples")){
 				minSamples=Integer.parseInt(b);
 			}else if(a.equals("verbose")){
-				RecordSet.verbose=Record.verbose=verbose=Tools.parseBoolean(b);
+				RecordSet.verbose=Record.verbose=verbose=Parse.parseBoolean(b);
 			}else if(parser.parse(arg, a, b)){
 				//do nothing
 			}else{
@@ -481,7 +482,7 @@ public class AnalyzeSketchResults {
 	int minSamples=1;
 	private long maxLines=Long.MAX_VALUE;
 	
-	final static int taxLevels=TaxTree.numTaxaNamesExtended;
+	final static int taxLevels=TaxTree.numTaxLevelNamesExtended;
 
 	final HashMap<Long, Float> aniMap=new HashMap<Long, Float>();
 	final HashMap<Long, Float> aaiMap=new HashMap<Long, Float>();
