@@ -15,6 +15,7 @@ import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -107,11 +108,11 @@ public class BlacklistMaker extends SketchObject {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}
 			
@@ -131,9 +132,9 @@ public class BlacklistMaker extends SketchObject {
 			
 			
 			else if(a.equals("mincount") || a.equals("mintaxcount")){
-				minTaxCount=Tools.parseIntKMG(b);
+				minTaxCount=Parse.parseIntKMG(b);
 			}else if(a.equals("prefilter")){
-				prefilter=Tools.parseBoolean(b);
+				prefilter=Parse.parseBoolean(b);
 			}else if(a.equals("prepasses") || a.equals("passes")){
 				assert(b!=null) : "Bad parameter: "+arg;
 				if(b.equalsIgnoreCase("auto")){
