@@ -14,6 +14,7 @@ import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import kmer.HashArrayHybridFast;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -99,14 +100,14 @@ public class BlacklistMaker2 extends SketchObject {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parseMode(arg, a, b)>-1){
 				mode_=parseMode(arg, a, b);
 			}else if(a.equals("tossjunk")){
-				tossJunk=Tools.parseBoolean(b);
+				tossJunk=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("taxtree") || a.equals("tree")){
@@ -117,9 +118,9 @@ public class BlacklistMaker2 extends SketchObject {
 			
 			
 			else if(a.equals("mincount") || a.equals("mintaxcount")){
-				minTaxCount=Tools.parseIntKMG(b);
+				minTaxCount=Parse.parseIntKMG(b);
 			}else if(a.equals("maxkeys") || a.equals("keys") || a.equals("length") || a.equals("size")){
-				maxKeys=Tools.parseIntKMG(b);
+				maxKeys=Parse.parseIntKMG(b);
 			}else if(a.equals("name")){
 				outName=b;
 			}else if(a.equalsIgnoreCase("name0") || a.equalsIgnoreCase("nm0")){
