@@ -13,6 +13,7 @@ import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import kmer.AbstractKmerTableSet;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -99,24 +100,26 @@ public class CompareSketch extends SketchObject {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("in")){
 				addFiles(b, in);
 			}else if(parseSketchFlags(arg, a, b)){
 				//Do nothing
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("alltoall") || a.equals("ata")){
-				allToAll=Tools.parseBoolean(b);
+				allToAll=Parse.parseBoolean(b);
 			}else if(a.equals("skipcompare") || a.equals("sketchonly")){
-				skipCompare=Tools.parseBoolean(b);
+				skipCompare=Parse.parseBoolean(b);
 			}else if(a.equals("compareself") || a.equals("includeself")){
-				compareSelf=Tools.parseBoolean(b);
+				compareSelf=Parse.parseBoolean(b);
 			}else if(a.equals("printmemory")){
-				printMemory=Tools.parseBoolean(b);
+				printMemory=Parse.parseBoolean(b);
+			}else if(a.equals("parsesubunit")){
+				SketchMaker.parseSubunit=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("taxtree") || a.equals("tree")){
@@ -276,6 +279,17 @@ public class CompareSketch extends SketchObject {
 					if(outTaxName!=null){sk.setTaxName(outTaxName);}
 					if(outFname!=null){sk.setFname(outFname);}
 					if(outName0!=null){sk.setName0(outName0);}
+					if(SketchMaker.parseSubunit && sk.name0()!=null){
+						if(outMeta!=null){
+							sk.meta=(ArrayList<String>)sk.meta.clone();
+						}else if(sk.meta==null){
+							if(sk.name0().contains("SSU_")){
+								sk.addMeta("subunit:ssu");
+							}else if(sk.name0().contains("LSU_")){
+								sk.addMeta("subunit:lsu");
+							}
+						}
+					}
 					sk.setMeta(outMeta);
 					if(defaultParams.printSSU()){sk.loadSSU();}//since taxID was just set
 				}
