@@ -11,6 +11,7 @@ import dna.AminoAcid;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -97,28 +98,28 @@ public class KmerLimit2 extends SketchObject {
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("size") || a.equals("heapsize")){
-				heapSize_=Tools.parseIntKMG(b);
+				heapSize_=Parse.parseIntKMG(b);
 				setHeapSize=true;
 			}else if(a.equals("kmers") || a.equals("target") || a.equals("limit")){
-				targetKmers_=Tools.parseKMG(b);
+				targetKmers_=Parse.parseKMG(b);
 			}else if(a.equals("mincount")){
-				minCount_=Tools.parseIntKMG(b);
+				minCount_=Parse.parseIntKMG(b);
 			}else if(a.equals("maxexpandedlength") || a.equals("maxlength") || a.equals("maxlen")){
-				maxExpandedLength=Tools.parseIntKMG(b);
+				maxExpandedLength=Parse.parseIntKMG(b);
 			}else if(a.equals("seed")){
-				seed=Tools.parseKMG(b);
+				seed=Parse.parseKMG(b);
 			}else if(a.equals("trials")){
-				trials=Tools.parseIntKMG(b);
+				trials=Parse.parseIntKMG(b);
 			}else if(parseSketchFlags(arg, a, b)){
 				parser.parse(arg, a, b);
 			}else if(defaultParams.parse(arg, a, b)){
 				parser.parse(arg, a, b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
