@@ -13,6 +13,7 @@ import fileIO.TextStreamWriter;
 import kmer.AbstractKmerTableSet;
 import server.ServerTools;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -100,7 +101,7 @@ public class SendSketch extends SketchObject {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("in")){
 				addFiles(b, in);
 			}else if(a.equals("blacklist") || a.equalsIgnoreCase("bl")){
@@ -111,19 +112,19 @@ public class SendSketch extends SketchObject {
 			}else if(defaultParams.parse(arg, a, b)){
 				//Do nothing
 			}else if(a.equals("local")){
-				local=Tools.parseBoolean(b);
+				local=Parse.parseBoolean(b);
 				setLocal=true;
 			}else if(a.equals("refid") || a.equals("refids") || a.equals("refname") || a.equals("refnames")){
 				refNames=b;
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(a.equals("address")){
 				assert(b!=null) : "Bad parameter: "+arg;
 				address=b;
 			}
 //			else if(a.equals("alternateaddress") || a.equals("altaddress") || a.equalsIgnoreCase("vm")){
-//				boolean alt=Tools.parseBoolean(b);
+//				boolean alt=Parse.parseBoolean(b);
 //				switchDefaultAddresses(alt);
 //			}
 			
