@@ -9,6 +9,7 @@ import java.util.concurrent.atomic.AtomicInteger;
 
 import dna.AminoAcid;
 import fileIO.ReadWrite;
+import shared.KillSwitch;
 import shared.Tools;
 import structures.AbstractBitSet;
 import structures.ByteBuilder;
@@ -699,7 +700,7 @@ public class Sketch extends SketchObject implements Comparable<Sketch>, Cloneabl
 		toHeader(bb);
 		bb.append("\n");
 		byte[] temp=null;
-		if(CODING==A48){temp=new byte[12];}
+		if(CODING==A48){temp=KillSwitch.allocByte1D(12);}
 		for(int i=0; i<keys.length; i++){
 			long key=keys[i];
 			int count=(keyCounts==null ? 1 : keyCounts[i]);
@@ -729,7 +730,7 @@ public class Sketch extends SketchObject implements Comparable<Sketch>, Cloneabl
 		long prev=0;
 		toHeader(bb);
 		bb.append("\n");
-		final byte[] temp=new byte[12];
+		final byte[] temp=KillSwitch.allocByte1D(12);
 
 		if(keyCounts==null){
 			for(int i=0; i<keys.length; i++){
