@@ -14,6 +14,7 @@ import prok.CallGenes;
 import prok.GeneCaller;
 import prok.Orf;
 import prok.ProkObject;
+import shared.Parse;
 import shared.Tools;
 import stream.ConcurrentReadInputStream;
 import stream.Read;
@@ -448,7 +449,7 @@ public class SketchMakerMini extends SketchObject {
 	boolean looksLikePacBio(Read r){
 		if(r.length()<302 || r.mate!=null){return false;}
 		if(r.quality==null){
-			int x=Tools.parseZmw(r.id);
+			int x=Parse.parseZmw(r.id);
 			return x>=0;
 		}
 		int positive=0;
