@@ -14,6 +14,7 @@ import prok.GeneCaller;
 import prok.GeneModel;
 import prok.GeneModelParser;
 import prok.ProkObject;
+import shared.Parse;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -58,27 +59,27 @@ public class SketchObject {
 			}
 			setK=true;
 		}else if(a.equalsIgnoreCase("rcomp")){
-			rcomp=Tools.parseBoolean(b);
+			rcomp=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("minfakeid")){
 			minFakeID=Integer.parseInt(b);
 		}else if(a.equalsIgnoreCase("hashNames")){
-			hashNames=Tools.parseBoolean(b);
+			hashNames=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("preferSSUMap")){
-			preferSSUMap=Tools.parseBoolean(b);
+			preferSSUMap=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("preferSSUMapForEuks") || a.equalsIgnoreCase("preferSSUMapEuks")){
-			preferSSUMapForEuks=Tools.parseBoolean(b);
+			preferSSUMapForEuks=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("useSSUMapOnly")){
-			useSSUMapOnly=Tools.parseBoolean(b);
+			useSSUMapOnly=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("useSSUMapOnlyForEuks") || a.equalsIgnoreCase("SSUMapOnlyEuks")){
-			useSSUMapOnlyForEuks=Tools.parseBoolean(b);
+			useSSUMapOnlyForEuks=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("skipNonCanonical")){
-			skipNonCanonical=Tools.parseBoolean(b);
+			skipNonCanonical=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("useSizeEstimateInScore") || a.equalsIgnoreCase("useSizeEstimate")){
-			useSizeEstimate=Tools.parseBoolean(b);
+			useSizeEstimate=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("blacklist") || a.equalsIgnoreCase("bl")){
 			blacklist=b;
 		}else if(a.equalsIgnoreCase("whitelist") || a.equalsIgnoreCase("usewhitelist")){
-			useWhitelist=Tools.parseBoolean(b);
+			useWhitelist=Parse.parseBoolean(b);
 		}
 		
 		else if(a.equalsIgnoreCase("sampleseed")){
@@ -97,7 +98,7 @@ public class SketchObject {
 			}else{
 				AUTOSIZE=false;
 				AUTOSIZE_LINEAR=false;
-				targetSketchSize=Tools.parseIntKMG(b);
+				targetSketchSize=Parse.parseIntKMG(b);
 				SET_TARGET_SIZE=true;
 			}
 		}else if(a.equalsIgnoreCase("maxfraction") || a.equalsIgnoreCase("maxgenomefraction") || a.equalsIgnoreCase("mgf")){
@@ -107,7 +108,7 @@ public class SketchObject {
 		}else if(a.equalsIgnoreCase("minSketchSize")){
 			minSketchSize=Tools.max(1, Integer.parseInt(b));
 		}else if(a.equalsIgnoreCase("autosize")){
-			AUTOSIZE=Tools.parseBoolean(b);
+			AUTOSIZE=Parse.parseBoolean(b);
 			if(AUTOSIZE){AUTOSIZE_LINEAR=false;}
 			SET_AUTOSIZE=true;
 		}else if(a.equalsIgnoreCase("autosizefactor") || a.equalsIgnoreCase("autosizefraction") || a.equalsIgnoreCase("autosizemult") || a.equalsIgnoreCase("sizemult")){
@@ -122,7 +123,7 @@ public class SketchObject {
 				AUTOSIZE=false;
 				SET_AUTOSIZE=true;
 			}else{
-				AUTOSIZE_LINEAR=Tools.parseBoolean(b);
+				AUTOSIZE_LINEAR=Parse.parseBoolean(b);
 				if(AUTOSIZE_LINEAR){AUTOSIZE=false;}
 				SET_AUTOSIZE=true;
 			}
@@ -133,7 +134,7 @@ public class SketchObject {
 			setKeyFraction(d);
 		}else if(a.equalsIgnoreCase("prealloc")){
 			if(b==null || Character.isLetter(b.charAt(0))){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					prealloc=1.0f;
 				}else{
 					prealloc=0;
@@ -144,9 +145,9 @@ public class SketchObject {
 		}
 		
 		else if(a.equalsIgnoreCase("intmap")){
-			SketchIndex.useIntMap=Tools.parseBoolean(b);
+			SketchIndex.useIntMap=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("intmapsize")){
-			SketchIndex.intMapSize=Tools.parseIntKMG(b);
+			SketchIndex.intMapSize=Parse.parseIntKMG(b);
 		}else if(a.equalsIgnoreCase("bitsetbits")){
 			assert(false) : "bitsetbits should be 2.";
 //			bitSetBits=Integer.parseInt(b);
@@ -160,53 +161,53 @@ public class SketchObject {
 		}
 		
 		else if(a.equalsIgnoreCase("killok")){
-			KILL_OK=Tools.parseBoolean(b);
+			KILL_OK=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("ssa") || a.equalsIgnoreCase("usessa")){
-			useSSA=Tools.parseBoolean(b);
+			useSSA=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("ssa3") || a.equalsIgnoreCase("usessa3")){
-			useSSA3=Tools.parseBoolean(b);
+			useSSA3=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("exactani")){
-			EXACT_ANI=Tools.parseBoolean(b);
+			EXACT_ANI=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("translate") || a.equalsIgnoreCase("callgenes")){
-			translate=Tools.parseBoolean(b);
+			translate=Parse.parseBoolean(b);
 			defaultParams.translate=translate;
 		}else if(a.equalsIgnoreCase("sixframes") || a.equalsIgnoreCase("6frames")){
-			sixframes=Tools.parseBoolean(b);
+			sixframes=Parse.parseBoolean(b);
 			defaultParams.sixframes=sixframes;
 			if(sixframes){
 				translate=defaultParams.translate=true;
 			}
 		}else if(a.equalsIgnoreCase("processSSU") || a.equalsIgnoreCase("process16S") || a.equalsIgnoreCase("16S") || a.equalsIgnoreCase("SSU")){
-			processSSU=Tools.parseBoolean(b);
+			processSSU=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("hashSeed")){
 			hashSeed=Long.parseLong(b);
 			//remakeCodes(hashSeed); //Happens in postParse
 		}
 		
 		else if(a.equalsIgnoreCase("forceDisableMultithreadedFastq")){
-			forceDisableMultithreadedFastq=Tools.parseBoolean(b);
+			forceDisableMultithreadedFastq=Parse.parseBoolean(b);
 		}
 		
 		else if(a.equalsIgnoreCase("verifyentropy")){
-			EntropyTracker.verify=Tools.parseBoolean(b);
+			EntropyTracker.verify=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("entropyK")){
 			entropyK=Integer.parseInt(b);
 		}else if(a.equalsIgnoreCase("fastentropy") || a.equalsIgnoreCase("fentropy")){
-			if(Tools.parseBoolean(b)){EntropyTracker.speed=EntropyTracker.FAST;}
+			if(Parse.parseBoolean(b)){EntropyTracker.speed=EntropyTracker.FAST;}
 		}else if(a.equalsIgnoreCase("mediumentropy") || a.equalsIgnoreCase("mentropy")){
-			if(Tools.parseBoolean(b)){EntropyTracker.speed=EntropyTracker.MEDIUM;}
+			if(Parse.parseBoolean(b)){EntropyTracker.speed=EntropyTracker.MEDIUM;}
 		}else if(a.equalsIgnoreCase("slowentropy") || a.equalsIgnoreCase("sentropy")){
-			if(Tools.parseBoolean(b)){EntropyTracker.speed=EntropyTracker.SLOW;}
+			if(Parse.parseBoolean(b)){EntropyTracker.speed=EntropyTracker.SLOW;}
 		}else if(a.equalsIgnoreCase("superslowentropy") || a.equalsIgnoreCase("ssentropy")){
-			if(Tools.parseBoolean(b)){EntropyTracker.speed=EntropyTracker.SUPERSLOW;}
+			if(Parse.parseBoolean(b)){EntropyTracker.speed=EntropyTracker.SUPERSLOW;}
 		}else if(a.equalsIgnoreCase("verbose2")){
-			verbose2=Tools.parseBoolean(b);
+			verbose2=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("loadSketchesFromSketchFile2")){
-			LOADER2=Tools.parseBoolean(b);
+			LOADER2=Parse.parseBoolean(b);
 		}
 		
 		else if(a.equalsIgnoreCase("useToValue2") || a.equalsIgnoreCase("ToValue2")){
-			useToValue2=Tools.parseBoolean(b);
+			useToValue2=Parse.parseBoolean(b);
 		}else if(a.equals("ssu") || a.equals("ssufile")){
 			assert(false) : "ssufile is deprecated; please specify 16Sfile and/or 18Sfile independently";
 		}else if(a.equalsIgnoreCase("16Sfile")/* || a.equalsIgnoreCase("ssufile") || a.equalsIgnoreCase("silvafile")*/){
@@ -231,17 +232,17 @@ public class SketchObject {
 	
 	private static boolean parseCoding(String arg, String a, String b){
 		if(a.equalsIgnoreCase("deltaout") || a.equalsIgnoreCase("delta")){
-			deltaOut=Tools.parseBoolean(b);
+			deltaOut=Parse.parseBoolean(b);
 		}else if(a.equalsIgnoreCase("a33") || a.equalsIgnoreCase("a48")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			if(x){CODING=A48;}
 			else if(CODING==A48){CODING=HEX;}
 		}else if(a.equalsIgnoreCase("hex")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			if(x){CODING=HEX;}
 			else if(CODING==HEX){CODING=A48;}
 		}else if(a.equalsIgnoreCase("raw")){
-			boolean x=Tools.parseBoolean(b);
+			boolean x=Parse.parseBoolean(b);
 			if(x){CODING=RAW;}
 			else if(CODING==RAW){CODING=A48;}
 		}else{
