@@ -77,7 +77,7 @@ public class SketchResults extends SketchObject {
 		
 		//Apply records per level filter
 		if(params.recordsPerLevel>0 && al.size()>params.recordsPerLevel && al.get(0).hasQueryTaxID()){
-			int[] count=new int[TaxTree.numTaxaNamesExtended];
+			int[] count=new int[TaxTree.numTaxLevelNamesExtended];
 			int removed=0;
 			for(int i=0; i<al.size(); i++){
 				Comparison c=al.get(i);
