@@ -12,6 +12,7 @@ import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -91,20 +92,20 @@ public class Shuffle2 {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("verbose2")){
 				assert(false) : "Verbose2 is disabled.";
-//				verbose2=Tools.parseBoolean(b);
+//				verbose2=Parse.parseBoolean(b);
 			}else if(a.equals("delete")){
-				delete=Tools.parseBoolean(b);
+				delete=Parse.parseBoolean(b);
 			}else if(a.equals("allowtemp") || a.equals("usetemp")){
-				allowTempFiles=Tools.parseBoolean(b);
+				allowTempFiles=Parse.parseBoolean(b);
 			}else if(a.equals("memmult") || a.equals("mult")){
 				memMult=(float) Double.parseDouble(b);
 			}else if(a.equals("ascending")){
-				ascending=Tools.parseBoolean(b);
+				ascending=Parse.parseBoolean(b);
 			}else if(a.equals("descending")){
-				ascending=!Tools.parseBoolean(b);
+				ascending=!Parse.parseBoolean(b);
 			}else if(a.equals("maxfiles") || a.equals("files")){
 				maxFiles=Integer.parseInt(b);
 			}else if(a.equals("parse_flag_goes_here")){
