@@ -11,6 +11,7 @@ import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -95,54 +96,54 @@ public class SortByName {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("verbose2")){
 				assert(false) : "Verbose2 is disabled.";
-//				verbose2=Tools.parseBoolean(b);
+//				verbose2=Parse.parseBoolean(b);
 			}else if(a.equals("delete")){
-				delete=Tools.parseBoolean(b);
+				delete=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("deleteearly")){
-				deleteEarly=Tools.parseBoolean(b);
+				deleteEarly=Parse.parseBoolean(b);
 			}else if(a.equals("allowtemp") || a.equals("usetemp")){
-				allowTempFiles=Tools.parseBoolean(b);
+				allowTempFiles=Parse.parseBoolean(b);
 			}else if(a.equals("memmult") || a.equals("mult")){
 				memMult=(float) Double.parseDouble(b);
 			}else if(a.equals("ascending")){
-				ascending=Tools.parseBoolean(b);
+				ascending=Parse.parseBoolean(b);
 			}else if(a.equals("descending")){
-				ascending=!Tools.parseBoolean(b);
+				ascending=!Parse.parseBoolean(b);
 			}else if(a.equals("length")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					comparator=ReadLengthComparator.comparator;
 				}
 			}else if(a.equals("name")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					comparator=ReadComparatorName.comparator;
 				}
 			}else if(a.equals("quality")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					comparator=ReadQualityComparator.comparator;
 				}
 			}else if(a.equals("position")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					comparator=ReadComparatorPosition.comparator;
 				}
 			}else if(a.equals("list") || a.equals("names")){
 				comparator=new ReadComparatorList(b);
 			}else if(a.equals("random") || a.equals("shuffle")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					comparator=ReadComparatorRandom.comparator;
 				}
 			}else if(a.equals("taxa")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					comparator=ReadComparatorTaxa.comparator;
 				}
 			}else if(a.equals("topo") || a.equals("topological") || a.equals("alphabetic") || a.equals("sequence") || a.equals("lexographic")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					comparator=ReadComparatorTopological.comparator;
 				}
 			}else if(a.equals("flowcell")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					comparator=ReadComparatorFlowcell.comparator;
 				}
 			}else if(a.equals("table") || a.equals("gi") || a.equals("gitable")){
