@@ -7,6 +7,7 @@ import java.util.concurrent.TimeUnit;
 
 import dna.Data;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Timer;
@@ -47,7 +48,7 @@ public class ConcurrentGenericReadInputStream extends ConcurrentReadInputStream
 			}else if(Parser.parseFasta(arg, a, b)){
 				//do nothing
 			}else if(a.equals("reads") || a.startsWith("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else{
 				throw new RuntimeException("Unknown parameter "+args[i]);
 			}
