@@ -1,7 +1,6 @@
 package structures;
 
 import java.io.Serializable;
-import java.util.Arrays;
 
 import dna.AminoAcid;
 import shared.KillSwitch;
@@ -21,17 +20,17 @@ public final class ByteBuilder implements Serializable, CharSequence {
 	private static final long serialVersionUID = -4786450129730831665L;
 	
 	public ByteBuilder(){
-		array=new byte[32];
+		array=KillSwitch.allocByte1D(32);
 	}
 	
 	public ByteBuilder(int initial){
 		assert(initial>=1);
-		array=new byte[initial];
+		array=KillSwitch.allocByte1D(initial);
 	}
 	
 	public ByteBuilder(Object o){
 		String s=o.toString();
-		array=new byte[s.length()+1];
+		array=KillSwitch.allocByte1D(s.length()+1);
 		append(s);
 	}
 	
@@ -49,7 +48,7 @@ public final class ByteBuilder implements Serializable, CharSequence {
 	@Override
 	public CharSequence subSequence(int start, int end) throws IndexOutOfBoundsException{
 		if(start<0 || end>=length()){throw new IndexOutOfBoundsException();}
-		return new ByteBuilder(Arrays.copyOfRange(array, start, end));
+		return new ByteBuilder(KillSwitch.copyOfRange(array, start, end));
 	}
 
 //	public ByteBuilder append(float x, int places){return append(String.format(Locale.ROOT, decimalFormat[places], x));}
@@ -315,13 +314,13 @@ public final class ByteBuilder implements Serializable, CharSequence {
 			}
 		}
 		
-//		assert(String.format(Locale.ROOT, "%."+decimals0+"f", x0).equals(new String(Tools.reverseAndCopy(Arrays.copyOf(numbuffer, pos))))) : 
-//			String.format(Locale.ROOT, "%."+decimals0+"f", x0)+"\n"+new String(Tools.reverseAndCopy(Arrays.copyOf(numbuffer, pos)));
+//		assert(String.format(Locale.ROOT, "%."+decimals0+"f", x0).equals(new String(Tools.reverseAndCopy(KillSwitch.copyOf(numbuffer, pos))))) : 
+//			String.format(Locale.ROOT, "%."+decimals0+"f", x0)+"\n"+new String(Tools.reverseAndCopy(KillSwitch.copyOf(numbuffer, pos)));
 
 //		longRep=(long)x;
 //		assert(longRep==(long)(decimalMult[decimals0]*Double.parseDouble((String.format(Locale.ROOT, "%."+decimals0+"f", x0))))) : 
 //			"\n"+longRep+"\n"+decimalMult[decimals0]*Double.parseDouble((String.format(Locale.ROOT, "%."+decimals0+"f", x0)))+
-//			"\n"+x0+"\n"+String.format(Locale.ROOT, "%."+decimals0+"f", x0)+"\n"+new String(Tools.reverseAndCopy(Arrays.copyOf(numbuffer, pos)));
+//			"\n"+x0+"\n"+String.format(Locale.ROOT, "%."+decimals0+"f", x0)+"\n"+new String(Tools.reverseAndCopy(KillSwitch.copyOf(numbuffer, pos)));
 		
 		while(pos>0){
 			pos--;
@@ -561,9 +560,9 @@ public final class ByteBuilder implements Serializable, CharSequence {
 		if(array.length<=maxLen){return;}
 //		assert(length<=maxLen) : length+", "+array.length+", "+maxLen;
 		if(length<1){
-			array=new byte[maxLen];
+			array=KillSwitch.allocByte1D(maxLen);
 		}else{
-			array=Arrays.copyOf(array, maxLen);
+			array=KillSwitch.copyOf(array, maxLen);
 			length=Tools.min(length, maxLen);
 		}
 	}
@@ -646,7 +645,7 @@ public final class ByteBuilder implements Serializable, CharSequence {
 	
 	public byte[] array;
 	public int length=0;
-	private final byte[] numbuffer=new byte[40];
+	private final byte[] numbuffer=KillSwitch.allocByte1D(40);
 
 	public static final byte[] numbers=new byte[] {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9'};
 	public static final byte[] nullBytes="null".getBytes();
