@@ -15,6 +15,7 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import kmer.HashBuffer;
 import kmer.KmerTableSet;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -72,7 +73,7 @@ public class AccessionToTaxid_old {
 			String b=split.length>1 ? split[1] : null;
 
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -80,19 +81,19 @@ public class AccessionToTaxid_old {
 				stream.FastqReadInputStream.verbose=verbose;
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("stripunderscore")){
-//				STRIP_UNDERSCORE=Tools.parseBoolean(b);
+//				STRIP_UNDERSCORE=Parse.parseBoolean(b);
 				assert(false) : "stripunderscore is disabled.";
 			}else if(a.equals("usetables")){
-//				USE_TABLES=Tools.parseBoolean(b);
+//				USE_TABLES=Parse.parseBoolean(b);
 			}else if(a.equals("usetables")){
-//				USE_TABLES=Tools.parseBoolean(b);
+//				USE_TABLES=Parse.parseBoolean(b);
 			}else if(a.equals("skipparse")){
-				skipParse=Tools.parseBoolean(b);
+				skipParse=Parse.parseBoolean(b);
 			}else if(a.equals("skiphash")){
-				skipHash=Tools.parseBoolean(b);
+				skipHash=Parse.parseBoolean(b);
 			}else if(a.equals("prealloc")){ 
 				if(b==null || Character.isLetter(b.charAt(0))){
-					if(Tools.parseBoolean(b)){
+					if(Parse.parseBoolean(b)){
 						prealloc=0.78f;
 					}else{
 						prealloc=0;
@@ -428,7 +429,7 @@ public class AccessionToTaxid_old {
 		
 		while(b<line.length && line[b]!=delimiter){b++;}
 		assert(b>a) : "Missing field 2: "+new String(line);
-		ncbi=Tools.parseInt(line, a, b);
+		ncbi=Parse.parseInt(line, a, b);
 		b++;
 		a=b;
 		
@@ -527,13 +528,13 @@ public class AccessionToTaxid_old {
 //
 //			while(b<line.length && line[b]!=delimiter){b++;}
 //			assert(b>a) : "Missing field 2: "+new String(line);
-//			ncbi=Tools.parseInt(line, a, b);
+//			ncbi=Parse.parseInt(line, a, b);
 //			b++;
 //			a=b;
 //
 ////			while(b<line.length && line[b]!=delimiter){b++;}
 ////			assert(b>a) : "Missing field 3: "+new String(line);
-//////			gi=Tools.parseInt(line, a, b);
+//////			gi=Parse.parseInt(line, a, b);
 ////			b++;
 ////			a=b;
 //
@@ -591,13 +592,13 @@ public class AccessionToTaxid_old {
 			
 			while(b<line.length && line[b]!=delimiter){b++;}
 			assert(b>a) : "Missing field 2: "+new String(line);
-			ncbi=Tools.parseInt(line, a, b);
+			ncbi=Parse.parseInt(line, a, b);
 			b++;
 			a=b;
 			
 //			while(b<line.length && line[b]!=delimiter){b++;}
 //			assert(b>a) : "Missing field 3: "+new String(line);
-////			gi=Tools.parseInt(line, a, b);
+////			gi=Parse.parseInt(line, a, b);
 //			b++;
 //			a=b;
 			
@@ -676,14 +677,14 @@ public class AccessionToTaxid_old {
 			
 			while(b<line.length && line[b]!=delimiter){b++;}
 			assert(b>a) : "Missing field 2: "+new String(line);
-			ncbi=Tools.parseInt(line, a, b);
+			ncbi=Parse.parseInt(line, a, b);
 			//System.err.println("D: a="+a+", b="+b+", ncbi="+ncbi+", '"+(new String(line, a, b-a))+"'");
 			b++;
 			a=b;
 			
 //			while(b<line.length && line[b]!=delimiter){b++;}
 //			assert(b>a) : "Missing field 3: "+new String(line);
-////			gi=Tools.parseInt(line, a, b);
+////			gi=Parse.parseInt(line, a, b);
 //			b++;
 //			a=b;
 			
