@@ -5,6 +5,7 @@ import java.util.ArrayList;
 
 import fileIO.ByteFile;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Tools;
 import structures.IntList;
 
@@ -315,8 +316,8 @@ public class GiToTaxid {
 				assert(tab2<line.length && line[tab2]=='\t') : tab2+", "+tab3+", '"+new String(line)+"'";
 				assert(tab3<line.length && line[tab3]=='\t') : tab2+", "+tab3+", '"+new String(line)+"'";
 //				assert(false) : tab2+", "+tab3+", '"+new String(line)+"'";
-				int tid=Tools.parseInt(line, tab2+1, tab3);
-				int gi=Tools.parseInt(line, tab3+1, line.length);
+				int tid=Parse.parseInt(line, tab2+1, tab3);
+				int gi=Parse.parseInt(line, tab3+1, line.length);
 				int old=list.get(gi);
 				assert(old==0 || old==tid) : "Contradictory entries for gi "+gi+": "+old+" -> "+tid+"\n'"+new String(line)+"'\ntab2="+tab2+", tab3="+tab3;
 				
@@ -375,7 +376,7 @@ public class GiToTaxid {
 //		while(line!=null){
 //			count++;
 //			int tab=Tools.indexOf(line, (byte)'\t');
-//			long gi=Tools.parseLong(line, 0, tab);
+//			long gi=Parse.parseLong(line, 0, tab);
 //			max=Tools.max(max, gi);
 //			line=bf.nextLine();
 //		}
@@ -391,8 +392,8 @@ public class GiToTaxid {
 //		while(line!=null){
 //			count++;
 //			int tab=Tools.indexOf(line, (byte)'\t');
-//			int gi=Tools.parseInt(line, 0, tab);
-//			int ncbi=Tools.parseInt(line, tab+1, line.length);
+//			int gi=Parse.parseInt(line, 0, tab);
+//			int ncbi=Parse.parseInt(line, tab+1, line.length);
 //			//assert(x[gi]==-1 || x[gi]==ncbi) : "Contradictory entries for gi "+gi+": "+x[gi]+" -> "+ncbi;
 //			if(x[gi]!=-1 && x[gi]!=ncbi){
 //				if(!warned){
