@@ -13,6 +13,7 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import kmer.HashArray1D;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -63,7 +64,7 @@ public class RenameGiToTaxid {
 			String b=split.length>1 ? split[1] : null;
 
 			if(a.equals("prefix")){
-				prefix=Tools.parseBoolean(b);
+				prefix=Parse.parseBoolean(b);
 			
 			}else if(a.equals("server") || a.equals("useserver")){
 				if(b!=null && b.startsWith("http")){
@@ -72,7 +73,7 @@ public class RenameGiToTaxid {
 					if(!path.endsWith("/")){path+="/";}
 					Shared.setTaxServer(path);
 				}else{
-					useServer=Tools.parseBoolean(b);
+					useServer=Parse.parseBoolean(b);
 				}
 			}else if(a.equals("title")){
 				title=(b==null ? ">" : (">"+b+"|")).getBytes();
@@ -85,25 +86,25 @@ public class RenameGiToTaxid {
 			}else if(a.equals("invalid")){
 				outInvalid=b;
 			}else if(a.equals("deleteinvalid")){
-				deleteInvalid=Tools.parseBoolean(b);
+				deleteInvalid=Parse.parseBoolean(b);
 			}else if(a.equals("badheaders")){
 				badHeaders=b;
 			}else if(a.equals("maxbadheaders") || a.equals("maxinvalidheaders")){
-				maxInvalidHeaders=Tools.parseKMG(b);
+				maxInvalidHeaders=Parse.parseKMG(b);
 			}else if(a.equals("keepall")){
-				keepAll=Tools.parseBoolean(b);
+				keepAll=Parse.parseBoolean(b);
 			}else if(a.equals("shrinknames")){
-				shrinkNames=Tools.parseBoolean(b);
+				shrinkNames=Parse.parseBoolean(b);
 			}else if(a.equals("warn")){
-				warnBadHeaders=Tools.parseBoolean(b);
+				warnBadHeaders=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("maxpigzprocesses")){
 				AccessionToTaxid.maxPigzProcesses=Integer.parseInt(b);
 			}else if(a.equals("skipparse")){
-				AccessionToTaxid.skipParse=Tools.parseBoolean(b);
+				AccessionToTaxid.skipParse=Parse.parseBoolean(b);
 			}else if(a.equals("skiphash")){
-				AccessionToTaxid.skipHash=Tools.parseBoolean(b);
+				AccessionToTaxid.skipHash=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("mode")){
@@ -124,7 +125,7 @@ public class RenameGiToTaxid {
 			}
 			
 			else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
