@@ -6,6 +6,7 @@ import java.util.ArrayList;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -99,7 +100,7 @@ public class A_SampleSamStreamer implements Accumulator<A_SampleSamStreamer.Proc
 		
 		{
 //			if("auto".equalsIgnoreCase(atomic)){Scaffold.setCA3A(Shared.threads()>8);}
-//			else{Scaffold.setCA3A(Tools.parseBoolean(atomic));}
+//			else{Scaffold.setCA3A(Parse.parseBoolean(atomic));}
 
 			if(ploidy<1){System.err.println("WARNING: ploidy not set; assuming ploidy=1."); ploidy=1;}
 			samFilter.setSamtoolsFilter();
@@ -146,21 +147,21 @@ public class A_SampleSamStreamer implements Accumulator<A_SampleSamStreamer.Proc
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ref")){
 				ref=b;
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("realign")){
-				realign=Tools.parseBoolean(b);
+				realign=Parse.parseBoolean(b);
 			}else if(a.equals("ploidy")){
 				ploidy=Integer.parseInt(b);
 			}else if(a.equals("clearfilters")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					samFilter.clear();
 				}
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(samFilter.parse(arg, a, b)){
 				//do nothing
