@@ -13,6 +13,7 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
 import fileIO.TextStreamWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -77,7 +78,7 @@ public class CallVariants {
 				while(a.startsWith("-")){a=a.substring(1);} //Strip leading hyphens
 				
 				if(a.equals("multi") || a.equals("multisample")){
-					multi=Tools.parseBoolean(b);
+					multi=Parse.parseBoolean(b);
 				}
 			}
 		}
@@ -140,21 +141,21 @@ public class CallVariants {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("multi") || a.equals("multisample")){
-				boolean multi=Tools.parseBoolean(b);
+				boolean multi=Parse.parseBoolean(b);
 				assert(!multi) : "\nThis program does not support multi-sample variant calling.\n";
 			}else if(a.equals("ploidy")){
 				ploidy=Integer.parseInt(b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(a.equals("ss") || a.equals("samstreamer") || a.equals("streamer")){
 				if(b!=null && Tools.isDigit(b.charAt(0))){
 					useStreamer=true;
 					streamerThreads=Tools.max(1, Integer.parseInt(b));
 				}else{
-					useStreamer=Tools.parseBoolean(b);
+					useStreamer=Parse.parseBoolean(b);
 				}
 			}else if(a.equals("ssmf") || a.equals("samstreamermf") || a.equals("streamermf")){
 				if(b!=null && Tools.isDigit(b.charAt(0))){
@@ -162,37 +163,39 @@ public class CallVariants {
 					useStreamerMF=SamStreamerMF.MAX_FILES>1;
 					if(useStreamerMF){useStreamer=true;}
 				}else{
-					useStreamerMF=Tools.parseBoolean(b);
+					useStreamerMF=Parse.parseBoolean(b);
 					if(useStreamerMF){
 						SamStreamerMF.MAX_FILES=Tools.max(2, SamStreamerMF.MAX_FILES);
 						useStreamer=true;
 					}
 				}
 			}else if(a.equals("sslistsize")){
-				SamStreamer.LIST_SIZE=Tools.parseIntKMG(b);
+				SamStreamer.LIST_SIZE=Parse.parseIntKMG(b);
 				assert(SamStreamer.LIST_SIZE>0);
 			}else if(a.equals("cc") || a.equals("calccoverage") || a.equals("coverage")){
-				calcCoverage=Tools.parseBoolean(b);
+				calcCoverage=Parse.parseBoolean(b);
 			}else if(a.equals("parsename")){
-				SamLine.PARSE_0=Tools.parseBoolean(b);
+				SamLine.PARSE_0=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("noPassDotGenotype") || a.equalsIgnoreCase("noPassDot")){
-				Var.noPassDotGenotype=Tools.parseBoolean(b);
+				Var.noPassDotGenotype=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("minVarCopies")){
+				Var.MIN_VAR_COPIES=Integer.parseInt(b);
 			}else if(a.equals("extended")){
-				Var.extendedText=Tools.parseBoolean(b);
+				Var.extendedText=Parse.parseBoolean(b);
 			}else if(a.equals("useidentity")){
-				Var.useIdentity=Tools.parseBoolean(b);
+				Var.useIdentity=Parse.parseBoolean(b);
 			}else if(a.equals("usehomopolymer") || a.equals("homopolymer")){
-				Var.useHomopolymer=Tools.parseBoolean(b);
+				Var.useHomopolymer=Parse.parseBoolean(b);
 			}else if(a.equals("usepairing")){
-				Var.usePairing=Tools.parseBoolean(b);
+				Var.usePairing=Parse.parseBoolean(b);
 			}else if(a.equals("usebias")){
-				Var.useBias=Tools.parseBoolean(b);
+				Var.useBias=Parse.parseBoolean(b);
 			}else if(a.equals("nscan") || a.equals("donscan")){
-				Var.doNscan=Tools.parseBoolean(b);
+				Var.doNscan=Parse.parseBoolean(b);
 			}else if(a.equals("useedist")){
-				Var.useEdist=Tools.parseBoolean(b);
+				Var.useEdist=Parse.parseBoolean(b);
 			}else if(a.equals("prefilter")){
-				prefilter=Tools.parseBoolean(b);
+				prefilter=Parse.parseBoolean(b);
 			}else if(a.equals("ref")){
 				ref=b;
 			}else if(a.equals("vcf") || a.equals("vcfout") || a.equals("outvcf")){
@@ -214,17 +217,17 @@ public class CallVariants {
 			}
 			
 			else if(a.equals("ca3") || a.equals("32bit")){
-				Scaffold.setCA3(Tools.parseBoolean(b));
+				Scaffold.setCA3(Parse.parseBoolean(b));
 			}else if(a.equals("atomic")){
 				atomic=b;
 			}else if(a.equals("strandedcov") || a.equals("trackstrand") || a.equals("stranded")){
-				Scaffold.setTrackStrand(Tools.parseBoolean(b));
+				Scaffold.setTrackStrand(Parse.parseBoolean(b));
 			}
 			
 			else if(a.equals("realign")){
-				realign=Tools.parseBoolean(b);
+				realign=Parse.parseBoolean(b);
 			}else if(a.equals("unclip")){
-				unclip=Tools.parseBoolean(b);
+				unclip=Parse.parseBoolean(b);
 			}else if(a.equals("realignrows") || a.equals("rerows")){
 				Realigner.defaultMaxrows=Integer.parseInt(b);
 			}else if(a.equals("realigncols") || a.equals("recols")){
@@ -234,13 +237,17 @@ public class CallVariants {
 			}else if(a.equals("msa")){
 				Realigner.defaultMsaType=b;
 			}else if(a.equals("vmtlimit")){
-				vmtSizeLimit=Tools.parseIntKMG(b);
+				vmtSizeLimit=Parse.parseIntKMG(b);
 			}
 			
 			else if(samFilter.parse(arg, a, b)){
 				//do nothing
 			}
 			
+			else if(a.equalsIgnoreCase("countNearbyVars")){
+				countNearbyVars=Parse.parseBoolean(b);
+			}
+			
 			else if(a.equals("in") || a.equals("in1") || a.equals("in2")){
 				assert(b!=null) : "Bad parameter: "+arg;
 				if(new File(b).exists()){in.add(b);}
@@ -252,7 +259,7 @@ public class CallVariants {
 					in.add(line);
 				}
 			}else if(a.equals("clearfilters")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					varFilter.clear();
 					samFilter.clear();
 				}
@@ -287,7 +294,7 @@ public class CallVariants {
 		}
 		
 		if("auto".equalsIgnoreCase(atomic)){Scaffold.setCA3A(Shared.threads()>8);}
-		else{Scaffold.setCA3A(Tools.parseBoolean(atomic));}
+		else{Scaffold.setCA3A(Parse.parseBoolean(atomic));}
 
 		if(ploidy<1){System.err.println("WARNING: ploidy not set; assuming ploidy=1."); ploidy=1;}
 		samFilter.setSamtoolsFilter();
@@ -590,11 +597,32 @@ public class CallVariants {
 		t2.stop("Time: ");
 		outstream.println();
 		
+		if(countNearbyVars){
+			t2.start("Counting nearby variants.");
+			int x=varMap.countNearbyVars(varFilter);
+			if(x>0 && varFilter.failNearby){
+				Arrays.fill(types, 0);
+				for(Var v : varMap.toArray(false)){
+					if(!v.forced() && v.nearbyVarCount>varFilter.maxNearbyCount){
+						varMap.removeUnsynchronized(v);
+					}else{
+						//TODO:
+						//Recalculate passing statistics
+						//Only relevant in failNearby mode...  not really important.
+					}
+				}
+			}
+			t2.stop("Time: ");
+			outstream.println();
+//			assert(false) : varFilter.failNearby+", "+varFilter.maxNearbyCount;
+		}
+		
 		if(ffout!=null || vcf!=null || gffout!=null || scoreHistFile!=null || zygosityHistFile!=null || qualityHistFile!=null){
 //			t2.start("Writing output.");
 			if(ffout!=null || vcf!=null || gffout!=null){
 				Timer t3=new Timer("Sorting variants.");
-				VcfWriter vw=new VcfWriter(varMap, varFilter, readsProcessed-readsDiscarded, pairedInSequencingReadsProcessed, properlyPairedReadsProcessed,
+				VcfWriter vw=new VcfWriter(varMap, varFilter, readsProcessed-readsDiscarded, 
+						pairedInSequencingReadsProcessed, properlyPairedReadsProcessed,
 							trimmedBasesProcessed, ref, trimWhitespace, sampleName);
 				t3.stop("Time: ");
 				if(ffout!=null){
@@ -647,7 +675,7 @@ public class CallVariants {
 			if(prefilter){
 				outstream.println(c+" of "+d+" events were screened by the prefilter ("+String.format(Locale.ROOT, "%.4f%%", c*100.0/d)+").");
 			}
-			outstream.println(b+" of "+a+" variants passed filters ("+String.format(Locale.ROOT, "%.4f%%", b*amult)+").");
+			outstream.println(b+" of "+a+" variants passed primary filters ("+String.format(Locale.ROOT, "%.4f%%", b*amult)+").");
 			outstream.println();
 			final long sub=types[Var.SUB], del=types[Var.DEL], ins=types[Var.INS];
 			final double smult=1.0/Tools.max(1, sub), dmult=1.0/Tools.max(1, del), imult=1.0/Tools.max(1, ins);
@@ -661,7 +689,7 @@ public class CallVariants {
 			final double subQual=Tools.sumHistogram(avgQualityArray[Var.SUB+1])*smult;
 			final double delQual=Tools.sumHistogram(avgQualityArray[Var.DEL+1])*dmult;
 			final double insQual=Tools.sumHistogram(avgQualityArray[Var.INS+1])*imult;
-					
+			
 			outstream.println("Type           \tCount\tRate\tAD\tDepth\tAF\tScore\tQual");
 			outstream.println("Substitutions: \t"+sub+String.format(Locale.ROOT, "\t%.1f%%\t%."+(subAD>1000 ? 0 : 1)+"f\t%."+(subRD>1000 ? 0 : 1)+"f\t%.3f\t%.1f\t%.1f", 
 					sub*bmult, subAD, subRD, subAF, subScore, subQual));
@@ -1503,6 +1531,13 @@ public class CallVariants {
 	
 	public String sampleName=null;
 	
+	/* 
+	 * These cover junk due to artifacts, misassemblies, or structural variants,
+	 * which generally result in a rainbow of adjacent SNPs.
+	 * Some fields are in VarFilter.
+	 */
+	public boolean countNearbyVars=true;
+	
 	/*--------------------------------------------------------------*/
 	/*----------------         Final Fields         ----------------*/
 	/*--------------------------------------------------------------*/
