@@ -7,6 +7,7 @@ import java.util.Locale;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -85,15 +86,15 @@ public class FilterSam {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("ss") || a.equals("streamer")){
-				useStreamer=Tools.parseBoolean(b);
+				useStreamer=Parse.parseBoolean(b);
 			}else if(a.equals("ploidy")){
 				ploidy=Integer.parseInt(b);
 			}else if(a.equals("prefilter")){
-				prefilter=Tools.parseBoolean(b);
+				prefilter=Parse.parseBoolean(b);
 			}else if(a.equals("ref")){
 				ref=b;
 			}else if(a.equals("outbad") || a.equals("outb")){
@@ -102,6 +103,10 @@ public class FilterSam {
 				varFile=b;
 			}else if(a.equals("vcf") || a.equals("vcffile")){
 				vcfFile=b;
+			}else if(a.equals("maxsubs") || a.equals("subfilter")){
+				maxSubs=Integer.parseInt(b);
+			}else if(a.equals("maxvars") || a.equals("varfilter")){
+				maxVars=Integer.parseInt(b);
 			}else if(a.equals("maxbadsubs") || a.equals("maxbadvars") || a.equals("mbv")){
 				maxBadVars=Integer.parseInt(b);
 			}else if(a.equals("maxbadsubdepth") || a.equals("maxbadvardepth") || a.equals("maxbadsuballeledepth")
@@ -112,17 +117,17 @@ public class FilterSam {
 			}else if(a.equals("minbadsubreaddepth") || a.equals("minbadreaddepth") || a.equals("mbsrd") || a.equals("mbrd")){
 				minBadReadDepth=Integer.parseInt(b);
 			}else if(a.equals("sub") || a.equals("subs")){
-				Var.CALL_SUB=Tools.parseBoolean(b);
+				Var.CALL_SUB=Parse.parseBoolean(b);
 			}else if(a.equals("ins") || a.equals("inss")){
-				Var.CALL_INS=Tools.parseBoolean(b);
+				Var.CALL_INS=Parse.parseBoolean(b);
 			}else if(a.equals("del") || a.equals("dels")){
-				Var.CALL_DEL=Tools.parseBoolean(b);
+				Var.CALL_DEL=Parse.parseBoolean(b);
 			}else if(a.equals("indel") || a.equals("indels")){
-				Var.CALL_INS=Var.CALL_DEL=Tools.parseBoolean(b);
+				Var.CALL_INS=Var.CALL_DEL=Parse.parseBoolean(b);
 			}else if(a.equals("minedist") || a.equals("minenddist") || a.equals("border")){
 				minEDist=Integer.parseInt(b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
@@ -610,6 +615,23 @@ public class FilterSam {
 			mappedReadsProcessedT++;
 			mappedBasesProcessedT+=len;
 			
+			if(vars==0){
+				varSumGoodT+=vars;
+				qSumGoodT+=q;
+				mapqSumGoodT+=sl.mapq;
+				mappedReadsRetainedT++;
+				mappedBasesRetainedT+=len;
+				return true;
+			}
+			
+			if((maxVars>=0 && vars>maxVars) || 
+					(maxSubs>=0 && vars>maxSubs && ((subsOnly ? vars : Read.countSubs(r.match))>maxSubs))){
+				varSumBadT+=vars;
+				qSumBadT+=q;
+				mapqSumBadT+=sl.mapq;
+				return false;
+			}
+			
 			if(vars<=maxBadVars){
 				varSumGoodT+=vars;
 				qSumGoodT+=q;
@@ -618,6 +640,7 @@ public class FilterSam {
 				mappedBasesRetainedT+=len;
 				return true;
 			}
+			
 			final ArrayList<Var> list;
 			if(subsOnly){
 				list=CallVariants.findUniqueSubs(r, sl, varMap, scafMap, maxBadAlleleDepth, maxBadAlleleFraction, minBadReadDepth, minEDist);
@@ -707,6 +730,11 @@ public class FilterSam {
 	
 	/*--------------------------------------------------------------*/
 	
+	/** Maximum allowed substitutions in a read */
+	private int maxSubs=-1;
+	/** Maximum allowed variations in a read */
+	private int maxVars=-1;
+	
 	/** Maximum allowed unsupported substitutions in a read */
 	private int maxBadVars=1;
 	/** Maximum variant depth for a variant to be considered unsupported */
