@@ -9,6 +9,7 @@ import fileIO.ByteFile2;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -62,7 +63,7 @@ public class FilterVCF {
 				maxLines=Long.parseLong(b);
 				if(maxLines<0){maxLines=Long.MAX_VALUE;}
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -70,37 +71,37 @@ public class FilterVCF {
 				stream.FastqReadInputStream.verbose=verbose;
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("multithreaded") || a.equals("mt")){
-				multithreaded=Tools.parseBoolean(b);
+				multithreaded=Parse.parseBoolean(b);
 			}else if(a.equals("singlethreaded") || a.equals("st")){
-				multithreaded=!Tools.parseBoolean(b);
+				multithreaded=!Parse.parseBoolean(b);
 			}else if(a.equals("ref")){
 				ref=b;
 			}else if(a.equals("ploidy")){
 				ploidy=Integer.parseInt(b);
 			}else if(a.equals("sub") || a.equals("subs")){
-				Var.CALL_SUB=Tools.parseBoolean(b);
+				Var.CALL_SUB=Parse.parseBoolean(b);
 			}else if(a.equals("del") || a.equals("dels")){
-				Var.CALL_DEL=Tools.parseBoolean(b);
+				Var.CALL_DEL=Parse.parseBoolean(b);
 			}else if(a.equals("ins") || a.equals("inss")){
-				Var.CALL_INS=Tools.parseBoolean(b);
+				Var.CALL_INS=Parse.parseBoolean(b);
 			}else if(a.equals("indel") || a.equals("indels")){
-				Var.CALL_INS=Var.CALL_DEL=Tools.parseBoolean(b);
+				Var.CALL_INS=Var.CALL_DEL=Parse.parseBoolean(b);
 			}else if(a.equals("junction") || a.equals("junctions")){
-				Var.CALL_JUNCTION=Tools.parseBoolean(b);
+				Var.CALL_JUNCTION=Parse.parseBoolean(b);
 			}else if(a.equals("minscore")){
 				minScore=Double.parseDouble(b);
 			}else if(a.equals("splitalleles")) {
-				splitAlleles=Tools.parseBoolean(b);
+				splitAlleles=Parse.parseBoolean(b);
 			}else if(a.equals("splitsubs") || a.equals("splitsnps")) {
-				splitSubs=Tools.parseBoolean(b);
+				splitSubs=Parse.parseBoolean(b);
 			}else if(a.equals("splitcomplex")) {
-				splitComplex=Tools.parseBoolean(b);
+				splitComplex=Parse.parseBoolean(b);
 			}else if(a.equals("sass") || a.equals("split")) {
-				splitAlleles=splitSubs=Tools.parseBoolean(b);
+				splitAlleles=splitSubs=Parse.parseBoolean(b);
 			}else if(a.equals("splitall") || a.equals("sascsss")) {
-				splitAlleles=splitComplex=splitSubs=Tools.parseBoolean(b);
+				splitAlleles=splitComplex=splitSubs=Parse.parseBoolean(b);
 			}else if(a.equals("clearfilters")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					varFilter.clear();
 					samFilter.clear();
 				}
@@ -111,7 +112,11 @@ public class FilterVCF {
 			}else if(a.equals("scorehist") || a.equals("qualhist") || a.equals("qhist") || a.equals("shist")){
 				scoreHistFile=b;
 			}else if(a.equals("trimtocanonical") || a.equals("canonicalize") || a.equals("canonicize") || a.equals("canonize")){
-				VCFLine.TRIM_TO_CANONICAL=Tools.parseBoolean(b);
+				VCFLine.TRIM_TO_CANONICAL=Parse.parseBoolean(b);
+			}
+			
+			else if(a.equalsIgnoreCase("countNearbyVars")){
+				countNearby=Parse.parseBoolean(b);
 			}
 			
 			else if(parser.parse(arg, a, b)){
@@ -336,8 +341,8 @@ public class FilterVCF {
 						}
 						
 						if(v!=null){
-							pass&=varFilter.passesFilter(v, properPairRate,
-									totalQualityAvg, totalMapqAvg, readLengthAvg, ploidy, scafMap);
+							pass&=varFilter.passesFilter(v, properPairRate, totalQualityAvg, totalMapqAvg,
+									readLengthAvg, ploidy, scafMap, countNearby);
 						}else{
 							pass&=vline.qual>=varFilter.minScore;
 						}
@@ -591,8 +596,8 @@ public class FilterVCF {
 									v=vline.toVar();
 								}
 								
-								pass&=varFilter.passesFilter(v, properPairRate,
-										totalQualityAvg, totalMapqAvg, readLengthAvg, ploidy, scafMap);
+								pass&=varFilter.passesFilter(v, properPairRate, totalQualityAvg, totalMapqAvg,
+										readLengthAvg, ploidy, scafMap, countNearby);
 							} catch (Throwable e) {
 								System.err.println("WARNING: This VCF file does not support Var format.\n"
 										+ "Filtering can only be done on location and quality score.\n"+e);
@@ -676,6 +681,10 @@ public class FilterVCF {
 	boolean splitSubs=false;
 	boolean splitComplex=false;
 	
+	//TODO: These should actually be counted if this is enabled,
+	//if counts are -1 rather than 0.
+	boolean countNearby=false;
+	
 //	private final ArrayBlockingQueue<ListNum<byte[]>> inq;
 	
 	/*--------------------------------------------------------------*/
