@@ -6,6 +6,7 @@ import java.util.ArrayList;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -96,17 +97,17 @@ public class Realign {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}
 			
 			
 			else if(a.equals("unclip")){
-				unclip=Tools.parseBoolean(b);
+				unclip=Parse.parseBoolean(b);
 			}else if(a.equals("realignrows") || a.equals("rerows")){
 				Realigner.defaultMaxrows=Integer.parseInt(b);
 			}else if(a.equals("realigncols") || a.equals("recols")){
